@@ -76,7 +76,9 @@
 #2.0.4.4 - Mar08 - add daily maintenance for sql
 #2.0.4.5 - Nov10 - Sanity 
 #2.0.4.6 - Minor release changes and fine tuning - Jul2015
-
+#2.0.5   - Add ipV6 -May2017
+#					-Changes made in SuccessManager
+#					-Changes made in FailManager
 
 
 use warnings;
@@ -125,6 +127,9 @@ my $ReplCmd=$bkupreplcommand;   #Requires valid ssh keys - see the sehll script
  my $RefDate=0;
  my $mntLoopCur=0;
  my $startup=0;
+ 
+ my ($ResIP6,$NodeVIP6,$sqlIP6); #2.0.5
+ 
  if ($setdaemon eq 1) {&SetDaemon;}
  $CurEpoche=0;
  my $WeightDownTimer=0;
@@ -467,19 +472,19 @@ sub GetConfig {
  }
  #Get Inventory from mySQL 
  $dbh = DBI->connect("DBI:mysql:$database:$servername:3306",$sqluser,$sqlpassword)  or &sqldead;
- my $sqlnode = $dbh->prepare("SELECT nodeID,Name,scheduler,service,vip,persistent FROM tblNodes where monitor='1' and enabled='1'" );
+ my $sqlnode = $dbh->prepare("SELECT nodeID,Name,scheduler,service,vip,persistent,vip6 FROM tblNodes where monitor='1' and enabled='1'" );
  $sqlnode->execute ;  #Get Nodes
  #print "DEB $database:$servername\n";
- while(($NodeID,$NodeName,$NodeScheduler,$NodeService,$NodeVIP,$NodePersistent)=$sqlnode->fetchrow_array) {
+ while(($NodeID,$NodeName,$NodeScheduler,$NodeService,$NodeVIP,$NodePersistent,$NodeVIP6)=$sqlnode->fetchrow_array) {
   $nodecnt++;
   
   #2.0.3.8 do not add maintenance marked inventory entries
   my $sqlnodeinv = $dbh->prepare("SELECT invID,resID,Method,Link,Weight,AutomovePoolID,Port,Failstate,bid FROM tblNodesInventory where nodeID='" . $NodeID ."' and enabled='1' and maintenance <> '1';" );
   $sqlnodeinv->execute ;  #Get NodesInentory
   while(($InvID,$InvResID,$InvMethod,$invLink,$InvWeight,$InvAutomovePoolID,$InvPort,$InvFailstate,$InvBid)=$sqlnodeinv->fetchrow_array) {
-   my $sqlnoderes = $dbh->prepare("SELECT alias,realip FROM tblResources where resID='" . $InvResID ."' and enabled='1';" );
+   my $sqlnoderes = $dbh->prepare("SELECT alias,realip,realip6 FROM tblResources where resID='" . $InvResID ."' and enabled='1';" );
    $sqlnoderes->execute ; #Get Resources
-   while (($ResAlias,$ResIP)=$sqlnoderes->fetchrow_array) {
+   while (($ResAlias,$ResIP,$ResIP6)=$sqlnoderes->fetchrow_array) {
     $hstcnt++;
     my $sqlmon = $dbh->prepare("SELECT monid,timeout,recTaskID,checkinterval,failcheckinterval,rechecks,recheckwait,notificationclock,Immediaterecoverid,commandid,lastcheck,status,enabled,checkinventory,messageid FROM tblMonitor where invID='" . $InvID ."' and checkalive='1';" ); 
     $sqlmon->execute ;  #Get Monitor conf
@@ -657,14 +662,15 @@ sub SuccessManager(){
 	my $dbhs = DBI->connect("DBI:mysql:$database:$servername:3306",$sqluser,$sqlpassword)  or &sqldead;
 	my ($sqlmoninv,$sqlInvID,$sqlmon,$mymonID,%TmpFailState);
 	my ($InvLink,$InvNodeID,$scheduler,$NodeService,$NodeName,$NodeVIP,$InvResID,$mscheduler,$NodeIDautomovepoolid,$presID,$InvRealIP,$NodeINVactive,$NodeINVenabled,$NodeINVmethod,$NodeINVweight,$NodeINVID,$sqlmethod,$sqlweight,$mstring,$sqlalias,$sqlIPort);
+	my ($NodeVIP6,$mscheduler6,$mstring6); #2.0.5
 	my $TmpFailTot=0;
   #Get InvID by $_[1]
   $sqlmoninv = $dbhs->prepare("SELECT link,nodeID,resID,method,weight FROM tblNodesInventory where invID = '" . $_[1] . "' and enabled='1';" ) or &sqldead;
 	$sqlmoninv->execute;
 	(($InvLink,$InvNodeID,$InvResID,$sqlmethod,$sqlweight)=$sqlmoninv->fetchrow_array) ;
-  $sqlalias = $dbhs->prepare("SELECT alias,realip FROM tblResources where resID = '" . $InvResID . "';" ) or &sqldead;
+  $sqlalias = $dbhs->prepare("SELECT alias,realip,realip6 FROM tblResources where resID = '" . $InvResID . "';" ) or &sqldead;
   $sqlalias->execute ; #Get Inventory and ID's
-  (my($sqlAlias,$sqlIP)=$sqlalias->fetchrow_array);
+  (my($sqlAlias,$sqlIP,$sqlIP6)=$sqlalias->fetchrow_array);
   #ADD INVENTORY PRECHECK
   #If chkInv then Check all services within this host and skip all operations if active = 0 !!!!
   #But dont do this if Maintenance/Service mode $-[3] is configured 
@@ -714,37 +720,90 @@ sub SuccessManager(){
 	 
 	while (($InvLink,$InvNodeID,$NodeIDautomovepoolid,$NodeINVmethod,$NodeINVweight,$NodeINVID,$sqlIPort)=$sqlmoninv->fetchrow_array) {
 	 #Enum all belonging services within this host
-   my $sqlnode = $dbhs->prepare("SELECT Name,service,vip FROM tblNodes where nodeID='" . $InvNodeID ."' and enabled='1'" ) or &sqldead;
+   my $sqlnode = $dbhs->prepare("SELECT Name,service,vip,vip6 FROM tblNodes where nodeID='" . $InvNodeID ."' and enabled='1'" ) or &sqldead;
    $sqlnode->execute ;  #Get Nodes
-   (($NodeName,$NodeService,$NodeVIP)=$sqlnode->fetchrow_array) ;
+   (($NodeName,$NodeService,$NodeVIP,$NodeVIP6)=$sqlnode->fetchrow_array) ;
    #&syslog ("=>DEBUG::: $_[2] - $NodeINVID - $_[0]",1);
    if (($_[2] ne 1 ) and ($NodeINVID eq $_[1]) or (($_[2] eq 1 ))) {
     if ($NodeService !~ /fwm/i) {
-     $mscheduler = "-t $NodeVIP";
+     if ($NodeVIP) {
+      $mscheduler = "-t $NodeVIP";
+     }
+     if ($NodeVIP6) { #2.0.5
+      if ($NodeVIP6=~/(.*):(\d+)$/) {  
+       $mscheduler6 = "-t [$1]:$2";
+      } 
+     }
+     
+      
     } else {
-     $mscheduler = "-f $NodeVIP";	
+     if ($NodeVIP) {
+      $mscheduler = "-f $NodeVIP";	
+     } 
+
+     if ($NodeVIP6) {  #2.0.5
+      $mscheduler6 = "-f $NodeVIP6";	
+     } 
+
     }	
     
     if ($NodeService !~ /fwm/i) {
-     $mstring = "$lvscmd -a -t $NodeVIP -r $sqlIP:$sqlIPort -$NodeINVmethod -w $NodeINVweight";
+     if ($NodeVIP) {
+      $mstring = "$lvscmd -a -t $NodeVIP -r $sqlIP:$sqlIPort -$NodeINVmethod -w $NodeINVweight";
+     } 
+     if ($NodeVIP6) {  #2.0.5
+     	if ($NodeVIP6=~/(.*):(\d+)$/) {  
+       $mstring6 = "$lvscmd -a -t [$1]:$2 -r [$sqlIP6]:$sqlIPort -$NodeINVmethod -w $NodeINVweight";
+      } 
+     } 
+
+
     } else {
-     $mstring = "$lvscmd -a -f $NodeVIP -r $sqlIP -$NodeINVmethod -w $NodeINVweight";	
+     if ($NodeVIP) {
+      $mstring = "$lvscmd -a -f $NodeVIP -r $sqlIP -$NodeINVmethod -w $NodeINVweight";	
+     }
+
+     if ($NodeVIP6) {  #2.0.5
+      $mstring6 = "$lvscmd -a -f $NodeVIP6 -6 -r [$sqlIP6]:$sqlIPort -$NodeINVmethod -w $NodeINVweight";	
+     }
+     
+      
     }	
     
     if ($TmpFailTot eq 0){  
      #Need to depend on InvC
      if (!$simulate) {
       &chk_time_to_die; 
-      &syslog ("=>APPLY: $mstring",1);
-      &lvslog(10,"Apply: $mstring","monitor");
-      $cmdret=`$mstring`;   #Run command
+
+      if ($mstring) {
+       &syslog ("=>APPLY(v4): $mstring",1);
+       &lvslog(10,"Apply(v4): $mstring","monitor");
+       $cmdret=`$mstring`;   #Run command
+      } 
+
+      if ($mstring6) { #2.0.5
+       &syslog ("=>APPLY(v6): $mstring6",1);
+       &lvslog(10,"Apply(v6): $mstring6","monitor");
+       $cmdret=`$mstring6`;   #Run command
+      } 
+
+
   	 } else {
-  	  &syslog ("=>Simulate APPLY: $mstring",1);
-      &lvslog(10,"Simulate Apply: $mstring","monitor");
+  	 	if ($mstring) {
+  	   &syslog ("=>Simulate APPLY(v4): $mstring",1);
+       &lvslog(10,"Simulate Apply(v4): $mstring","monitor");
+      }
+      if ($mstring6) { #2.0.5
+  	   &syslog ("=>Simulate APPLY(v6): $mstring6",1);
+       &lvslog(10,"Simulate Apply(v6): $mstring6","monitor");
+      }	 
   	 }
   	 #$NodeINVID
   	 &syslog ("=>OK APPLY: UPDATE tblNodesInventory SET active = '1' where invID ='" . $NodeINVID . "'  and enabled='1';",1) ;
 	   &lvslog(3,"=>OK APPLY: UPDATE tblNodesInventory SET active = 1 where invID =" . $NodeINVID . "  and enabled=1;" ,"monitor");
+
+
+
      $sqlset = $dbhs->prepare("UPDATE tblNodesInventory SET active = '1' where invID ='" . $NodeINVID . "'  and enabled='1';") or &sqldead;
 	   $Time=time;
 	   &lvslog(3,"UPDATE tblMonitor SET lastcheck = ". $Time .", status=OK where invID =".$NodeINVID.";","monitor");
@@ -830,6 +889,7 @@ sub FailManager(){
 	my $sqlmoninv;
 	my ($sqlResID,$sqlAlias,$presHost,$myCHost,$var,$value,$sqlLink,$InvRealAlias,$myCurID);
 	my ($InvLink,$InvNodeID,$scheduler,$NodeService,$NodeName,$NodeVIP,$InvResID,$mscheduler,$NodeIDautomovepoolid,$presID,$InvRealIP,$NodeINVactive,$NodeINVenabled,$NodeINVmethod,$NodeINVweight,$NodeINVID,$sqlstat);
+	my ($NodeVIP6,$mscheduler6,$sqlIP6,$sqlPort); #2.0.5
 	&syslog("=>APPLY: Function FailManager =>$_[0]<=>$_[1]<=>$_[2]<=",1);
   #Get InvID by $_[1]
   &syslog("DEBUG SELECT link,nodeID,resID,automovepoolid FROM tblNodesInventory where invID = '" . $_[1] . "' and enabled='1';",1);
@@ -838,32 +898,70 @@ sub FailManager(){
 	(($InvLink,$InvNodeID,$InvResID,$NodeIDautomovepoolid)=$sqlmoninv->fetchrow_array) ;
 	&syslog("DEBUG Response $InvLink,$InvNodeID,$InvResID,$NodeIDautomovepoolid",1);
 	&syslog("DEBUG SELECT link,nodeID,automovepoolid,method,weight,invID FROM tblNodesInventory where resID = '" . $InvResID . "';",1);
-	$sqlmoninv = $dbhf->prepare("SELECT link,nodeID,automovepoolid,method,weight,invID FROM tblNodesInventory where resID = '" . $InvResID . "';" ) or &sqldead;
+  #2.0.5 - Special - get realip6
+  $sqlmoninv = $dbhf->prepare("SELECT realip6 FROM tblResources where resID = '" . $InvResID . "';" ) or &sqldead;
+  $sqlmoninv->execute ; #Get Inventory and ID's
+  (($sqlIP6)=$sqlmoninv->fetchrow_array);
+
+
+	$sqlmoninv = $dbhf->prepare("SELECT link,nodeID,automovepoolid,method,weight,invID,port FROM tblNodesInventory where resID = '" . $InvResID . "';" ) or &sqldead;
 	$sqlmoninv->execute;
-	while (($InvLink,$InvNodeID,$NodeIDautomovepoolid,$NodeINVmethod,$NodeINVweight,$NodeINVID)=$sqlmoninv->fetchrow_array) {
+	while (($InvLink,$InvNodeID,$NodeIDautomovepoolid,$NodeINVmethod,$NodeINVweight,$NodeINVID,$sqlPort)=$sqlmoninv->fetchrow_array) {
 	 &syslog("DEBUG Response $InvLink,$InvNodeID,$NodeIDautomovepoolid,$NodeINVmethod,$NodeINVweight,$NodeINVID",1);
 	 #Enum all belonging services within this host
    &syslog("DEBUG SELECT Name,service,vip FROM tblNodes where nodeID='" . $InvNodeID ."' and enabled='1'",1);
-   my $sqlnode = $dbhf->prepare("SELECT Name,service,vip FROM tblNodes where nodeID='" . $InvNodeID ."' and enabled='1'" ) or &sqldead;
+   my $sqlnode = $dbhf->prepare("SELECT Name,service,vip,vip6 FROM tblNodes where nodeID='" . $InvNodeID ."' and enabled='1'" ) or &sqldead;
    $sqlnode->execute ;  #Get Nodes
-   (($NodeName,$NodeService,$NodeVIP)=$sqlnode->fetchrow_array) ;
+   (($NodeName,$NodeService,$NodeVIP,$NodeVIP6)=$sqlnode->fetchrow_array) ;
    &syslog("DEBUG Compare $NodeName,$NodeService,$NodeVIP,$NodeINVID,$_[0],$_[1],$_[2]",1);
    if ((($_[2] ne 1 ) and ($NodeINVID eq $_[1])) or ($_[2] eq 1 )) {
     if ($NodeService !~ /fwm/i) {
-     $mscheduler = "-t $NodeVIP";
+     if ($NodeVIP) {
+      $mscheduler = "-t $NodeVIP";
+     }
+     
+     if ($NodeVIP6) {
+     	if ($NodeVIP6=~/(.*):(\d+)$/) {  
+     	 $mscheduler6 = "-t [$1]:$2";
+     	} 
+     }
+      
     } else {
-     $mscheduler = "-f $NodeVIP";	
+     if ($NodeVIP) {
+      $mscheduler = "-f $NodeVIP";	
+     }
+     if ($NodeVIP6) {
+      $mscheduler6 = "-f $NodeVIP6";	
+     } 
     }	
     if (!$simulate) {
      &chk_time_to_die; 
-     $cmdret=`$lvscmd -d $mscheduler -r $LvsMonIP{$_[0]}`;   #Run command
-     &syslog ("=>APPLY: $lvscmd -d $mscheduler -r $LvsMonIP{$_[0]}",1);
-     $LvsMonStateFrom{$_[0]}=1;
-     &lvslog(10,"Apply: $lvscmd -d $mscheduler -r $LvsMonIP{$_[0]}","monitor");
+     if ($mscheduler) {
+      $cmdret=`$lvscmd -d $mscheduler -r $LvsMonIP{$_[0]}`;   #Run command
+      &syslog ("=>APPLY(v4): $lvscmd -d $mscheduler -r $LvsMonIP{$_[0]}:$sqlPort",1);  #2.0.5 - add port
+      $LvsMonStateFrom{$_[0]}=1;
+      &lvslog(10,"Apply(v4): $lvscmd -d $mscheduler -r $LvsMonIP{$_[0]}:$sqlPort","monitor");  #2.0.5 - add port
+     } 
+     if ($mscheduler6) { #2.0.5
+      $cmdret=`$lvscmd -d $mscheduler6 -r [$sqlIP6]:$sqlPort`;   #Run command
+      #$sqlIP6
+      &syslog ("=>APPLY(v6): $lvscmd -d $mscheduler6 -r [$sqlIP6]:$sqlPort",1);
+      $LvsMonStateFrom{$_[0]}=1;
+      &lvslog(10,"Apply(v6): $lvscmd -d $mscheduler6 -r [$sqlIP6]:$sqlPort","monitor");
+     }     
+     
+     
     } else {
-     &syslog ("=>Simulate APPLY: $lvscmd -d $mscheduler -r $LvsMonIP{$_[0]}",1);
-     $LvsMonStateFrom{$_[0]}=1;
-     &lvslog(10,"Simulate Apply: $lvscmd -d $mscheduler -r $LvsMonIP{$_[0]}","monitor");
+     if ($mscheduler) {
+      &syslog ("=>Simulate APPLY(v4): $lvscmd -d $mscheduler -r $LvsMonIP{$_[0]}",1);
+      $LvsMonStateFrom{$_[0]}=1;
+      &lvslog(10,"Simulate Apply(v4): $lvscmd -d $mscheduler -r $LvsMonIP{$_[0]}","monitor");
+     }
+     if ($mscheduler6) {  #2.0.5
+      &syslog ("=>APPLY(v6): $lvscmd -d $mscheduler6 -r [$sqlIP6]:$sqlPort",1);
+      &lvslog(10,"Apply(v6): $lvscmd -d $mscheduler6 -r [$sqlIP6]:$sqlPort","monitor");
+     }	
+      
     }
     
     #if ($_[3] ne 1) {
@@ -904,7 +1002,9 @@ sub FailManager(){
          (($NodeName,$NodeService,$NodeVIP)=$sqlnodee->fetchrow_array) ;
          if ($NodeService !~ /fwm/i) {
           #$mscheduler = "-t $NodeVIP";
+          
           $mscheduler = "$lvscmd -a -t $NodeVIP -r $InvRealIP:$LvsMonPort{$_[0]} -$LvsMonInvMethodID{$_[0]} -w $NodeINVweight";
+          
           #$LvsMonInvWeight{$_[0]}
          } else {
           $mscheduler = "$lvscmd -a -f $NodeVIP -r $InvRealIP -$LvsMonInvMethodID{$_[0]} -w $NodeINVweight";	
@@ -1093,40 +1193,72 @@ sub chk_time_to_die () {
 sub WeightDownHost {
 	#Independant service function - Nov06
   my $fdbh = DBI->connect("DBI:mysql:$database:$servername:3306",$sqluser,$sqlpassword)  or &sqldead;
-  
   my ($fResID,$simulate);
   $simulate="0";
+  my ($fsqlIP6,$fNodeVip6,$fmstring6); #2.0.5
 	$fResID=$_[0];
   my ($fsqliID,$fsqliWeight,$fsqlNodeID,$fsqlLink,$fsqlIPort,$fsqlactive,$fsqlmethod,$fsqlweight,$fsqlPoolID);
   my ($fNodeService,$fNodeVip,$fmstring,$fmdstring,$fsqlPoolReource,$fmyCurID,$fmxstring,$sqli,$sqln,$sqla,$myIP,$myHost);
   my ($sqls,$fmyCHost,$fauto_ok,$fvar,$fvalue,$fsqlcur,$fweightdownstate,$fsqliTID,$fsqlpool,$fsqlIP,$fsqlaEnabled,$fsqlHostName);
   
-  $sqla = $fdbh->prepare("SELECT alias,realip,alias FROM tblResources where resID = '" . $fResID . "';" ); 
+  $sqla = $fdbh->prepare("SELECT alias,realip,realip6 FROM tblResources where resID = '" . $fResID . "';" ); 
   $sqla->execute ; #Get Inventory and ID's
-  (($sqla,$fsqlIP)=$sqla->fetchrow_array);
+  (($sqla,$fsqlIP,$fsqlIP6)=$sqla->fetchrow_array);
   $myIP=$fsqlIP;
   $myHost=$sqla;
   $sqli = $fdbh->prepare("SELECT invID,weight,nodeID,link,port,active,method,weight,automovepoolid FROM tblNodesInventory where resID = '" . $fResID . "';" ); 
   $sqli->execute ; #Get Inventory and ID's
   while (($fsqliID,$fsqliWeight,$fsqlNodeID,$fsqlLink,$fsqlIPort,$fsqlactive,$fsqlmethod,$fsqlweight,$fsqlPoolID)=$sqli->fetchrow_array) {
-   $sqln = $fdbh->prepare("SELECT service,vip FROM tblNodes where nodeid = '" . $fsqlNodeID . "';" ); 
+   $sqln = $fdbh->prepare("SELECT service,vip,vip6 FROM tblNodes where nodeid = '" . $fsqlNodeID . "';" ); 
    $sqln->execute ; 
-   ($fNodeService,$fNodeVip)=$sqln->fetchrow_array ;
+   ($fNodeService,$fNodeVip,$fNodeVip6)=$sqln->fetchrow_array ;
    if ($fNodeService !~ /fwm/i) {
    	
-    $fmstring = "$lvscmd -e -t $fNodeVip -r $fsqlIP:$fsqlIPort -$fsqlmethod -w 0";
+   	if ($fNodeVip) {
+     $fmstring = "$lvscmd -e -t $fNodeVip -r $fsqlIP:$fsqlIPort -$fsqlmethod -w 0";
+    } 
+    
+    if ($fNodeVip6) {  #2.0.5
+     if ($fNodeVip6 =~/(.*):(\d+)$/) {  #
+      $fmstring6 = "$lvscmd -e -t [$1]:$2 -r [$fsqlIP6]:$fsqlIPort -$fsqlmethod -w 0";
+     } 
+    } 
+    
     $fmdstring = "$lvscmd -d -t $fNodeVip -r $fsqlIP:$fsqlIPort";
+    
    } else {
-    $fmstring = "$lvscmd -e -f $fNodeVip -r $fsqlIP -$fsqlmethod -w 0";	
+
+    if ($fNodeVip) {
+     $fmstring = "$lvscmd -e -f $fNodeVip -r $fsqlIP:$fsqlIPort -$fsqlmethod -w 0";	
+    }
+
+    if ($fNodeVip6) {  #
+     $fmstring6 = "$lvscmd -e -f $fNodeVip6 -6 -r [$fsqlIP6]:$fsqlIPort -$fsqlmethod -w 0";	
+    }
+     
+    
     $fmdstring = "$lvscmd -d -f $fNodeVip -r $fsqlIP";	
    }	
    #	APPLY: /usr/bin/sudo /sbin/ipvsadm -e -t 10.0.1.4:7000 -r 10.0.1.11:7000 -g -w 0
    #	APPLY: /usr/bin/sudo /sbin/ipvsadm -e -f 5 -r 10.0.1.11 -g -w 0
-   &syslog("MGR: Apply: $fmstring",2);
-   if ($simulate eq "0") {
-    `$fmstring`;
-   } 
-   &lvslog(11,"Drain down service by: $fmstring","system");
+   
+   
+   if ($fNodeVip) {
+    &syslog("MGR: Apply v4: $fmstring",2);
+    &lvslog(11,"Drain down v4 service by: $fmstring","system");
+    if ($simulate eq "0") {
+     `$fmstring`;
+    } 
+   }
+    
+   if ($fNodeVip6) {
+   	&syslog("MGR: Apply v6: $fmstring6",2);
+    &lvslog(11,"Drain down v6 service by: $fmstring6","system");
+    if ($simulate eq "0") {
+     `$fmstring6`;
+    } 
+   }
+   
    
    &syslog("MGR: SQL: UPDATE tblNodesInventory SET weightdown = '1' where invID ='" . $fsqliID,2);
    if ($simulate eq "0") {
@@ -1157,9 +1289,6 @@ sub WeightDownHost {
       (($fmyCurID)=$sqls->fetchrow_array);
       &syslog("MGR: CurID: $fmyCurID",2);
       if ($fmyCurID) {
-
-      
-      
        if ($fsqlaEnabled eq "1") {
        	#print "Next CurID: $fmyCurID <BR>";
         $fweightdownstate=undef;
@@ -1246,34 +1375,67 @@ sub WeightDownHost {
 sub TurnOffHost {
 	#Independant service function - Nov06
   my $fdbh = DBI->connect("DBI:mysql:$database:$servername:3306",$sqluser,$sqlpassword)  or &sqldead;
-  
-
   my ($fsqlInvID,$fsqlInvWeight,$fsqlNodeID,$fsqlLink,$fsqlIPort,$fsqlactive,$fsqlmethod,$fsqlweight,$fsqlPoolID);
   my ($fsqlAlias,$fsqlIP,$fsqlpoolReource,$fweightdownstate,$fsqlinv,$fsqlinvTID,$fmyCHost,$fmxstring,$fResID);
   my ($fNodeService,$fNodeVip,$fmyIP,$fmyHost,$fmstring,$sqlc,$fauto_ok,$fsqlpool,$fvar,$fvalue,$simulate);
+  my ($fsqlIP6,$fNodeVip6,$fmstring6); #2.0.5
   $simulate="0";
 	$fResID=$_[0];
-  my $fsqla = $fdbh->prepare("SELECT alias,realip FROM tblResources where resID = '" . $fResID . "';" ); 
+  my $fsqla = $fdbh->prepare("SELECT alias,realip,realip6 FROM tblResources where resID = '" . $fResID . "';" ); 
   $fsqla->execute ; #Get Inventory and ID's
-  (($fsqlAlias,$fsqlIP)=$fsqla->fetchrow_array);
+  (($fsqlAlias,$fsqlIP,$fsqlIP6)=$fsqla->fetchrow_array);
   $fmyIP=$fsqlIP;
   $fmyHost=$fsqlAlias;
   my $sqli = $fdbh->prepare("SELECT invID,weight,nodeID,link,port,active,method,weight,automovepoolid FROM tblNodesInventory where resID = '" . $fResID . "';" ); 
   $sqli->execute ; #Get Inventory and ID's
   while (($fsqlInvID,$fsqlInvWeight,$fsqlNodeID,$fsqlLink,$fsqlIPort,$fsqlactive,$fsqlmethod,$fsqlweight,$fsqlPoolID)=$sqli->fetchrow_array) {
-   my $sqln = $fdbh->prepare("SELECT service,vip FROM tblNodes where nodeid = '" . $fsqlNodeID . "';" ); 
+   my $sqln = $fdbh->prepare("SELECT service,vip,vip6 FROM tblNodes where nodeid = '" . $fsqlNodeID . "';" ); 
    $sqln->execute ; 
-   ($fNodeService,$fNodeVip)=$sqln->fetchrow_array ;
+   ($fNodeService,$fNodeVip,$fNodeVip6)=$sqln->fetchrow_array ;
    if ($fNodeService !~ /fwm/i) {
-    $fmstring = "$lvscmd -d -t $fNodeVip -r $fsqlIP:$fsqlIPort";
+    
+    if ($fNodeVip) {  #2.0.5
+     $fmstring = "$lvscmd -d -t $fNodeVip -r $fsqlIP:$fsqlIPort";
+    } 
+    
+    if ($fNodeVip6) {  #2.0.5
+     if ($fNodeVip6 =~/(.*):(\d+)$/) {  #
+      $fmstring6 = "$lvscmd -d -t [$1]:$2 -r [$fsqlIP6]:$fsqlIPort";
+     } 
+    } 
+    
+    
+    
    } else {
-    $fmstring = "$lvscmd -d -f $fNodeVip -r $fsqlIP";	
+   	if ($fNodeVip) {  #2.0.5
+     $fmstring = "$lvscmd -d -f $fNodeVip -r $fsqlIP:$fsqlIPort";	
+    }
+    
+    if ($fNodeVip6) {  #2.0.5 - 
+     $fmstring6 = "$lvscmd -d -f $fNodeVip6 -6 -r [$fsqlIP6]:$fsqlIPort";
+    } 
    }	
-   &syslog ("MGR: Apply -$fsqlPoolID: $fmstring",1);
-   if ($simulate eq "0") {
-    `$fmstring`;
+   
+
+
+   
+   if ($fNodeVip) {  #2.0.5
+   	&syslog ("MGR: Apply v4 -$fsqlPoolID: $fmstring",1);
+   	&lvslog(11,"Turn off v4 service by: $fmstring","system");
+    if ($simulate eq "0") {
+     `$fmstring`;
+    } 
    } 
-   &lvslog(11,"Turn off service by: $fmstring","system");
+
+
+   if ($fNodeVip6) {  #2.0.5
+   	&syslog ("MGR: Apply v6 -$fsqlPoolID: $fmstring6",1);
+   	&lvslog(11,"Turn off v6 service by: $fmstring6","system");
+    if ($simulate eq "0") {
+     `$fmstring6`;
+    } 
+   } 
+   
    #print "SQL:: UPDATE tblNodesInventory SET enabled = '0',maintenance='1' where invID = $fsqlInvID\n";
    &syslog ("MGR: SQL:: UPDATE tblNodesInventory SET enabled='0',maintenance='1' where invID = $fsqlInvID",2);
    if ($simulate eq "0") {
@@ -1369,33 +1531,66 @@ sub TurnOnHost {
 	#Independant service function - Nov06
   my $fdbh = DBI->connect("DBI:mysql:$database:$servername:3306",$sqluser,$sqlpassword)  or &sqldead;
   my ($fResID,$simulate);
+  my ($fsqlIP6,$fNodeVip6,$fmstring6); #2.0.5
   $simulate="0";
 	$fResID=$_[0];
   my ($fmyIP,$sqli,$fsqlAlias,$fsqlIP,$sqln,$fmstring,$sqlc);
   my ($fsqlInvID,$fsqlInvWeight,$fsqlNodeID,$fsqlLink,$fsqlIPort,$fsqlactive,$fsqlmethod,$fsqlweight,$fNodeService,$fNodeVip);
-  $fsqlAlias = $fdbh->prepare("SELECT alias,realip FROM tblResources where resID = '" . $fResID . "';" ); 
+  $fsqlAlias = $fdbh->prepare("SELECT alias,realip,realip6 FROM tblResources where resID = '" . $fResID . "';" ); 
   $fsqlAlias->execute ; #Get Inventory and ID's
-  (($fsqlAlias,$fsqlIP)=$fsqlAlias->fetchrow_array);
+  (($fsqlAlias,$fsqlIP,$fsqlIP6)=$fsqlAlias->fetchrow_array);
   $fmyIP=$fsqlIP;
   $sqli = $fdbh->prepare("SELECT invID,weight,nodeID,link,port,active,method,weight FROM tblNodesInventory where resID = '" . $fResID . "';" ); 
   $sqli->execute ; #Get Inventory and ID's
   while (($fsqlInvID,$fsqlInvWeight,$fsqlNodeID,$fsqlLink,$fsqlIPort,$fsqlactive,$fsqlmethod,$fsqlweight)=$sqli->fetchrow_array) {
-   $sqln = $fdbh->prepare("SELECT service,vip FROM tblNodes where nodeid = '" . $fsqlNodeID . "';" ); 
+   $sqln = $fdbh->prepare("SELECT service,vip,vip6 FROM tblNodes where nodeid = '" . $fsqlNodeID . "';" ); 
    $sqln->execute ; 
-   ($fNodeService,$fNodeVip)=$sqln->fetchrow_array ;
+   ($fNodeService,$fNodeVip,$fNodeVip6)=$sqln->fetchrow_array ;
    if ($fNodeService !~ /fwm/i) {
-    $fmstring = "$lvscmd -a -t $fNodeVip -r $fsqlIP:$fsqlIPort -$fsqlmethod -w $fsqlweight";
+    if ($fNodeVip) {  #2.0.5
+     $fmstring = "$lvscmd -a -t $fNodeVip -r $fsqlIP:$fsqlIPort -$fsqlmethod -w $fsqlweight";
+    } 
+
+    if ($fNodeVip6) {  #2.0.5
+     if ($fNodeVip6 =~/(.*):(\d+)$/) {  
+      $fmstring6 = "$lvscmd -a -t [$1]:$2 -r [$fsqlIP6]:$fsqlIPort -$fsqlmethod -w $fsqlweight";
+     }
+    }
+    
+    
    } else {
-    $fmstring = "$lvscmd -a -f $fNodeVip -r $fsqlIP -$fsqlmethod -w $fsqlweight";	
+    if ($fNodeVip) {  #2.0.5
+     $fmstring = "$lvscmd -a -f $fNodeVip -r $fsqlIP -$fsqlmethod -w $fsqlweight";
+    }
+
+    if ($fNodeVip6) {  #2.0.5
+      $fmstring6 = "$lvscmd -a -f $fNodeVip6 -6 -r [$fsqlIP6]:$fsqlIPort  -w $fsqlweight";
+    }
+    	
+     	
    }	
    if ($fsqlactive eq "0") {
     &syslog("MGR: WARNING: Host $fsqlIP:$fsqlIPort is in down state.",2);
    }
-   if ($simulate eq "0") {
-   &syslog("MGR: Apply: $fmstring",2);
-   `$fmstring`;
-   } 
-   &lvslog(11,"Turn on service by: $fmstring","system");
+
+   if ($fNodeVip) {  #2.0.5
+    &syslog("MGR: Apply v4: $fmstring",2);
+    &lvslog(11,"Turn on service v4 by: $fmstring","system");
+    if ($simulate eq "0") {
+     `$fmstring`;
+    } 
+   }
+   
+   if ($fNodeVip6) {  #2.0.5
+    &syslog("MGR: Apply v6: $fmstring6",2);
+    &lvslog(11,"Turn on service v6 by: $fmstring6","system");
+    if ($simulate eq "0") {
+     `$fmstring6`;
+    } 
+   }
+   
+   
+
    if ($simulate eq "0") {
     $sqlc = $fdbh->prepare("UPDATE tblNodesInventory SET enabled = '1',maintenance='0',active='1' where invID ='" . $fsqlInvID . "';" );
     $sqlc->execute;
