@@ -1,13 +1,19 @@
--- myLVS data to be used as template for new installations.
--- Note: Make sure that you have a backup of your existing database if exist.
--- See the following URL for more details: http://mylvs.com
-
-
--- MySQL dump 10.13  Distrib 5.5.43, for debian-linux-gnu (x86_64)
+-- MySQL dump 10.16  Distrib 10.1.23-MariaDB, for debian-linux-gnu (x86_64)
 --
 -- Host: localhost    Database: mylvs
 -- ------------------------------------------------------
--- Server version	5.5.43-0+deb8u1
+-- Server version	10.1.23-MariaDB-9+deb9u1
+
+/*!40101 SET @OLD_CHARACTER_SET_CLIENT=@@CHARACTER_SET_CLIENT */;
+/*!40101 SET @OLD_CHARACTER_SET_RESULTS=@@CHARACTER_SET_RESULTS */;
+/*!40101 SET @OLD_COLLATION_CONNECTION=@@COLLATION_CONNECTION */;
+/*!40101 SET NAMES utf8mb4 */;
+/*!40103 SET @OLD_TIME_ZONE=@@TIME_ZONE */;
+/*!40103 SET TIME_ZONE='+00:00' */;
+/*!40014 SET @OLD_UNIQUE_CHECKS=@@UNIQUE_CHECKS, UNIQUE_CHECKS=0 */;
+/*!40014 SET @OLD_FOREIGN_KEY_CHECKS=@@FOREIGN_KEY_CHECKS, FOREIGN_KEY_CHECKS=0 */;
+/*!40101 SET @OLD_SQL_MODE=@@SQL_MODE, SQL_MODE='NO_AUTO_VALUE_ON_ZERO' */;
+/*!40111 SET @OLD_SQL_NOTES=@@SQL_NOTES, SQL_NOTES=0 */;
 
 
 --
@@ -25,6 +31,10 @@ USE `mylvs`;
 
 GRANT ALL PRIVILEGES ON mylvs.* TO mylvsuser@localhost IDENTIFIED BY 'demo';
 
+--
+-- Table structure for table `tblCommands`
+-- 
+
 --
 -- Table structure for table `tblCommands`
 --
@@ -179,9 +189,18 @@ CREATE TABLE `tblLogging` (
   `message` varchar(255) DEFAULT NULL,
   `epoche` int(10) unsigned NOT NULL DEFAULT '0',
   PRIMARY KEY (`logID`)
-) ENGINE=MyISAM AUTO_INCREMENT=338 DEFAULT CHARSET=utf8;
+) ENGINE=MyISAM AUTO_INCREMENT=343 DEFAULT CHARSET=utf8;
 /*!40101 SET character_set_client = @saved_cs_client */;
 
+--
+-- Dumping data for table `tblLogging`
+--
+
+LOCK TABLES `tblLogging` WRITE;
+/*!40000 ALTER TABLE `tblLogging` DISABLE KEYS */;
+INSERT INTO `tblLogging` VALUES (338,'demo',2,25,7,2017,14,47,47,'Delete Backup: /var/www/mylvs/backup//20150822-151653.sql',1501008467),(339,'demo',2,25,7,2017,14,47,51,'Delete Backup: /var/www/mylvs/backup//20150822-161718.sql',1501008471),(340,'demo',2,25,7,2017,14,48,6,'Apply Comment: First setup',1501008486),(341,'demo',2,25,7,2017,14,48,6,'Apply Backup Comment:  /usr/bin/sudo /var/www/mylvs/scripts/mkbackup.sh mylvs mylvsuser pass /var/www/mylvs/backup/ 20170725-144759.sql',1501008486),(342,'demo',2,25,7,2017,14,48,16,'Delete Backup: /var/www/mylvs/backup//20150827-135828.sql',1501008496);
+/*!40000 ALTER TABLE `tblLogging` ENABLE KEYS */;
+UNLOCK TABLES;
 
 --
 -- Table structure for table `tblMaintenance`
@@ -335,6 +354,7 @@ CREATE TABLE `tblNodes` (
   `scheduler` varchar(8) DEFAULT NULL,
   `service` char(3) DEFAULT NULL,
   `vip` varchar(20) DEFAULT NULL,
+  `vip6` varchar(51) DEFAULT NULL,
   `persistent` int(8) DEFAULT NULL,
   `monitor` int(1) DEFAULT NULL,
   PRIMARY KEY (`nodeID`)
@@ -347,7 +367,7 @@ CREATE TABLE `tblNodes` (
 
 LOCK TABLES `tblNodes` WRITE;
 /*!40000 ALTER TABLE `tblNodes` DISABLE KEYS */;
-INSERT INTO `tblNodes` VALUES (1,1,'Demo-Node01','wlc','tcp','192.168.2.220:80',0,1);
+INSERT INTO `tblNodes` VALUES (1,1,'Demo-Node01','wlc','tcp','192.168.2.220:80','',0,1);
 /*!40000 ALTER TABLE `tblNodes` ENABLE KEYS */;
 UNLOCK TABLES;
 
@@ -503,6 +523,7 @@ CREATE TABLE `tblResources` (
   `enabled` int(1) DEFAULT NULL,
   `alias` varchar(128) DEFAULT NULL,
   `realip` varchar(15) DEFAULT NULL,
+  `realip6` varchar(45) DEFAULT NULL,
   `cmd_reboot_id` int(8) DEFAULT NULL,
   `mrtg_link` varchar(128) DEFAULT NULL,
   `visible` int(1) unsigned DEFAULT NULL,
@@ -519,7 +540,7 @@ CREATE TABLE `tblResources` (
 
 LOCK TABLES `tblResources` WRITE;
 /*!40000 ALTER TABLE `tblResources` DISABLE KEYS */;
-INSERT INTO `tblResources` VALUES (1,1,'WEB-01','192.168.2.221',3,'-',1,'-',0,0),(2,1,'WEB-02','192.168.2.222',3,'-',1,'-',0,0);
+INSERT INTO `tblResources` VALUES (1,1,'WEB-01','192.168.2.221','',3,'-',1,'-',0,0),(2,1,'WEB-02','192.168.2.222',NULL,3,'-',1,'-',0,0);
 /*!40000 ALTER TABLE `tblResources` ENABLE KEYS */;
 UNLOCK TABLES;
 
@@ -617,4 +638,4 @@ UNLOCK TABLES;
 /*!40101 SET COLLATION_CONNECTION=@OLD_COLLATION_CONNECTION */;
 /*!40111 SET SQL_NOTES=@OLD_SQL_NOTES */;
 
--- Dump completed on 2015-08-27 13:58:42
+-- Dump completed on 2017-07-25 15:23:55
