@@ -1,3 +1,6 @@
+
+#1.0.1 - Fix after update to Debian Buster - 31.Jul.2019
+
 use strict;
 use POSIX;
 use XML::Simple;      #=>Read my XML Config
@@ -22,8 +25,6 @@ use DBI;              ##=>used for mySQL
 #     407 ip renew is not set on: $TmpLVSHost
 #     408 Function not supported
 
-
-
 #     500: Access denied
 #     501: Update failed, contact IT-Admin
 
@@ -41,7 +42,7 @@ my ($LVSServer,$LVSUser,$LVSPass,$UnlimitedAccess,$LVSDB,%AccessHost,$tAccess,$s
 
 
 
- 
+
 package lvs;
 
 # Based on the idea from:
@@ -51,6 +52,7 @@ package lvs;
 
 sub WHATISMYIP {                     
   use CGI ':standard';
+  &syslog("Request WHATISMYIP"); #1.0.1
   my $RemoteAddr=$ENV{REMOTE_ADDR};
   if ($RemoteAddr){
    return "200 $RemoteAddr";     
@@ -262,91 +264,122 @@ sub REQUESTWEIGHTDOWN {
  
  use DBI;
  use DBD::mysql;
-
-
+ my $dstr;
+ #/var/www/mylvs/ws/modules
+# open FH,">>/var/www/mylvs/ws/modules/deb.txt";
+# print FH "tst\n";
+# close FH;
+  &syslog("Request REQUESTWEIGHTDOWN"); #1.0.1
   &GetConfig;
+  &syslog("GetConfig OK"); #1.0.1
   if (&GetPermission){  #Access granted, go and proceed!!!
    my $dbh = DBI->connect("DBI:mysql:$LVSDB:$LVSServer:3306",$LVSUser,$LVSPass,{
-  	PrintError => 1, # warn() on errors
+    PrintError => 1, # warn() on errors
     RaiseError => 0, # don't die on error
     AutoCommit => 1, # commit executes
    });
 
    my $dbhn = DBI->connect("DBI:mysql:$LVSDB:$LVSServer:3306",$LVSUser,$LVSPass,{
-  	PrintError => 1, # warn() on errors
+    PrintError => 1, # warn() on errors
     RaiseError => 0, # don't die on error
     AutoCommit => 1, # commit executes
    });
   
-   my ($WARNTxt,$sql,$sqln);
+   my ($WARNTxt,$sql,$sqln,$sqlstr);
    #my ($class, $c) = @_;   #use $c for the passed var
    #Check tblMaintenace first
-   $sql = $dbh->prepare("SELECT enabled,requestUP,requestDOWN,updatepending,DSLMaintenance,response,message FROM tblMaintenance where ip = '".$TmpLVSHost."' and enabled=1;" );  
+   $sqlstr="SELECT enabled,requestUP,requestDOWN,updatepending,DSLMaintenance,response,message FROM tblMaintenance where ip = '".$TmpLVSHost."' and enabled=1;"; 
+   $sql = $dbh->prepare($sqlstr );   
    $sql->execute;
+   &syslog("Send $sqlstr"); #1.0.1
    (my ($SQLenabled,$SQLrequestUP,$SQLrequestDOWN,$SQLupdatepending,$SQLDSLMaintenance,$SQLresponse,$SQLmessage)=$sql->fetchrow_array);
+    &syslog("Received: $SQLenabled,$SQLrequestUP,$SQLrequestDOWN,$SQLupdatepending,$SQLDSLMaintenance,$SQLresponse,$SQLmessage"); #1.0.1
    if (($SQLrequestUP eq 1) or ($SQLrequestDOWN eq 1) or ($SQLupdatepending eq 1) or ($SQLDSLMaintenance eq 1) or ($SQLenabled ne 1) or ($SQLresponse =~ /401/)){
-   	$dbh->disconnect;
-   	$dbhn->disconnect;
+   	#$dbh->disconnect;  #1.0.1
+   	#$dbhn->disconnect; #1.0.1
   	if ($SQLenabled ne 1){
+     	        $dbh->disconnect; #1.0.1
+        	$dbhn->disconnect;#1.0.1 
   		return "500: Host is disabled on $TmpLVSHost";
   	}
   	if ($SQLrequestUP){
+     	        $dbh->disconnect; #1.0.1
+        	$dbhn->disconnect; #1.0.1
   		return "500: REQUESTWEIGHTUP is already set on $TmpLVSHost";
   	}
   	if ($SQLrequestDOWN){
+     	        $dbh->disconnect; #1.0.1
+        	$dbhn->disconnect;#1.0.1 
   		return "500: REQUESTWEIGHTDOWN is already set on $TmpLVSHost";
   	}
   	if ($SQLupdatepending){
+     	        $dbh->disconnect; #1.0.1
+        	$dbhn->disconnect;#1.0.1
   		return "500: REQUESTWEIGHTDOWN (Updatepending) is already set on $TmpLVSHost";
   	}
   	if ($SQLDSLMaintenance){
+     	        $dbh->disconnect; #1.0.1
+        	$dbhn->disconnect;#1.0.1
   		return "301: DSL Maintenance pending, please come back again later - on $TmpLVSHost";
   	}
   	
   	if ($SQLresponse =~ /401/){
+     	        $dbh->disconnect; #1.0.1
+        	$dbhn->disconnect;#1.0.1
   		return "$SQLresponse: $SQLmessage - on $TmpLVSHost";
   	}
    }         #   if (($SQLrequestUP eq 1) or ($SQLrequestDOWN eq 1) or ($SQLupdatepending eq 1) or ($SQLDSLMaintenance eq 1) or ($SQLenabled ne 1))
 
 
-
+   
    
    my $xstr = "SELECT tblNodesInventory.invid,tblResources.enabled,tblResources.alias FROM $LVSDB.tblNodesInventory,$LVSDB.tblResources,$LVSDB.tblMaintenance,$LVSDB.tblNodes where tblResources.realip = '".$TmpLVSHost."' and tblResources.resID = tblNodesInventory.resID and tblNodesInventory.nodeid = tblNodes.nodeid group by tblNodesInventory.invid;";
-
-
+   $dstr=$xstr;
+   &syslog("Send $xstr"); #1.0.1
    $sql = $dbh->prepare($xstr);   
    $sql->execute;
    
    while(my($SQLinvID,$SQLResourcesEnabled,$SQLResourcesAlias)=$sql->fetchrow_array) {
     
+    &syslog("Receive $SQLinvID,$SQLResourcesEnabled,$SQLResourcesAlias"); #1.0.1
     
     if ($SQLResourcesEnabled ne 1){
-    	$dbh->disconnect;
+    	$dbh->disconnect; 
     	$dbhn->disconnect;
     	return "500: Host is entirely disabled ($TmpLVSHost/$SQLResourcesAlias)";  
     }
     
     #Follow up, we try hard to check all services
+    &syslog("Send3 SELECT invID,enabled,active,maintenance,weightdown,link FROM $LVSDB.tblNodesInventory where invID = $SQLinvID;");
     $sqln = $dbhn->prepare("SELECT invID,enabled,active,maintenance,weightdown,link FROM $LVSDB.tblNodesInventory where invID = $SQLinvID;" );  
     $sqln->execute;
     while ((my ($SQLchk,$SQLenabled,$SQLactive,$SQLmaintenance,$SQLweightdown,$SQLlink)=$sqln->fetchrow_array)) {   
-     $dbh->disconnect;
-     $dbhn->disconnect;
+     &syslog("Receive3: $SQLchk,$SQLenabled,$SQLactive,$SQLmaintenance,$SQLweightdown,$SQLlink");
+     #$dbh->disconnect; #1.0.1
+     #$dbhn->disconnect;#1.0.1
 
      if ($SQLenabled ne 1) {
+        $dbh->disconnect; #1.0.1
+        $dbhn->disconnect;#1.0.1
     	return "500: Service is disabled (Link:$SQLlink/INV-ID:$SQLinvID)";  
      }
 
      if ($SQLmaintenance eq 1) {
+        $dbh->disconnect; #1.0.1
+        $dbhn->disconnect;#1.0.1
     	return "500: Service has the maintenance flag set (Link:$SQLlink/INV-ID:$SQLinvID)";  
      }
 
      if ($SQLactive ne 1) {
+        $dbh->disconnect; #1.0.1
+        $dbhn->disconnect;#1.0.1
     	return "500: Service is set to be INACTIVE (Link:$SQLlink/INV-ID:$SQLinvID-$SQLactive)";  
      }
 
      if ($SQLweightdown eq 1) {
-      return "500: Service has weightdown set set (Link:$SQLlink/INV-ID:$SQLinvID)";  
+        $dbh->disconnect; #1.0.1
+        $dbhn->disconnect;#1.0.1
+        return "500: Service has weightdown set set (Link:$SQLlink/INV-ID:$SQLinvID)";  
      }
      
     }   #While 
@@ -355,6 +388,8 @@ sub REQUESTWEIGHTDOWN {
        	
    #No Maintenance set and nothing else disabled so go ahead!
    my $sql = ("UPDATE $LVSDB.tblMaintenance set requestDOWN='1',response='0',message='0' ,WeightDownTime='" . $wdTime . "',TurnOffTime='" . $toTime . "' where ip = '".$TmpLVSHost."';");   
+
+   &syslog("Send Final $sql");  #1.0.1
    #my $sql = ("UPDATE $LVSDB.tblMaintenance set requestDOWN='1',WeightDownTime='" . $wdTime . "',TurnOffTime='" . $toTime . "' where ip = '".$TmpLVSHost."';");   
    my $sqlret  = $dbh->do($sql);
    if ($sqlret){
@@ -363,6 +398,7 @@ sub REQUESTWEIGHTDOWN {
     return "501: Update failed, contact IT-Admin";
     #return "UPDATE tblMaintenance set requestDOWN='1',response='0',message='0' ,WeightDownTime='" . $wdTime . "',TurnOffTime='" . $toTime . "' where ip = '".$c."';";
    }         #if ($sqlret)
+
   } else {
    return "500: Access denied - No permission to send from $TmpLVSHost";
   } #Get Permisssion
@@ -649,4 +685,13 @@ sub GetPermission {
 }
 
 
+sub syslog {
+#    use this for debugging
+#    use POSIX;
+#    open FH,">>/var/www/mylvs/ws/modules/deb.txt";
+#    my $tlxdate = strftime("%Y%m%d %H:%M:%S", localtime(time));
+#    print FH "$tlxdate $_[0]\n";
+#    close FH;
+}	
+
 1;
\ No newline at end of file
