@@ -10,14 +10,16 @@ use strict;
 use CGI::Carp qw(fatalsToBrowser);
 use DBI;
 use POSIX;
+use Sys::Hostname;
+
 #Too many problems for now using snmp ... MK 2015
 #use Net::SNMP;  #Used for live http users
 
 
 #####################################################################
 my $scriptname = 'mylvs.pl';
-my $version="2.0.3";
-
+my $version="2.0.5";
+my $host = hostname;
 #Get Apache Environs
 my $tparam=$ENV{QUERY_STRING};
 my $curuser=$ENV{REMOTE_USER};
@@ -58,6 +60,8 @@ my (%RSAddress,%RSPort,%RSRoute,%RSWeight,%RSActive,%RSInActive,$sqlsnmpkey,$sql
 my ($sqlInvID,$sqlInvEnabled,$sqlInvWeight,$sqlInvActive,$sqlSNMP,$mrtglink,%ResMrtgID,$sqlNodeID,$curnodeid,$tmpcurnodeid,$GlobalTxt,$mid,$uppen,$dslpen);
 my (%ResAlias,%ResIP,%ResKEY,%ResEnabled,%ResWeight,%ResInvID,%ResMonStat,%ResMonLastCheck,$tmonstat,$img_monstat,$img_monstat_title,%ResServiceTot,%ResServices,$txt_curservice,$txt_curactive,%ResActiveSrvTot,%ResActiveConTot,%ResInActiveConTot,$tmpActive,$tmpInActive,%ResWeightTot,%ResWeightCur,$txt_curweight,$tmpstr4,$link_weight,$img_weight,$img_weight_title,$link_mgr,$img_enable,$img_enable_title,$img_enabled,$img_enabled_text);
 my (%ResVisible); #2.0.3
+my (%ResIP6,$hdeb,%NodeIDv4,%NodeIDv6); #2.0.5
+my $prtDeb=undef;  #2.0.5 - set to undef for non debug
 my $date=localtime(); 
 $dbh = DBI->connect("DBI:mysql:$database:$servername:3306",$sqluser,$sqlpassword); 
 &GetLVSOutput;
@@ -83,11 +87,12 @@ print jscript;
 print &HTMLStartOutsideTable;
 print &HTMLStartInsideTable;
 
- my $sqlres = $dbh->prepare("SELECT resID,alias,realip,enabled,mrtg_link,visible FROM tblResources" ); 
+ my $sqlres = $dbh->prepare("SELECT resID,alias,realip,enabled,mrtg_link,visible,realip6 FROM tblResources" ); 
  $sqlres->execute ; #Get Resources
- while (my($sqlResID,$sqlResAlias,$sqlResIP,$sqlResEnabled,$mrtglink,$sqlvisible)=$sqlres->fetchrow_array) {
+ while (my($sqlResID,$sqlResAlias,$sqlResIP,$sqlResEnabled,$mrtglink,$sqlvisible,$sqlResIP6)=$sqlres->fetchrow_array) {
   $ResAlias{$sqlResID}=$sqlResAlias;
   $ResIP{$sqlResID}=$sqlResIP;
+  $ResIP6{$sqlResID}=$sqlResIP6;
   $ResEnabled{$sqlResID}=$sqlResEnabled;
   $ResKEY{$sqlResAlias}=$sqlResID;
   $ResMrtgID{$sqlResID}=$mrtglink;
@@ -101,6 +106,12 @@ print &HTMLStartInsideTable;
    #print "=>$sqlInvID\n";
    $ResInvID{$sqlResID}{$sqlInvID}=$sqlInvID;
    $ResWeight{$sqlResID}+=$sqlInvWeight;
+   
+   if (($ResIP6{$sqlResID})) { #2.0.5 ! Let v6 shown up in the weight stats
+    $ResWeight{$sqlResID}+=$sqlInvWeight;
+    #$hdeb.="DEBW $ResIP6{$sqlResID} -- $ResIP{$sqlResID} -- $ResWeight{$sqlResID}<br>";
+   }
+   
    if ($sqlSNMP ne 0) {
     $ResSNMPID{$sqlResID}{$sqlSNMP}=$sqlSNMP;
     my $sqlsnmp = $dbh->prepare("SELECT snmpkey,snmppass,snmpport,snmptimeout FROM tblSNMP where snmpID = '" . $sqlSNMP . "';" ); 
@@ -115,6 +126,14 @@ print &HTMLStartInsideTable;
    if (($sqlInvEnabled eq 1) and ($sqlInvActive eq 1)) {
     $ResServiceTot{$sqlResID}++;
     $ResServices{$sqlResID}++;
+
+    if (($ResIP6{$sqlResID}) and ($ResIP{$sqlResID})) { #2.0.5 ! Let v6 shown up in the weight stats
+     $ResServiceTot{$sqlResID}++;
+     $ResServices{$sqlResID}++;
+    }
+    
+    
+    
    } else {
    	$ResServiceTot{$sqlResID}++;
    }
@@ -161,12 +180,32 @@ print &HTMLStartInsideTable;
    #######  Get Live Services and Weigth vs Enabled Services  ########
    for my $pntbase (sort keys %NodeID){  #Enum LVS Inventory
     for my $pntval (sort keys %{$RSAddress{$pntbase}} ){
-     if ($RSAddress{$pntbase}{$pntval} eq $ResIP{$ResKEY{$resources}}){
+    	
+     #$hdeb.="$RSAddress{$pntbase}{$pntval}<br>";
+    	
+    	
+     #if ( ($RSAddress{$pntbase}{$pntval} eq $ResIP{$ResKEY{$resources}})  or ($RSAddress{$pntbase}{$pntval} eq $ResIP6{$ResKEY{$resources}}) ) {
+     if ( ($RSAddress{$pntbase}{$pntval} eq $ResIP{$ResKEY{$resources}})  	 ) {
       $ResActiveSrvTot{$ResKEY{$resources}}++;
-       $ResActiveConTot{$ResKEY{$resources}}+=$RSActive{$pntbase}{$pntval};
+      $ResActiveConTot{$ResKEY{$resources}}+=$RSActive{$pntbase}{$pntval};
       $ResInActiveConTot{$ResKEY{$resources}}+=$RSInActive{$pntbase}{$pntval};
       $ResWeightCur{$ResKEY{$resources}}+=$RSWeight{$pntbase}{$pntval};
-     } 
+      $hdeb.="V4====$RSAddress{$pntbase}{$pntval} --- $ResActiveSrvTot{$ResKEY{$resources}}<br>";
+      $NodeIDv4{$curmodeID}=1; #2.0.5 - Display Fix
+     }
+     
+
+     if ( ($RSAddress{$pntbase}{$pntval} eq $ResIP6{$ResKEY{$resources}})  	 ) {
+      #NodeIDv6{$curmodeID}=$curmodeID;
+      #if (!$NodeIDv4{$curmodeID}) {  #let them count ..!
+       $ResActiveSrvTot{$ResKEY{$resources}}++;  #2.0.5 Count v6 if v4 is not present
+       $ResWeightCur{$ResKEY{$resources}}+=$RSWeight{$pntbase}{$pntval}; #2.0.5 Count v6 if v4 is not present
+       $hdeb.="V6====$RSAddress{$pntbase}{$pntval} --- $ResActiveSrvTot{$ResKEY{$resources}} <br>";
+      #} 
+      $ResActiveConTot{$ResKEY{$resources}}+=$RSActive{$pntbase}{$pntval};
+      $ResInActiveConTot{$ResKEY{$resources}}+=$RSInActive{$pntbase}{$pntval};
+      
+     }
     }
    }
   
@@ -386,72 +425,145 @@ sub GetLVSOutput {
  	chomp $myret;
   #Mask: "TCP  10.0.1.18:7000 wrr persistent 3600"
   #Mask: "UDP  10.0.1.22:7000 wrr persistent 3600"
- 	#print "XXXXX  DEB1 => $myret\n";
- 	if ($myret =~ /^(\w{3})\s*(\d*).(\d*).(\d*).(\d*):(\d*)\s*(\w*)\s*(\w*)\s*(\d*)/) {
- 	 #print "XXXXX  DEB2 => $myret\n";
- 	 $curmodeID++;
- 	 $curmodePropertyID=0;
-   $NodeID{$curmodeID}=$curmodeID;
-   $NodeProto{$curmodeID}="$1";
- 	 $NodeAddress{$curmodeID}="$2.$3.$4.$5";
- 	 $NodePort{$curmodeID}="$6";
-   $NodeScheduler{$curmodeID}="$7";		
-   $NodePersistent{$curmodeID}="$8";		
-   $NodePersistentTimeout{$curmodeID}="$9";		
- 	} else {
- 	 if ($myret =~ /^(\w{3})\s*(\d*).(\d*).(\d*).(\d*):(\d*)\s*(\w*)/) {
- 	 	#Mask: "TCP  10.0.1.18:7000 wrr"
-    #Mask: "UDP  10.0.1.22:7000 wrr"
- 	 	#print "XXXXX  DEB2a => $myret\n";
+ 	$hdeb.="XXXXX  DEB1 => $myret<br>";
+ 	if ($myret!~/\s*\[/ ) {  #v6?  #2.0.5
+ 	 if ($myret =~ /^(\w{3})\s*(\d*).(\d*).(\d*).(\d*):(\d*)\s*(\w*)\s*(\w*)\s*(\d*)/) {
+ 	  #print "XXXXX  DEB2 => $myret\n";
  	  $curmodeID++;
  	  $curmodePropertyID=0;
     $NodeID{$curmodeID}=$curmodeID;
+    $NodeIDv4{$curmodeID}=$curmodeID;
     $NodeProto{$curmodeID}="$1";
  	  $NodeAddress{$curmodeID}="$2.$3.$4.$5";
  	  $NodePort{$curmodeID}="$6";
     $NodeScheduler{$curmodeID}="$7";		
-    $NodePersistent{$curmodeID}="";		
-    $NodePersistentTimeout{$curmodeID}="";		
+    $NodePersistent{$curmodeID}="$8";		
+    $NodePersistentTimeout{$curmodeID}="$9";		
  	 } else {
- 	  if ($myret =~ /^FWM\s*(\d*)\s*(\w*)\s*(\w*)\s*(\d*)/) {
- 	 	 #Mask: "FWM  1 wlc persistent 3600"
- 	 	 #print "XXXXX  DEB3 => $myret\n";
- 		 $curmodeID++;
- 		 $curmodePropertyID=0;
- 		 $NodeID{$curmodeID}=$curmodeID;
- 		 $NodeProto{$curmodeID}="FWM";
- 		 $NodeAddress{$curmodeID}="$1";
- 		 $NodePort{$curmodeID}="0";
-     $NodeScheduler{$curmodeID}="$2";		
-     $NodePersistent{$curmodeID}="$3";		
-     $NodePersistentTimeout{$curmodeID}="$4";		
+ 	  if ($myret =~ /^(\w{3})\s*(\d*).(\d*).(\d*).(\d*):(\d*)\s*(\w*)/) {
+ 	   #Mask: "TCP  10.0.1.18:7000 wrr"
+     #Mask: "UDP  10.0.1.22:7000 wrr"
+ 	   #print "XYXYXY  DEB2a => $myret\n";
+ 	   $curmodeID++;
+ 	   $curmodePropertyID=0;
+     $NodeID{$curmodeID}=$curmodeID;
+     $NodeIDv4{$curmodeID}=$curmodeID;
+     $NodeProto{$curmodeID}="$1";
+ 	   $NodeAddress{$curmodeID}="$2.$3.$4.$5";
+ 	   $NodePort{$curmodeID}="$6";
+     $NodeScheduler{$curmodeID}="$7";		
+     $NodePersistent{$curmodeID}="";		
+     $NodePersistentTimeout{$curmodeID}="";		
  	  } else {
- 	   if ($myret =~ /^FWM\s*(\d*)\s*(\w*)/) {
- 	    #Mask: "FWM  1 wlc "
- 	 	  #print "XXXXX  DEB3a => $myret\n";
- 		  $curmodeID++;
- 		  $curmodePropertyID=0;
- 		  $NodeID{$curmodeID}=$curmodeID;
- 		  $NodeProto{$curmodeID}="FWM";
- 		  $NodeAddress{$curmodeID}="$1";
- 		  $NodePort{$curmodeID}="0";
+ 	   if ($myret =~ /^FWM\s*(\d*)\s*(\w*)\s*(\w*)\s*(\d*)/) {
+ 	  	 #Mask: "FWM  1 wlc persistent 3600"
+ 	  	 #print "XXXXX  DEB3 => $myret\n";
+ 	 	 $curmodeID++;
+ 	 	 $curmodePropertyID=0;
+ 	 	 $NodeID{$curmodeID}=$curmodeID;
+ 	 	 $NodeIDv4{$curmodeID}=$curmodeID;
+ 	 	 $NodeProto{$curmodeID}="FWM";
+ 	 	 $NodeAddress{$curmodeID}="$1";
+ 	 	 $NodePort{$curmodeID}="0";
       $NodeScheduler{$curmodeID}="$2";		
       $NodePersistent{$curmodeID}="$3";		
       $NodePersistentTimeout{$curmodeID}="$4";		
+ 	   } else {
+ 	    if ($myret =~ /^FWM\s*(\d*)\s*(\w*)/) {
+ 	     #Mask: "FWM  1 wlc "
+ 	  	  #print "XXXXX  DEB3a => $myret\n";
+ 	 	  $curmodeID++;
+ 	 	  $curmodePropertyID=0;
+ 	 	  $NodeID{$curmodeID}=$curmodeID;
+ 	 	  $NodeIDv4{$curmodeID}=$curmodeID;
+ 	 	  $NodeProto{$curmodeID}="FWM";
+ 	 	  $NodeAddress{$curmodeID}="$1";
+ 	 	  $NodePort{$curmodeID}="0";
+       $NodeScheduler{$curmodeID}="$2";		
+       $NodePersistent{$curmodeID}="$3";		
+       $NodePersistentTimeout{$curmodeID}="$4";		
+ 	    }
  	   }
  	  }
+	 }	
+  }   else {  #2.0.5 V6
+   $hdeb.=" =oo> $myret<br>\n";
+ 	 if ($myret =~ /^(\w{3})\s*\[(.*)\]:(\d*)\s*(\w*)\s*(\w*)\s*(\d*)/) {
+ 	  $hdeb.=" yy=> $myret<br>\n";
+ 	  $curmodeID++;
+ 	  $curmodePropertyID=0;
+    $NodeID{$curmodeID}=$curmodeID;
+    $NodeIDv6{$curmodeID}=$curmodeID;
+    $NodeProto{$curmodeID}="$1";
+ 	  $NodeAddress{$curmodeID}="$2";
+ 	  $NodePort{$curmodeID}="$3";
+    $NodeScheduler{$curmodeID}="$4";		
+    $NodePersistent{$curmodeID}="$5";		
+    $NodePersistentTimeout{$curmodeID}="$6";		
+   } else {
+   	#TCP [fde2:8acd:e9d3::220]:7798 wlc
+ 	  if ($myret =~ /^(\w{3})\s*\[(.*)\]:(\d*)\s*(\w*)/) {
+ 	   $hdeb.=" =xxs> $myret<br>\n";	
+ 	  	#Mask: TCP [fde2:8acd:e9d3::220]:7798 wlc
+ 	   $curmodeID++;
+ 	   $curmodePropertyID=0;
+     $NodeID{$curmodeID}=$curmodeID;
+     $NodeIDv6{$curmodeID}=$curmodeID;
+     $NodeProto{$curmodeID}="$1";
+ 	   $NodeAddress{$curmodeID}="$2";
+ 	   $NodePort{$curmodeID}="$3";
+     $NodeScheduler{$curmodeID}="$4";		
+     $NodePersistent{$curmodeID}="";		
+     $NodePersistentTimeout{$curmodeID}="";		
  	 }
-	}	
+  }
+ } 	
+ 	
+ 	
+ 	
  	#Get Node Values
  	#Mask: " -> 10.0.1.240:0                 Route   100    0          0         "
- 	if ($myret =~ m/\s*->\s*(\d*).(\d*).(\d*).(\d*):(\d*)\s*(\w+)\s*(\d*)\s*(\d*)\s*(\d*)/) {
- 	 $curmodePropertyID++;
-   $RSAddress{$curmodeID}{$curmodePropertyID}="$1.$2.$3.$4";
-   $RSPort{$curmodeID}{$curmodePropertyID}="$5";
-   $RSRoute{$curmodeID}{$curmodePropertyID}="$6";
-   $RSWeight{$curmodeID}{$curmodePropertyID}="$7";
-   $RSActive{$curmodeID}{$curmodePropertyID}="$8";
-   $RSInActive{$curmodeID}{$curmodePropertyID}="$9";
+ 	if ($myret!~/\s*->\s*\[/ ) {  #v6?  #2.0.5
+ 	 if ($myret =~ m/\s*->\s*(\d*).(\d*).(\d*).(\d*):(\d*)\s*(\w+)\s*(\d*)\s*(\d*)\s*(\d*)/) {
+ 	  $curmodePropertyID++;
+    $RSAddress{$curmodeID}{$curmodePropertyID}="$1.$2.$3.$4";
+    $RSPort{$curmodeID}{$curmodePropertyID}="$5";
+    $RSRoute{$curmodeID}{$curmodePropertyID}="$6";
+    $RSWeight{$curmodeID}{$curmodePropertyID}="$7";
+    $RSActive{$curmodeID}{$curmodePropertyID}="$8";
+    $RSInActive{$curmodeID}{$curmodePropertyID}="$9";
+ 	 }
+ 	} else {  #v6
+ 		#if ($iptmp =~ /^\[(.*)\]:(\d+)$/) {
+ 		#$hdeb.="V6 --> $myret<br>\n";  #2.0.5
+ 		#  -> [fde2:8acd:e9d3::221]:7798   Route   100    0          0
+
+ 	  if ($myret =~ m/\s*->\s*\[(.*)\]:(\d*)\s*(\w+)\s*(\d*)\s*(\d*)\s*(\d*)/) {
+ 	   #$hdeb.="$1 $2 $3 -- Active=$5 InActive=$6<br>\n";  #2.0.5
+ 	   $curmodePropertyID++;
+     $RSAddress{$curmodeID}{$curmodePropertyID}="$1";
+     $RSPort{$curmodeID}{$curmodePropertyID}="$2";
+     $RSRoute{$curmodeID}{$curmodePropertyID}="$3";
+     $RSWeight{$curmodeID}{$curmodePropertyID}="$4";
+     $RSActive{$curmodeID}{$curmodePropertyID}="$5";
+     $RSInActive{$curmodeID}{$curmodePropertyID}="$6";
+   
+ 	 } else {
+ 	  if ($myret =~ /^FWM\s*(\d*)\s*(\w*)/) {  #=> experimental - not tested yet
+ 	   #Mask: "FWM  1 wlc "
+ 	   #print "XXXXX  DEB3a => $myret\n";
+ 	 	 #$curmodeID++;
+ 	 	 $curmodePropertyID=0;
+ 	 	 $NodeID{$curmodeID}=$curmodeID;
+ 	 	 $NodeIDv6{$curmodeID}=$curmodeID;
+ 	 	 $NodeProto{$curmodeID}="FWM";
+ 	 	 $NodeAddress{$curmodeID}="$1";
+ 	 	 $NodePort{$curmodeID}="0";
+     $NodeScheduler{$curmodeID}="$2";		
+     $NodePersistent{$curmodeID}="$3";		
+     $NodePersistentTimeout{$curmodeID}="$4";		
+ 	  }
+ 	 }
  	}
  }    #for my $myret (@lvsret)
 }     #sub GetLVSOutput
@@ -502,7 +614,7 @@ my $ret='
   </tr>
   <tr> 
     <td width="33"><img src="/images/ecke-top2-lft.gif" width="33" height="29"></td>
-    <td class="fontairname">Linux Virtual Server Manager<span class="fontnormal"> ( </span>'."User: $curuser from IP: $curip - Version: $version ".')</span></td>
+    <td class="fontairname">Linux Virtual Server Manager<span class="fontnormal"> ( </span>'."User: $curuser from IP: $curip - Version: $version - Hostname: $host".')</span></td>
     <td width="33"><img src="/images/ecke-top2-rt.gif" width="33" height="29"></td>
   </tr>
   <tr> 
@@ -674,7 +786,11 @@ my $ret='
 </body>
 </html>
 ';
-return $ret;		
+if ($prtDeb) {  #2.0.5
+ return $hdeb.$ret;		
+} else { 
+ return $ret;		
+} 
 }
 
 sub GetSnmpVal {
