@@ -4,6 +4,7 @@
 #LVS2 Node Edit / Add
 ######################
 
+#2.0.5 - Add v6
 
 #To Do: Check Vars: $netmask,$method, are they required incl. the fields ?
 
@@ -12,7 +13,7 @@ use DBI;
 use Time::localtime;
 #use Geo::IPfree;  
 
-my $version="2.0.1.2";
+my $version="2.0.5";
 ####################### CONFIGURATION #######################
 use XML::Simple;
 use Data::Dumper;
@@ -53,11 +54,9 @@ my ($seldr,$selma);
 my ($selrr,$selwr,$sellc,$selwlc,$sellblc,$sellblcr,$seldh,$selsh,$selsed,$selnq);
 #$selnq="selected";
 my ($NodeName,$NodeIP,$Protocol,$Schedule,$Port,$Persistance,$nodeid);
-my ($selmonval);
-my ($selen,$selenval);
-my $txtProto;
-my $tblText;
+my ($selmonval,$selen,$selenval,$txtProto,$tblText);
 my $EditMode=undef;
+my ($NodeIP6,$Port4,$Port6); #2.0.5
 #########################################################################################
 
 #BEGIN
@@ -68,10 +67,10 @@ if ($tparam =~ /^nodeid=/) {
 	$EditMode=1;
   if ($tparam =~ m/nodeid=(\d*)/){ 
    $nodeid=$1;
-   my $sql = $dbh->prepare("SELECT enabled,name,scheduler,service,vip,persistent,monitor FROM tblNodes where nodeid='".$1."' ;" );  	
+   my $sql = $dbh->prepare("SELECT enabled,name,scheduler,service,vip,persistent,monitor,vip6 FROM tblNodes where nodeid='".$1."' ;" );  	
    
    $sql->execute ; 
-   (my($enabled,$name,$scheduler,$service,$vip,$persistent,$monitor)=$sql->fetchrow_array);
+   (my($enabled,$name,$scheduler,$service,$vip,$persistent,$monitor,$vip6)=$sql->fetchrow_array);
    
    $txtProto="IP Address";
    
@@ -93,15 +92,42 @@ if ($tparam =~ /^nodeid=/) {
    
    if ($vip =~ m/(\d+).(\d+).(\d+).(\d+):(\d+)/){
     $NodeIP="$1.$2.$3.$4";
-    $Port="$5";
+    $Port4="$5";
    } else {
-    $NodeIP="";
-    $Port="-";
-    if ($vip =~ m/(\d+)/){
+   	if ($service =~ /fwm/i){
+     $NodeIP="";
+     $Port4="-";
+     $Port="-";
+     if ($vip =~ m/(\d+)/){
     	$NodeIP="$1";
-    }	
+     }	
+    } 
    }
   
+
+ 
+   if ($vip6 =~ m/^(.*):(\d+)$/) { #2.0.5
+    $NodeIP6="$1";
+    $Port6="$2";
+   } else {
+    if ($service =~ /fwm/i){
+     $NodeIP6="";
+     $Port6="-";
+     $Port="-";
+     if ($vip6 =~ m/(\d+)/){
+    	$NodeIP6="$1";
+     }	
+    } 
+   }
+   
+   if ($NodeIP =~ /\./){  #2.0.5 - Pick the port from either v4 or v6, depending which one is set
+    $Port=$Port4;
+   } else {
+    if ($NodeIP6 =~ /\:/){
+    	$Port=$Port6;
+    }	
+   }
+
    #Not build in yet
    #$Netmask=$netmask;
    
@@ -128,6 +154,9 @@ if ($tparam =~ /^nodeid=/) {
     #$selen=0;
    }
     
+    
+    
+    
    if ($scheduler =~ /rr/){$seldr="selected";}
    if ($scheduler =~ /wrr/){$selwr="selected";}
    if ($scheduler =~ /lc/){$sellc="selected";}
@@ -142,6 +171,7 @@ if ($tparam =~ /^nodeid=/) {
    #if ($method =~ /dr/){$seldr="selected";}
    #if ($method =~ /tu/){$seltu="selected";}
    #if ($method =~ /masq/){$selma="selected";}
+   
   }	
 }	
 
@@ -150,7 +180,6 @@ if ($EditMode){
 } else {
  $tblText="Node Manager - Add Node";
 } 
-
 print htmlmainheader;
 print htmlmaintab(7,860,0);
 print htmlmaincss;
@@ -368,12 +397,28 @@ my $ret='
    	     <td background="/images/t1_zeile-hg-bl.gif" height="30" valign="bottom" width="95"><img src="/images/1x1_clear.gif" height="1" width="1">Name</td>  
          <td background="/images/t1_zeile-hg-bl.gif" height="30" valign="bottom" width="263"><img src="/images/1x1_clear.gif" height="1" width="1">
    	     <input name="nodename" size="30" maxlength="30" class="fontblack" type="text" value="'.$NodeName.'">
-   	     </td><td background="/images/t1_zeile-hg-bl.gif" height="30" valign="bottom" width="98"><img src="/images/1x1_clear.gif" height="1" width="1">'.$txtProto.'</td>  
+   	     </td><td background="/images/t1_zeile-hg-bl.gif" height="30" valign="bottom" width="98"><img src="/images/1x1_clear.gif" height="1" width="1"></td>  
          <td background="/images/t1_zeile-hg-bl.gif" height="30" valign="bottom" width="288"><img src="/images/1x1_clear.gif" height="1" width="1">
-  		    <input name="ip" size="30" maxlength="30" class="fontblack" type="text" value="'.$NodeIP.'">
 	    	 </td>
          <td align="right" height="30" valign="bottom" width="14"><img src="/images/t1_zeile-rt-cl.gif" height="30" width="14"></td>
         </tr>
+
+
+
+        <tr> 
+         <td align="right" height="30" valign="bottom" width="11"><img src="/images/t1_zeile-lft-cl.gif" height="30" width="11"></td>
+   	     <td background="/images/t1_zeile-hg-bl.gif" height="30" valign="bottom" width="95"><img src="/images/1x1_clear.gif" height="1" width="1">IP (v4)</td>  
+         <td background="/images/t1_zeile-hg-bl.gif" height="30" valign="bottom" width="263"><img src="/images/1x1_clear.gif" height="1" width="1">
+   	     <input name="ipv4" size="30" maxlength="30" class="fontblack" type="text" value="'.$NodeIP.'">
+   	     </td><td background="/images/t1_zeile-hg-bl.gif" height="30" valign="bottom" width="98"><img src="/images/1x1_clear.gif" height="1" width="1">IP (v6)</td>  
+         <td background="/images/t1_zeile-hg-bl.gif" height="30" valign="bottom" width="288"><img src="/images/1x1_clear.gif" height="1" width="1">
+  		    <input name="ipv6" size="30" maxlength="30" class="fontblack" type="text" value="'.$NodeIP6.'">
+	    	 </td>
+         <td align="right" height="30" valign="bottom" width="14"><img src="/images/t1_zeile-rt-cl.gif" height="30" width="14"></td>
+        </tr>
+
+
+
         <tr> 
          <td align="right" height="30" valign="bottom" width="11"><img src="/images/t1_zeile-lft-cl.gif" height="30" width="11"></td>
    	     <td background="/images/t1_zeile-hg-bl.gif" height="30" valign="bottom" width="95"><img src="/images/1x1_clear.gif" height="1" width="1">Port</td>  
