@@ -11,8 +11,9 @@ use Time::localtime;
 
 #2.0.3 - Add Visible mode - May 2011
 #2.0.4 - Add Wakup and Shutdown-Jul2011
+#2.0.5 - Add v6 support 
 
-my $version="2.0.4";
+my $version="2.0.5";
 ####################### CONFIGURATION #######################
 use XML::Simple;
 use Data::Dumper;
@@ -40,10 +41,8 @@ use htmlsetuphelper qw(&htmlsetuptab &htmlsetupcss &htmlmainsetupheader);
 #########################################################################################
 my ($ServerName,$NodeIP,$Protocol,$Schedule,$Port,$Persistance,$tresid,$ResID,$ttt,$IP,$SQLCName,$SQLCID,$SQLcmd_reset_id,$RebootID,$MRTG,$ShutID,$WakeID);
 my ($Visible,$MAC);  #2.0.3
-my ($selmonval);
-my ($selen,$selenval);
-my $txtProto;
-my $tblText;
+my ($selmonval,$selen,$selenval,$txtProto,$tblText);
+my ($IP6);  #2.0.5
 my $EditMode=undef;
 my ($dbh,$dbhn,$ret);
 #########################################################################################
@@ -56,12 +55,13 @@ if ($tparam =~ /^serverid=/) {
  $EditMode=1;
  if ($tparam =~ m/serverid=(\d*)/){ 
   $tresid=$1;
-  my $sql = $dbh->prepare("SELECT enabled,alias,realip,cmd_reboot_id,mrtg_link,resID,visible,mac,cmd_shutdown_id,cmd_wakeup_id FROM tblResources where resID='".$1."' ;" );  	
-  $ttt=("SELECT enabled,alias,realip,cmd_reboot_id,mrtg_link,resID,visible,mac,cmd_shutdown_id,cmd_wakeup_id FROM tblResources where resID='".$1."' ;" );  	
+  my $sql = $dbh->prepare("SELECT enabled,alias,realip,realip6,cmd_reboot_id,mrtg_link,resID,visible,mac,cmd_shutdown_id,cmd_wakeup_id FROM tblResources where resID='".$1."' ;" );  	
+  $ttt=("SELECT enabled,alias,realip,realip6,cmd_reboot_id,mrtg_link,resID,visible,mac,cmd_shutdown_id,cmd_wakeup_id FROM tblResources where resID='".$1."' ;" );  	
   $sql->execute ; 
-  (my($enabled,$alias,$realip,$cmd_reboot_id,$mrtg_link,$resID,$visible,$mac,$Shutcmd,$Wakecmd)=$sql->fetchrow_array);
+  (my($enabled,$alias,$realip,$realip6,$cmd_reboot_id,$mrtg_link,$resID,$visible,$mac,$Shutcmd,$Wakecmd)=$sql->fetchrow_array);
   $txtProto="IP Address";
   $IP=$realip;
+  $IP6=$realip6;  #2.0.5
   $ServerName=$alias;
   $ResID=$resID;
   $RebootID=$cmd_reboot_id;
@@ -317,12 +317,27 @@ my $ret='
    	     <td background="/images/t1_zeile-hg-bl.gif" height="30" valign="bottom" width="95"><img src="/images/1x1_clear.gif" height="1" width="1">Name</td>  
          <td background="/images/t1_zeile-hg-bl.gif" height="30" valign="bottom" width="263"><img src="/images/1x1_clear.gif" height="1" width="1">
    	     <input name="servername" size="30" maxlength="30" class="fontblack" type="text" value="'.$ServerName.'">
-   	     </td><td background="/images/t1_zeile-hg-bl.gif" height="30" valign="bottom" width="98"><img src="/images/1x1_clear.gif" height="1" width="1">IP Address</td>  
+   	     </td><td background="/images/t1_zeile-hg-bl.gif" height="30" valign="bottom" width="98"><img src="/images/1x1_clear.gif" height="1" width="1"></td>  
          <td background="/images/t1_zeile-hg-bl.gif" height="30" valign="bottom" width="288"><img src="/images/1x1_clear.gif" height="1" width="1">
-  		    <input name="ip" size="30" maxlength="30" class="fontblack" type="text" value="'.$IP.'">
+  		    
 	    	 </td>
          <td align="right" height="30" valign="bottom" width="14"><img src="/images/t1_zeile-rt-cl.gif" height="30" width="14"></td>
         </tr>
+
+
+        <tr> 
+         <td align="right" height="30" valign="bottom" width="11"><img src="/images/t1_zeile-lft-cl.gif" height="30" width="11"></td>
+   	     <td background="/images/t1_zeile-hg-bl.gif" height="30" valign="bottom" width="95"><img src="/images/1x1_clear.gif" height="1" width="1">IP (v4)</td>  
+         <td background="/images/t1_zeile-hg-bl.gif" height="30" valign="bottom" width="263"><img src="/images/1x1_clear.gif" height="1" width="1">
+   	     <input name="ipv4" size="30" maxlength="30" class="fontblack" type="text" value="'.$IP.'">
+   	     </td><td background="/images/t1_zeile-hg-bl.gif" height="30" valign="bottom" width="98"><img src="/images/1x1_clear.gif" height="1" width="1">IP (v6)</td>  
+         <td background="/images/t1_zeile-hg-bl.gif" height="30" valign="bottom" width="288"><img src="/images/1x1_clear.gif" height="1" width="1">
+  		    <input name="ipv6" size="30" maxlength="30" class="fontblack" type="text" value="'.$IP6.'">
+	    	 </td>
+         <td align="right" height="30" valign="bottom" width="14"><img src="/images/t1_zeile-rt-cl.gif" height="30" width="14"></td>
+        </tr>
+
+
         <tr> 
          <td align="right" height="30" valign="bottom" width="11"><img src="/images/t1_zeile-lft-cl.gif" height="30" width="11"></td>
    	     <td background="/images/t1_zeile-hg-bl.gif" height="30" valign="bottom" width="95"><img src="/images/1x1_clear.gif" height="1" width="1">MRTG Link</td>  
@@ -539,10 +554,10 @@ my $ret='
           <td width="258"  height="8" valign="top" background="/images/t1_bottom-hg1.gif"><img src="/images/1x1_clear.gif" width="1" height="8"></td>
           <td height="14" align="left" valign="top"><img src="/images/t1_bottom-rt.gif" width="14" height="14"></td>
         </tr>
-                            <tr> 
-             <td colspan="2" align="left" valign="top"><a href="javascript:history.back()"><img src="/images/back-tab.gif" alt="previous page" width="63" height="29" border="0"></a></td>
-             <td width="19">&nbsp;</td>
-            </tr>
+        <tr> 
+         <td colspan="2" align="left" valign="top"><a href="javascript:history.back()"><img src="/images/back-tab.gif" alt="previous page" width="63" height="29" border="0"></a></td>
+         <td width="19">&nbsp;</td>
+        </tr>
 
      </table>
 
