@@ -1,5 +1,8 @@
 #!/usr/bin/perl 
 
+#2.0.3 - Add visible and mac adress options - may2011
+#2.0.4 - Add Wakup and Shutdown-Jul2011
+#2.0.5 - Add v6 - Mai2017
 
 ##################################
 #Manage Server Add / Edit / Delete
@@ -10,6 +13,8 @@
 ##################################
 
 
+
+
 use warnings;
 use strict;
 use DBI;
@@ -19,6 +24,9 @@ use POSIX;
 ####################### CONFIGURATION #######################
 use XML::Simple;
 use Data::Dumper;
+use Net::IP ':PROC'; #2.0.5 -  #http://stackoverflow.com/questions/27398691/ip-database-from-ip2location-and-convert-ipv4-to-ipv6-in-perl -  apt-get install libnet-ip-perl
+# apt-get install libnet-ip-perl
+
 ############
 #Config Vars
 ############
@@ -39,10 +47,8 @@ my $retscriptname="mylvsmgrsrv.pl";
 ####################### CONFIGURATION #######################
 
 
-#2.0.3 - Add visible and mac adress options - may2011
-#2.0.4 - Add Wakup and Shutdown-Jul2011
 
-my $version = "2.0.4";
+my $version = "2.0.5";
 
 #Get Apache Environs
 my $tparam=$ENV{QUERY_STRING};
@@ -56,6 +62,10 @@ my ($sqlAlias,$sqlIP,$GlobalAlias,$GlobalIP,$GlobalTxt,$sqln,$sqlnn,$sqlnnn);
 my ($dbh,$dbhn,$dbhnn,$dbhnnn,$var,$value);
 my $showid;  #=1;  #Ste TestID !!!
 my ($myIP,$myHost,$myCHost);
+
+my ($ip6,$ipinvalid);  #2.0.5
+
+
 $granted=&chkuser($curuser);  #Check User
 print &HTMLHeader;
 $dbh = DBI->connect("DBI:mysql:$database:$servername:3306",$sqluser,$sqlpassword); 
@@ -66,7 +76,7 @@ $tparam=URLDecode($tparam);
 
     
 
-my ($servername,$nodename,$ip,$id,$cpnode,$cpmon,$newresID,$newinvID,$tmpAlias,$tmpSQLlink,$newmonID,$cpserver,$newnodeID,$port);
+my ($servername,$nodename,$ip4,$id,$cpnode,$cpmon,$newresID,$newinvID,$tmpAlias,$tmpSQLlink,$newmonID,$cpserver,$newnodeID,$port);
 my ($chktoken,$id,$mode,$sqlstat,$sql);
 
 my ($errmsg); #2.0.3
@@ -100,7 +110,8 @@ foreach (@reqTokens){  #Get nmode first
    foreach (@reqTokens){
  	  if (!/\'|\;|\(|\)|\"|\`|\*|where\s+|truncate\s+|\s+from\s+|\select\s+|delete\s+|\s+as\s+/){  #No SQL Injection
 	   if (/^servername=*([^ ]*)/i){$servername=$1;}	 
-   	 if (/^ip=*([^ ]*)/i){$ip=$1;}	 
+   	 if (/^ip4=*([^ ]*)/i){$ip4=$1;}	 
+   	 if (/^ip6=*([^ ]*)/i){$ip6=$1;}	 
    	 if (/^id=*([^ ]*)/i){$id=$1;}	 
    	 if (/^cpnode=*([^ ]*)/i){$cpnode=$1;}	 
    	 if (/^cpmon=*([^ ]*)/i){$cpmon=$1;}	 
@@ -119,11 +130,25 @@ foreach (@reqTokens){  #Get nmode first
    }	
 
 
+
+#   if ((!checkIP($vip) and ($protocol!~/fwm/i)) and ($vip)){
+#   	print "Syntax error, check IPv4 address format<BR>";	
+#   	$dinc=1;
+#   }
+
+#   if ((!checkIP($vip6)) and ($protocol!~/fwm/i) and ($vip6) ){
+#   	print "Syntax error, check IPv6 address format<BR>";	
+#   	$dinc=1;
+#   }
+
+
+
    &PrintHTMLMessage("************************************************<BR>");
    &PrintHTMLMessage("***  Copy Server and all associated nodes and monitors   ***<BR>");
    &PrintHTMLMessage("************************************************<BR>");
    &PrintHTMLMessage("New Servername: $servername <BR>");
-   &PrintHTMLMessage("New IP: $ip <BR>");
+   &PrintHTMLMessage("New IP(4): $ip4 <BR>");
+   &PrintHTMLMessage("New IP(6): $ip6 <BR>");
    &PrintHTMLMessage("Source ResID: $id <BR>");
    $sqlstat = ("Select resID from tblResources order by resID desc limit 1;"); 
    $sql = $dbh->prepare($sqlstat);
@@ -149,6 +174,25 @@ foreach (@reqTokens){  #Get nmode first
    $newmonID=$sqlID+1;
    #&PrintHTMLMessage("$sqlstat <BR>");
    &PrintHTMLMessage("New MonID: $newmonID <BR>");
+
+
+   if ((!checkIP($ip4)) and ($ip4)){
+   	$isUnique=undef;
+   	&PrintHTMLMessage("Error: The IPv4 address is invalid <br>");
+   }
+
+   if ((!checkIP($ip6)) and ($ip6)){
+   	$isUnique=undef;
+   	&PrintHTMLMessage("Error: The IPv6 address is invalid <br>");
+   }
+   
+   if ((!$ip4) and (!$ip6)) {   
+   	&PrintHTMLMessage("Error: No ip address has been set, required is to set either v4 or v6 <br>");
+   	$isUnique=undef;
+   }	
+   
+
+
   
    #Should not exist
    $sqlstat = ("Select alias from tblResources where alias='$servername';"); 
@@ -161,7 +205,7 @@ foreach (@reqTokens){  #Get nmode first
    	&PrintHTMLMessage("Error! the alias does already exist: $sqlAlias  <BR>");
    }
 
-   $sqlstat = ("Select realip from tblResources where realip='$ip';"); 
+   $sqlstat = ("Select realip from tblResources where realip='$ip4';"); 
    $sql = $dbh->prepare($sqlstat);
    $sql->execute;
    (my($sqlIP)=$sql->fetchrow_array);
@@ -193,7 +237,7 @@ foreach (@reqTokens){  #Get nmode first
     #################
     #Insert new host!   
     #################
-    $sqlstat = ("insert into tblResources (resID,enabled,alias,realip,cmd_reboot_id,mrtg_link,visible,mac,cmd_shutdown_id,cmd_wakeup_id) values ('$newresID','0','$servername','$ip','$SQLcmd_reboot_id','$SQLmrtg_link','$SQLvisible','$SQLmac','$SQLcmd_shutdown_id','$SQLcmd_wakeup_id')"); 
+    $sqlstat = ("insert into tblResources (resID,enabled,alias,realip,cmd_reboot_id,mrtg_link,visible,mac,cmd_shutdown_id,cmd_wakeup_id,realip6) values ('$newresID','0','$servername','$ip4','$SQLcmd_reboot_id','$SQLmrtg_link','$SQLvisible','$SQLmac','$SQLcmd_shutdown_id','$SQLcmd_wakeup_id','$ip6')"); 
     #&PrintHTMLMessage("$sqlstat<br>");
     $sql  = $dbhn->do($sqlstat);
     if ($sql eq 1) {
@@ -212,12 +256,13 @@ foreach (@reqTokens){  #Get nmode first
      $sql->execute;
      while (my($SQLinvID,$SQLresID,$SQLnodeID,$SQLsnmpID,$SQLenabled,$SQLactive,$SQLmaintenance,$SQLfailstate,$SQLport,$SQLmethod,$SQLlink,$SQLweight,$SQLautomovepoolid,$SQLweightdown,$SQLcmd_reset_id,$SQLbid)=$sql->fetchrow_array) {
       #&PrintHTMLMessage(" - $SQLinvID,$SQLresID,$SQLnodeID,$SQLsnmpID,$SQLenabled,$SQLactive,$SQLmaintenance,$SQLfailstate,$SQLport,$SQLmethod,$SQLlink,$SQLweight,$SQLautomovepoolid,$SQLweightdown,$SQLcmd_reset_id,$SQLbid<br>");
-      $tmpSQLlink = $SQLlink;
-      $tmpSQLlink =~ s/$tmpAlias/$servername/g;
+      #$tmpSQLlink = $SQLlink;
+      #$tmpSQLlink =~ s/$tmpAlias/$servername/g; #!Replace alias with the new servername
       #Insert new node!     
-      
+      $tmpSQLlink=$servername.":".$SQLport; #2.0.5 - Use static link mapping
+
       $sqlstat = ("insert into tblNodesInventory (invID,resID,nodeID,snmpID,enabled,active,maintenance,failstate,port,method,link,weight,automovepoolid,weightdown,cmd_reset_id,bid) values ('$newinvID','$newresID','$SQLnodeID','$SQLsnmpID','0','$SQLactive','$SQLmaintenance','$SQLfailstate','$SQLport','$SQLmethod','$tmpSQLlink','$SQLweight','$SQLautomovepoolid','$SQLweightdown','$SQLcmd_reset_id','$SQLbid') ");
-      #&PrintHTMLMessage(" - $sqlstat<br>");
+      &PrintHTMLMessage(" - $sqlstat<br>");
       $sqln  = $dbhn->do($sqlstat);
       if ($sqln eq 1) {
        &PrintHTMLMessage(" -> OK: SQL NodeInventory Insert - NewInvID:$newinvID - Source:$SQLinvID   <br>");
@@ -304,7 +349,8 @@ foreach (@reqTokens){  #Get nmode first
  	  if (!/\'|\;|\(|\)|\"|\`|\*|where\s+|truncate\s+|\s+from\s+|\select\s+|delete\s+|\s+as\s+/){  #No SQL Injection
 	   if (/^nodename=*([^ ]*)/i){$nodename=$1;}	 
    	 if (/^id=*([^ ]*)/i){$id=$1;}	 
-   	 if (/^ip=*([^ ]*)/i){$ip=$1;}	 
+   	 if (/^ip4=*([^ ]*)/i){$ip4=$1;}	 
+   	 if (/^ip6=*([^ ]*)/i){$ip6=$1;}	 
    	 if (/^port=*([^ ]*)/i){$port=$1;}	 
    	 if (/^cpserver=*([^ ]*)/i){$cpserver=$1;}	 
     }
@@ -316,7 +362,8 @@ foreach (@reqTokens){  #Get nmode first
    }	
 
    &PrintHTMLMessage("New Nodename: $nodename <BR>");
-   &PrintHTMLMessage("New Node IP: $ip <BR>");
+   &PrintHTMLMessage("New Node IPv4: $ip4 <BR>");
+   &PrintHTMLMessage("New Node IPv6: $ip6 <BR>");
    &PrintHTMLMessage("Source NodeID: $id <BR>");
 
 
@@ -329,16 +376,46 @@ foreach (@reqTokens){  #Get nmode first
    &PrintHTMLMessage("New NodeID: $newnodeID <BR>");
    $isUnique=1;
    
-   if ($ip !~ /(\d+).(\d+).(\d+).(\d+)/){
-    $isUnique=undef;
-    $errmsg.="Error: The IP address is invalid <BR>";
-    &PrintHTMLMessage("Error: The IP address is invalid <br>");
+   
+   #if ($ip4 !~ /(\d+).(\d+).(\d+).(\d+)/){ #2.0.5 disabled
+   # $isUnique=undef;
+   # $errmsg.="Error: The IP address is invalid <BR>";
+   # &PrintHTMLMessage("Error: The IP address is invalid <br>");
+   #}
+   
+   if ((!checkIP($ip4)) and ($ip4)){
+   	$isUnique=undef;
+   	&PrintHTMLMessage("Error: The IPv4 address is invalid <br>");
+   }
+
+   if ((!checkIP($ip6)) and ($ip6)){
+   	$isUnique=undef;
+   	&PrintHTMLMessage("Error: The IPv6 address is invalid <br>");
    }
    
+   if ((!$ip4) and (!$ip6)) {   
+   	&PrintHTMLMessage("Error: No ip address has been set, required is to set either v4 or v6 <br>");
+   	$isUnique=undef;
+   }	
+   
+   if (!$nodename) {
+   	&PrintHTMLMessage("Error: No nodename has been set<br>");
+   	$isUnique=undef;
+   }
+
+
+   if (!$port) {
+   	&PrintHTMLMessage("Error: No port has been set<br>");
+   	$isUnique=undef;
+   }
+
+   
+   
+
    ################### 
    #Check node IP/Port
    ###################
-   $sqlstat = ("Select enabled,Name,scheduler,service,vip,persistent,monitor from tblNodes where vip = '$ip:$port'");
+   $sqlstat = ("Select enabled,Name,scheduler,service,vip,persistent,monitor from tblNodes where vip = '$ip4:$port' or vip6='$ip6:$port'");
    $sql = $dbh->prepare($sqlstat);
    $sql->execute;
    (my($SQLenabled,$SQLName,$SQLscheduler,$SQLservice,$SQLvip,$SQLpersistent,$SQLmonitor)=$sql->fetchrow_array);
@@ -377,7 +454,7 @@ foreach (@reqTokens){  #Get nmode first
     ############# 
     #Insert node
     ############
-   	$sqlstat = ("insert into tblNodes (nodeID,enabled,Name,scheduler,service,vip,persistent,monitor) values ('$newnodeID','$SQLenabled','$nodename','$SQLscheduler','$SQLservice','$ip:$port','$SQLpersistent','$SQLmonitor') ");
+   	$sqlstat = ("insert into tblNodes (nodeID,enabled,Name,scheduler,service,vip,persistent,monitor,vip6) values ('$newnodeID','$SQLenabled','$nodename','$SQLscheduler','$SQLservice','$ip4:$port','$SQLpersistent','$SQLmonitor','$ip6:$port') ");
     $sql  = $dbhn->do($sqlstat);
     if ($sql eq 1) {
      &PrintHTMLMessage(" -> OK: SQL Node Insert - New NodeID:$newnodeID <br>");
@@ -402,7 +479,7 @@ foreach (@reqTokens){  #Get nmode first
      $sql->execute;
      while (my($SQLinvID,$SQLresID,$SQLnodeID,$SQLsnmpID,$SQLenabled,$SQLactive,$SQLmaintenance,$SQLfailstate,$SQLport,$SQLmethod,$SQLlink,$SQLweight,$SQLautomovepoolid,$SQLweightdown,$SQLcmd_reset_id,$SQLbid)=$sql->fetchrow_array){
       #&PrintHTMLMessage(" -> $SQLinvID,$SQLresID,$SQLnodeID,$SQLsnmpID,$SQLenabled,$SQLactive,$SQLmaintenance,$SQLfailstate,$SQLport,$SQLmethod,$SQLlink,$SQLweight,$SQLautomovepoolid,$SQLweightdown,$SQLcmd_reset_id,$SQLbid  <br>");	
-      $sqlstat = ("insert into tblNodesInventory (invID,resID,nodeID,snmpID,enabled,active,maintenance,failstate,port,method,link,weight,automovepoolid,weightdown,cmd_reset_id,bid) values ('$newinvID','$SQLresID','$newnodeID','$SQLsnmpID','$SQLenabled','$SQLactive','$SQLmaintenance','$SQLfailstate','$SQLport','$SQLmethod','$ip:$port','$SQLweight','$SQLautomovepoolid','$SQLweightdown','$SQLcmd_reset_id','$SQLbid')");
+      $sqlstat = ("insert into tblNodesInventory (invID,resID,nodeID,snmpID,enabled,active,maintenance,failstate,port,method,link,weight,automovepoolid,weightdown,cmd_reset_id,bid) values ('$newinvID','$SQLresID','$newnodeID','$SQLsnmpID','$SQLenabled','$SQLactive','$SQLmaintenance','$SQLfailstate','$SQLport','$SQLmethod','$ip4:$port','$SQLweight','$SQLautomovepoolid','$SQLweightdown','$SQLcmd_reset_id','$SQLbid')");
       #&PrintHTMLMessage(" -> $sqlstat  <br>");
       $sqln  = $dbhn->do($sqlstat);
       if ($sqln eq 1) {
@@ -687,4 +764,36 @@ sub PrintHTMLMessage {
 	if ($HTMLLVSView){
 	 print "$_[0]\n";
 	} 
-}
\ No newline at end of file
+}
+
+
+
+sub checkIP {  #2.0.5
+ #my $ipaddr='fde2:8acd:e9d3::22011';
+ $ipinvalid=undef;
+ #print "Check IP  $_[0] <BR>";	 
+ my $ip = new Net::IP ($_[0]) or &errorprint(Net::IP::Error());
+
+ #$ip_num=$ip->intip();
+ #$ipaddr=$ip->ip();
+ #$ipver=$ip->version();
+ #$iptype=$ip->iptype();
+ if (!$ipinvalid) {
+ 	#if ($opt_v) {
+  # print ("$_[0] = IP Version: ".$ip->version()." (VALID)\n");
+  # #print ("Size: ".$ip->size()."\n");
+  # #print ("Len : ".$ip->prefixlen()."\n");
+  # #print ("Type: ".$ip->iptype()."\n");
+  #} 
+  return 1;
+ }
+ return undef; 
+}
+
+
+sub errorprint {  #2.0.5
+	#if ($opt_v) {
+	# print "$_[0]\n";
+	#} 
+	$ipinvalid=1;
+}
