@@ -13,6 +13,7 @@ use Time::localtime;
 #2.0.4 - Add Wakup and Shutdown-Jul2011
 #2.0.5 - Add Wakup and Shutdown-Jul2011
 #2.0.5 - New scriptname: mylvscopyserver.pl - previous (template) mylvsaddserver.pl
+#2.0.5 - Add v6
 
 my $version="2.0.4";
 ####################### CONFIGURATION #######################
@@ -40,7 +41,7 @@ use htmlhelper qw(&htmlmaintab &htmlmainheader &htmlmaincss &jscript);
 use htmlsetuphelper qw(&htmlsetuptab &htmlsetupcss &htmlmainsetupheader);
 
 #########################################################################################
-my ($ServerName,$NodeIP,$Protocol,$Schedule,$Port,$Persistance,$tresid,$ResID,$ttt,$IP,$SQLCName,$SQLCID,$SQLcmd_reset_id,$RebootID,$MRTG,$ShutID,$WakeID);
+my ($ServerName,$NodeIP,$Protocol,$Schedule,$Port,$Persistance,$tresid,$ResID,$ttt,$IP4,$SQLCName,$SQLCID,$SQLcmd_reset_id,$RebootID,$MRTG,$ShutID,$WakeID);
 my ($Visible,$MAC);  #2.0.3
 my ($selmonval);
 my ($selen,$selenval);
@@ -48,6 +49,7 @@ my $txtProto;
 my $tblText;
 my $EditMode=undef;
 my ($dbh,$dbhn,$ret);
+my ($IP6); #2.0.5
 #########################################################################################
 #BEGIN
 $granted=&chkuser($curuser);  #Check User
@@ -58,12 +60,13 @@ if ($tparam =~ /^serverid=/) {
  $EditMode=1;
  if ($tparam =~ m/serverid=(\d*)/){ 
   $tresid=$1;
-  my $sql = $dbh->prepare("SELECT enabled,alias,realip,cmd_reboot_id,mrtg_link,resID,visible,mac,cmd_shutdown_id,cmd_wakeup_id FROM tblResources where resID='".$1."' ;" );  	
-  $ttt=("SELECT enabled,alias,realip,cmd_reboot_id,mrtg_link,resID,visible,mac,cmd_shutdown_id,cmd_wakeup_id FROM tblResources where resID='".$1."' ;" );  	
+  my $sql = $dbh->prepare("SELECT enabled,alias,realip,cmd_reboot_id,mrtg_link,resID,visible,mac,cmd_shutdown_id,cmd_wakeup_id,realip6 FROM tblResources where resID='".$1."' ;" );  	
+  $ttt=("SELECT enabled,alias,realip,cmd_reboot_id,mrtg_link,resID,visible,mac,cmd_shutdown_id,cmd_wakeup_id,realip6 FROM tblResources where resID='".$1."' ;" );  	
   $sql->execute ; 
-  (my($enabled,$alias,$realip,$cmd_reboot_id,$mrtg_link,$resID,$visible,$mac,$Shutcmd,$Wakecmd)=$sql->fetchrow_array);
+  (my($enabled,$alias,$realip,$cmd_reboot_id,$mrtg_link,$resID,$visible,$mac,$Shutcmd,$Wakecmd,$realip6)=$sql->fetchrow_array);
   $txtProto="IP Address";
-  $IP=$realip;
+  $IP4=$realip;
+  $IP6=$realip6;
   $ServerName=$alias;
   $ResID=$resID;
   $RebootID=$cmd_reboot_id;
@@ -307,9 +310,19 @@ my $ret='
    	     <td background="/images/t1_zeile-hg-bl.gif" height="30" valign="bottom" width="187"><img src="/images/1x1_clear.gif" height="1" width="1">Copy to Name</td>  
          <td background="/images/t1_zeile-hg-bl.gif" height="30" valign="bottom" width="193"><img src="/images/1x1_clear.gif" height="1" width="1">
    	     <input name="servername" size="30" maxlength="30" class="fontblack" type="text" value="'.$ServerName.'">
-   	     </td><td background="/images/t1_zeile-hg-bl.gif" height="30" valign="bottom" width="161	"><img src="/images/1x1_clear.gif" height="1" width="1">Copy to IP</td>  
+   	     </td><td background="/images/t1_zeile-hg-bl.gif" height="30" valign="bottom" width="161	"><img src="/images/1x1_clear.gif" height="1" width="1"></td>  
+         <td background="/images/t1_zeile-hg-bl.gif" height="30" valign="bottom" width="203"><img src="/images/1x1_clear.gif" height="1" width="1"></td>
+         <td align="right" height="30" valign="bottom" width="14"><img src="/images/t1_zeile-rt-cl.gif" height="30" width="14"></td>
+        </tr>
+
+        <tr> 
+         <td align="right" height="30" valign="bottom" width="11"><img src="/images/t1_zeile-lft-cl.gif" height="30" width="11"></td>
+   	     <td background="/images/t1_zeile-hg-bl.gif" height="30" valign="bottom" width="187"><img src="/images/1x1_clear.gif" height="1" width="1">Copy to IPv4</td>  
+         <td background="/images/t1_zeile-hg-bl.gif" height="30" valign="bottom" width="193"><img src="/images/1x1_clear.gif" height="1" width="1">
+   	     <input name="ip4" size="30" maxlength="30" class="fontblack" type="text" value="'.$IP4.'">
+   	     </td><td background="/images/t1_zeile-hg-bl.gif" height="30" valign="bottom" width="161	"><img src="/images/1x1_clear.gif" height="1" width="1">Copy to IPv6</td>  
          <td background="/images/t1_zeile-hg-bl.gif" height="30" valign="bottom" width="203"><img src="/images/1x1_clear.gif" height="1" width="1">
-  		    <input name="ip" size="30" maxlength="30" class="fontblack" type="text" value="'.$IP.'">
+  		    <input name="ip6" size="30" maxlength="30" class="fontblack" type="text" value="'.$IP6.'">
 	    	 </td>
          <td align="right" height="30" valign="bottom" width="14"><img src="/images/t1_zeile-rt-cl.gif" height="30" width="14"></td>
         </tr>
