@@ -5,6 +5,7 @@
 
 #May2011 - Add Wakup Up and ShutDown option
 
+#2.0.5 - Add v6
 
 #####################
 #Show Host Properties
@@ -26,6 +27,8 @@ use Data::Dumper;
 my $conffile="/etc/mylvs/mylvs.conf.xml";
 my ($servername,$database,$sqluser,$sqlpassword,$lvscmd,$bkupdatabase,$bkupsqluser,$bkupsqlpassword,$bkupservername,$ActiveWarning,$InActiveWarning,$HTTP_ERR,$HTTP_WARN,$simulate,$maxcount,$backuppath,$restoreapp,$backupapp,$SuppressedAddress,$HTMLLVSView,$bkupreplcommand,$sitelogo);
 &getconfig;
+my $hdeb; #2.0.5;
+my $prtDeb=undef;  #2.0.5 - set to undef for non debug
 ############
 
 
@@ -49,6 +52,7 @@ my ($sqlInvID,$sqlInvWeight,$sqlNodeID,$sqlLink,$sqlCmdResetID,$sqlInvActive,$sq
 #####################################################################
 my (%NodeID,%NodeAddress,%NodePort,%NodeScheduler,%NodePersistent,%NodePersistentTimeout,%NodeProto,$prthtml,$sqlAlias,$cmdrebootid,$cmdrebootname,$sqlIP,$sqlEnabled);
 my (%RSRoute,%RSPort,%RSAddress,%RSInActive,%RSActive,%RSWeight,%RSFoundAddress,$curmodeID,$curmodePropertyID,%RSFound,$MonStat);
+my ($sqlVip6,%NodeIDv4,%NodeIDv6,$myIP6,$sqlIP6); #2.0.5;
 &GetLVSOutput;
 
  ###   Fetch Environ   ####
@@ -85,11 +89,11 @@ my (%RSRoute,%RSPort,%RSAddress,%RSInActive,%RSActive,%RSWeight,%RSFoundAddress,
   #Show Edit, Link, Service,Service Enable/Disable,Monitor Enable/Disable,Set Weight (Button),Set Weight (Amount)
   #Get ResID by IP
   #Get Services 
-  my $sqlgalias = $dbh->prepare("SELECT alias,realip,enabled,cmd_reboot_id FROM tblResources where resID = '" . $showid . "';" ); 
+  my $sqlgalias = $dbh->prepare("SELECT alias,realip,enabled,cmd_reboot_id,realip6 FROM tblResources where resID = '" . $showid . "';" ); 
   $sqlgalias->execute ; #Get Inventory and ID's
-  (($sqlAlias,$sqlIP,$sqlEnabled,$cmdrebootid)=$sqlgalias->fetchrow_array);
+  (($sqlAlias,$sqlIP,$sqlEnabled,$cmdrebootid,$sqlIP6)=$sqlgalias->fetchrow_array);
   $myIP=$sqlIP;
-  
+  $myIP6=$sqlIP6; #2.0.5
   
   my $sqlcmdid = $dbh->prepare("SELECT name FROM tblCommands where cmdID = '" . $cmdrebootid . "';" ); 
   $sqlcmdid->execute ; #Get Inventory and ID's
@@ -115,9 +119,9 @@ my (%RSRoute,%RSPort,%RSAddress,%RSInActive,%RSActive,%RSWeight,%RSFoundAddress,
    $ResInvID{$sqlInvID}=$sqlInvID;
    $ResWeight=$sqlInvWeight;
    $ResRstID{$sqlInvID}=$sqlCmdResetID;
-   my $sqlinvname = $dbh->prepare("SELECT name,enabled,scheduler,service,vip FROM tblNodes where nodeID = '" . $sqlNodeID . "';" ); 
+   my $sqlinvname = $dbh->prepare("SELECT name,enabled,scheduler,service,vip,vip6 FROM tblNodes where nodeID = '" . $sqlNodeID . "';" ); 
    $sqlinvname->execute ; #Get Inventory and ID's
-   (($sqlNodeName,$sqlNodeEnabled,$sqlScheduler,$sqlService,$sqlVip)=$sqlinvname->fetchrow_array);
+   (($sqlNodeName,$sqlNodeEnabled,$sqlScheduler,$sqlService,$sqlVip,$sqlVip6)=$sqlinvname->fetchrow_array);
 
    my $sqlmon = $dbh->prepare("SELECT enabled,monID,status,lastcheck,checkinterval,timeout FROM tblMonitor where invID = '" . $sqlInvID . "';" ); 
    #print "SELECT monid,status FROM tblMonitor where invID = '" . $sqlInvID . "' and enabled=1;\n"; 	
@@ -171,26 +175,27 @@ my (%RSRoute,%RSPort,%RSAddress,%RSInActive,%RSActive,%RSWeight,%RSFoundAddress,
 
    for my $pntbase (sort keys %NodeID){  #Enum LVS Inventory
     for my $pntval (sort keys %{$RSAddress{$pntbase}} ){
-     if ($RSAddress{$pntbase}{$pntval} eq $sqlIP)  {
-     	#print "DEB=: $NodeProto{$pntbase} == $sqlService\n"; 	
+     #$hdeb.="RAW DEB=: $RSAddress{$pntbase}{$pntval} == $sqlIP // $sqlIP6<br>"; 	
+     if (  ($RSAddress{$pntbase}{$pntval} eq $sqlIP) or ($RSAddress{$pntbase}{$pntval} eq $sqlIP6) )  {
+     	#$hdeb.="DEB MATCH=: $NodeProto{$pntbase} == $sqlService<br>"; 	
      	if ($NodeProto{$pntbase} =~ /$sqlService/i ) {
-       if (($NodeProto{$pntbase} eq "FWM" ) and ($NodeAddress{$pntbase} eq $sqlVip)) {
+       if (($NodeProto{$pntbase} eq "FWM" ) and ($NodeAddress{$pntbase} eq $sqlVip)  ) {
        	
        	#$NodePort{$curmodeID}="$0";
-       	#print "FWM DEB: $RSAddress{$pntbase}{$pntval} == $NodeAddress{$pntbase} == $sqlVip ==> $RSActive{$pntbase}{$pntval} ==> $RSInActive{$pntbase}{$pntval} ==> $RSWeight{$pntbase}{$pntval}\n";
-     	  $tmpActive=$RSActive{$pntbase}{$pntval};
+       	#$hdeb.="FWM DEB: $RSAddress{$pntbase}{$pntval} == $NodeAddress{$pntbase} == $sqlVip ==> Act: $RSActive{$pntbase}{$pntval} ==> $RSInActive{$pntbase}{$pntval} ==> $RSWeight{$pntbase}{$pntval}-Base: $pntbase - val:$pntval<br>";
+     	  $tmpActive+=$RSActive{$pntbase}{$pntval};
      	  $tmpWeight=$RSWeight{$pntbase}{$pntval};
-     	  $tmpInActive=$RSInActive{$pntbase}{$pntval};
+     	  $tmpInActive+=$RSInActive{$pntbase}{$pntval};
         $RSFound{$pntbase}{$pntval}=1;
         $RSFoundAddress{$pntbase}{$pntval}=$RSAddress{$pntbase}{$pntval};
        } 
      	 if ((($NodeProto{$pntbase} eq "TCP" ) or ($NodeProto{$pntbase} eq "UDP")) 
     		 and ("$NodeAddress{$pntbase}:$RSPort{$pntbase}{$pntval}" eq $sqlVip)
-    		 and ($sqlIP eq $RSAddress{$pntbase}{$pntval}))  {
-     	  #print "DEB>: $sqlIP $RSAddress{$pntbase}{$pntval} $NodeAddress{$pntbase}:$RSPort{$pntbase}{$pntval} $sqlVip ==> $RSActive{$pntbase}{$pntval} ==> $RSInActive{$pntbase}{$pntval}  ==> $RSWeight{$pntbase}{$pntval}\n";
+    		 and (  ($sqlIP eq $RSAddress{$pntbase}{$pntval})) or ($RSAddress{$pntbase}{$pntval} eq $sqlIP6)    )  {
+     	  $hdeb.="DEB>: $sqlIP $RSAddress{$pntbase}{$pntval} $NodeAddress{$pntbase}:$RSPort{$pntbase}{$pntval} $sqlVip ==> $RSActive{$pntbase}{$pntval} ==> $RSInActive{$pntbase}{$pntval}  ==> $RSWeight{$pntbase}{$pntval}-Base: $pntbase - val:$pntval<br>";
      	  $tmpWeight=$RSWeight{$pntbase}{$pntval};
-     	  $tmpActive=$RSActive{$pntbase}{$pntval};
-     	  $tmpInActive=$RSInActive{$pntbase}{$pntval};
+     	  $tmpActive+=$RSActive{$pntbase}{$pntval};
+     	  $tmpInActive+=$RSInActive{$pntbase}{$pntval};
      	  $RSFound{$pntbase}{$pntval}=1;
      	  #$RSFoundAddress{$pntbase}{$pntval}=$RSAddress{$pntbase}{$pntval};
      	 } 
@@ -319,83 +324,169 @@ print &HTMLEndHeader;
 
 
  
- sub GetLVSOutput {
+ 
+ 
+ 
+ 
+ 
+ 
+ 
+ 
+sub GetLVSOutput {
  #Parse LVS Command Output and save it to hash
  my @lvsret = `$lvscmd`;   #Get LVS Status
  for my $myret (@lvsret) {
  	chomp $myret;
   #Mask: "TCP  10.0.1.18:7000 wrr persistent 3600"
   #Mask: "UDP  10.0.1.22:7000 wrr persistent 3600"
- 	#print "XXXXX  DEB1 => $myret\n";
- 	if ($myret =~ /^(\w{3})\s*(\d*).(\d*).(\d*).(\d*):(\d*)\s*(\w*)\s*(\w*)\s*(\d*)/) {
- 	 #print "XXXXX  DEB2 => $myret\n";
- 	 $curmodeID++;
- 	 $curmodePropertyID=0;
-   $NodeID{$curmodeID}=$curmodeID;
-   $NodeProto{$curmodeID}="$1";
- 	 $NodeAddress{$curmodeID}="$2.$3.$4.$5";
- 	 $NodePort{$curmodeID}="$6";
-   $NodeScheduler{$curmodeID}="$7";		
-   $NodePersistent{$curmodeID}="$8";		
-   $NodePersistentTimeout{$curmodeID}="$9";		
- 	} else {
- 	 if ($myret =~ /^(\w{3})\s*(\d*).(\d*).(\d*).(\d*):(\d*)\s*(\w*)/) {
- 	 	#Mask: "TCP  10.0.1.18:7000 wrr"
-    #Mask: "UDP  10.0.1.22:7000 wrr"
- 	 	#print "XXXXX  DEB2a => $myret\n";
+ 	$hdeb.="XXXXX  DEB1 => $myret<br>";
+ 	if ($myret!~/\s*\[/ ) {  #v6?  #2.0.5
+ 	 if ($myret =~ /^(\w{3})\s*(\d*).(\d*).(\d*).(\d*):(\d*)\s*(\w*)\s*(\w*)\s*(\d*)/) {
+ 	  #print "XXXXX  DEB2 => $myret\n";
  	  $curmodeID++;
  	  $curmodePropertyID=0;
     $NodeID{$curmodeID}=$curmodeID;
+    $NodeIDv4{$curmodeID}=$curmodeID;
     $NodeProto{$curmodeID}="$1";
  	  $NodeAddress{$curmodeID}="$2.$3.$4.$5";
  	  $NodePort{$curmodeID}="$6";
     $NodeScheduler{$curmodeID}="$7";		
-    $NodePersistent{$curmodeID}="";		
-    $NodePersistentTimeout{$curmodeID}="";		
+    $NodePersistent{$curmodeID}="$8";		
+    $NodePersistentTimeout{$curmodeID}="$9";		
  	 } else {
- 	  if ($myret =~ /^FWM\s*(\d*)\s*(\w*)\s*(\w*)\s*(\d*)/) {
- 	 	 #Mask: "FWM  1 wlc persistent 3600"
- 	 	 #print "XXXXX  DEB3 => $myret\n";
- 		 $curmodeID++;
- 		 $curmodePropertyID=0;
- 		 $NodeID{$curmodeID}=$curmodeID;
- 		 $NodeProto{$curmodeID}="FWM";
- 		 $NodeAddress{$curmodeID}="$1";
- 		 $NodePort{$curmodeID}="0";
-     $NodeScheduler{$curmodeID}="$2";		
-     $NodePersistent{$curmodeID}="$3";		
-     $NodePersistentTimeout{$curmodeID}="$4";		
+ 	 	#No persitent
+ 	  if ($myret =~ /^(\w{3})\s*(\d*).(\d*).(\d*).(\d*):(\d*)\s*(\w*)/) {
+ 	  	#Mask: "TCP  10.0.1.18:7000 wrr"
+     #Mask: "UDP  10.0.1.22:7000 wrr"
+ 	  	#print "XXXXX  DEB2a => $myret\n";
+ 	   $curmodeID++;
+ 	   $curmodePropertyID=0;
+     $NodeID{$curmodeID}=$curmodeID;
+     $NodeIDv4{$curmodeID}=$curmodeID;
+     $NodeProto{$curmodeID}="$1";
+ 	   $NodeAddress{$curmodeID}="$2.$3.$4.$5";
+ 	   $NodePort{$curmodeID}="$6";
+     $NodeScheduler{$curmodeID}="$7";		
+     $NodePersistent{$curmodeID}="";		
+     $NodePersistentTimeout{$curmodeID}="";		
  	  } else {
- 	   if ($myret =~ /^FWM\s*(\d*)\s*(\w*)/) {
- 	    #Mask: "FWM  1 wlc "
- 	 	  #print "XXXXX  DEB3a => $myret\n";
- 		  $curmodeID++;
- 		  $curmodePropertyID=0;
- 		  $NodeID{$curmodeID}=$curmodeID;
- 		  $NodeProto{$curmodeID}="FWM";
- 		  $NodeAddress{$curmodeID}="$1";
- 		  $NodePort{$curmodeID}="0";
+ 	   if ($myret =~ /^FWM\s*(\d*)\s*(\w*)\s*(\w*)\s*(\d*)/) {
+ 	  	 #Mask: "FWM  1 wlc persistent 3600"
+ 	  	 #print "XXXXX  DEB3 => $myret\n";
+ 	 	 $curmodeID++;
+ 	 	 $curmodePropertyID=0;
+ 	 	 $NodeID{$curmodeID}=$curmodeID;
+ 	 	 $NodeIDv4{$curmodeID}=$curmodeID;
+ 	 	 $NodeProto{$curmodeID}="FWM";
+ 	 	 $NodeAddress{$curmodeID}="$1";
+ 	 	 $NodePort{$curmodeID}="0";
       $NodeScheduler{$curmodeID}="$2";		
       $NodePersistent{$curmodeID}="$3";		
       $NodePersistentTimeout{$curmodeID}="$4";		
+ 	   } else {
+ 	    if ($myret =~ /^FWM\s*(\d*)\s*(\w*)/) {
+ 	     #Mask: "FWM  1 wlc "
+ 	  	  #print "XXXXX  DEB3a => $myret\n";
+ 	 	   $curmodeID++;
+ 	 	   $curmodePropertyID=0;
+ 	 	   $NodeID{$curmodeID}=$curmodeID;
+ 	 	   $NodeIDv4{$curmodeID}=$curmodeID;
+ 	 	   $NodeProto{$curmodeID}="FWM";
+ 	 	   $NodeAddress{$curmodeID}="$1";
+ 	 	   $NodePort{$curmodeID}="0";
+       $NodeScheduler{$curmodeID}="$2";		
+       $NodePersistent{$curmodeID}="$3";		
+       $NodePersistentTimeout{$curmodeID}="$4";		
+ 	    }
  	   }
  	  }
+	 }	
+  }   else {  #2.0.5 V6
+   $hdeb.=" =oo> $myret<br>\n";
+ 	 #TCP  [fde2:8acd:e9d3::220]:7798 wlc persistent 10
+ 	 #TCP  [fde2:8acd:e9d3::220]:7798 wlc 
+ 	 if ($myret =~ /^(\w{3})\s*\[(.*)\]:(\d*)\s*(\w*)\s*(\w*)\s*(\d*)/) {
+ 	  $hdeb.=" yy=> $myret<br>\n";
+ 	  $curmodeID++;
+ 	  $curmodePropertyID=0;
+    $NodeID{$curmodeID}=$curmodeID;
+    $NodeIDv6{$curmodeID}=$curmodeID;
+    $NodeProto{$curmodeID}="$1";
+ 	  $NodeAddress{$curmodeID}="$2";
+ 	  $NodePort{$curmodeID}="$3";
+    $NodeScheduler{$curmodeID}="$4";		
+    $NodePersistent{$curmodeID}="$5";		
+    $NodePersistentTimeout{$curmodeID}="$6";		
+   } else {
+ 	  if ($myret =~ /^(\w{3})\s*\[(.*)\]:(\d*)\s*(\w*)/) {
+ 	   $hdeb.=" =xxs> $myret<br>\n";	
+ 	   #Mask: TCP [fde2:8acd:e9d3::220]:7798 wlc
+ 	   $curmodeID++;
+ 	   $curmodePropertyID=0;
+     $NodeID{$curmodeID}=$curmodeID;
+     $NodeIDv6{$curmodeID}=$curmodeID;
+     $NodeProto{$curmodeID}="$1";
+ 	   $NodeAddress{$curmodeID}="$2";
+ 	   $NodePort{$curmodeID}="$3";
+     $NodeScheduler{$curmodeID}="$4";		
+     $NodePersistent{$curmodeID}="";		
+     $NodePersistentTimeout{$curmodeID}="";		
  	 }
-	}	
+  }
+ }	
+ 	
+ 	
+ 	
  	#Get Node Values
  	#Mask: " -> 10.0.1.240:0                 Route   100    0          0         "
- 	if ($myret =~ m/\s*->\s*(\d*).(\d*).(\d*).(\d*):(\d*)\s*(\w+)\s*(\d*)\s*(\d*)\s*(\d*)/) {
- 	 $curmodePropertyID++;
-   $RSAddress{$curmodeID}{$curmodePropertyID}="$1.$2.$3.$4";
-   $RSPort{$curmodeID}{$curmodePropertyID}="$5";
-   $RSRoute{$curmodeID}{$curmodePropertyID}="$6";
-   $RSWeight{$curmodeID}{$curmodePropertyID}="$7";
-   $RSActive{$curmodeID}{$curmodePropertyID}="$8";
-   $RSInActive{$curmodeID}{$curmodePropertyID}="$9";
+ 	if ($myret!~/\s*->\s*\[/ ) {  #v6?  #2.0.5
+ 	 if ($myret =~ m/\s*->\s*(\d*).(\d*).(\d*).(\d*):(\d*)\s*(\w+)\s*(\d*)\s*(\d*)\s*(\d*)/) {
+ 	  $curmodePropertyID++;
+    $RSAddress{$curmodeID}{$curmodePropertyID}="$1.$2.$3.$4";
+    $RSPort{$curmodeID}{$curmodePropertyID}="$5";
+    $RSRoute{$curmodeID}{$curmodePropertyID}="$6";
+    $RSWeight{$curmodeID}{$curmodePropertyID}="$7";
+    $RSActive{$curmodeID}{$curmodePropertyID}="$8";
+    $RSInActive{$curmodeID}{$curmodePropertyID}="$9";
+ 	 }
+ 	} else {  #v6
+ 		#if ($iptmp =~ /^\[(.*)\]:(\d+)$/) {
+ 		#$hdeb.="V6 --> $myret<br>\n";  #2.0.5
+ 		#  -> [fde2:8acd:e9d3::221]:7798   Route   100    0          0
+
+ 	  if ($myret =~ m/\s*->\s*\[(.*)\]:(\d*)\s*(\w+)\s*(\d*)\s*(\d*)\s*(\d*)/) {
+ 	   $hdeb.="$1 $2 $3 -- Active=$5 InActive=$6 - Mode:$curmodeID Property:$curmodePropertyID <br>\n";  #2.0.5
+ 	   $curmodePropertyID++;
+     $RSAddress{$curmodeID}{$curmodePropertyID}="$1";
+     $RSPort{$curmodeID}{$curmodePropertyID}="$2";
+     $RSRoute{$curmodeID}{$curmodePropertyID}="$3";
+     $RSWeight{$curmodeID}{$curmodePropertyID}="$4";
+     $RSActive{$curmodeID}{$curmodePropertyID}="$5";
+     $RSInActive{$curmodeID}{$curmodePropertyID}="$6";
+   
+ 	 } else {
+ 	  if ($myret =~ /^FWM\s*(\d*)\s*(\w*)/) {  #=> experimental - not tested yet
+ 	   #Mask: "FWM  1 wlc "
+ 	   #print "XXXXX  DEB3a => $myret\n";
+ 	 	 #$curmodeID++;
+ 	 	 $curmodePropertyID=0;
+ 	 	 $NodeID{$curmodeID}=$curmodeID;
+ 	 	 $NodeIDv6{$curmodeID}=$curmodeID;
+ 	 	 $NodeProto{$curmodeID}="FWM";
+ 	 	 $NodeAddress{$curmodeID}="$1";
+ 	 	 $NodePort{$curmodeID}="0";
+     $NodeScheduler{$curmodeID}="$2";		
+     $NodePersistent{$curmodeID}="$3";		
+     $NodePersistentTimeout{$curmodeID}="$4";		
+ 	  }
+ 	 }
  	}
  }    #for my $myret (@lvsret)
 }     #sub GetLVSOutput
 
+ 
+ 
+ 
 sub getconfig {
  #Read xml config file
  my $xml = new XML::Simple (KeyAttr=>[]); # create XML object
@@ -724,5 +815,11 @@ my $ret='
 </body>
 </html>
 ';
-return $ret;	
+
+ if ($prtDeb) {
+   return $hdeb.$ret;	
+ } else {
+	return $ret;	
+ } 
+ 
 }
