@@ -53,7 +53,7 @@ my (%NodeID,%NodeAddress,%NodePort,%NodeScheduler,%NodePersistent,%NodePersisten
 my (%RSAddress,%RSPort,%RSRoute,%RSWeight,%RSActive,%RSInActive,$sqlsnmpkey,$sqlsnmppass,$sqlsnmpport,$sqlsnmptimeout,$CurHTTPUsers,$col_curhttp,$curhttpusrlink);
 my ($sqlInvID,$sqlInvEnabled,$sqlInvWeight,$sqlInvActive,$sqlSNMP,$mrtglink,%ResMrtgID,$sqlNodeID,$curnodeid,$tmpcurnodeid,$GlobalTxt);
 my (%ResAlias,%ResIP,%ResKEY,%ResEnabled,%ResWeight,%ResInvID,%ResMonStat,%ResMonLastCheck,$tmonstat,$img_monstat,$img_monstat_title,%ResServiceTot,%ResServices,$txt_curservice,$txt_curactive,%ResActiveSrvTot,%ResActiveConTot,%ResInActiveConTot,$tmpActive,$tmpInActive,%ResWeightTot,%ResWeightCur,$txt_curweight,$tmpstr4,$link_weight,$img_weight,$img_weight_title,$link_mgr,$img_enable,$img_enable_title,$img_enabled,$img_enabled_text);
-
+my (%RSAddress6);
 $lvscmd=$lvscmd." -Ln";
 &GetLVSOutput;
  #my @lvsret = `$lvscmd`;   #Get LVS Status
@@ -325,6 +325,7 @@ if ($granted) {
    #print "DEB: $RSAddress{$pntbase}{$pntval}<BR>";
    if ($RSAddress{$pntbase}{$pntval} eq $SQLRrealip)  {
     print "NodeID: $pntbase Proto: $NodeProto{$pntbase} Address: $pntval  RealAddress:$SQLRrealip Weight: $RSWeight{$pntbase}{$pntval} Active: $RSActive{$pntbase}{$pntval} InActive: $RSInActive{$pntbase}{$pntval}<BR>";
+    print "=> $RSAddress6{$pntbase}{$pntval} <br>";
    }
   }
  }
@@ -696,6 +697,7 @@ sub GetLVSOutput {
 	}	
  	#Get Node Values
  	#Mask: " -> 10.0.1.240:0                 Route   100    0          0         "
+ 	#print "DEB $myret<br>";
  	if ($myret =~ m/\s*->\s*(\d*).(\d*).(\d*).(\d*):(\d*)\s*(\w+)\s*(\d*)\s*(\d*)\s*(\d*)/) {
  	 $curmodePropertyID++;
    $RSAddress{$curmodeID}{$curmodePropertyID}="$1.$2.$3.$4";
@@ -705,5 +707,11 @@ sub GetLVSOutput {
    $RSActive{$curmodeID}{$curmodePropertyID}="$8";
    $RSInActive{$curmodeID}{$curmodePropertyID}="$9";
  	}
+ 	
+ 	#Does not work yet!
+ 	#if ($myret =~ m/\s*->\s*\[(.*)\]:(\d*)\s*(\w+)\s*(\d*)\s*(\d*)\s*(\d*)/) { #2.0.5
+ 	#if ($myret =~ m/\s*->\s*\[(.*)\]/) { #2.0.5
+ 	# $RSAddress6{$curmodeID}{$curmodePropertyID}="BLA $myret";
+  #}
  }    #for my $myret (@lvsret)
 }     #sub GetLVSOutput
