@@ -15,6 +15,7 @@ use strict;
 use DBI;
 use POSIX;
 
+#2.0.5 - Add ipv6
 
 ####################### CONFIGURATION #######################
 use XML::Simple;
@@ -41,7 +42,7 @@ my $retscriptname="mylvs.pl";
 #Remember this:   <td colspan="2" align="left" valign="top"><a href="javascript:history.back()"><img src="/images/back-tab.gif" alt="previous page" width="63" height="29" border="0"></a></td>
 
 ####################### CONFIGURATION #######################
-my $version = "2.0.1.9";
+my $version = "2.0.5";
 
 #Get Apache Environs
 my $tparam=$ENV{QUERY_STRING};
@@ -60,19 +61,29 @@ my $granted = undef;   #user login flag - default off
 my ($sqlAlias,$sqlIP,$GlobalAlias,$GlobalIP,$GlobalTxt,$replstr,$weightdownstate,$myCurID);
 my (%ResInvID,$ResWeight,$dbh,$mstring,$mxstring,$var,$value,$auto_ok);
 my ($NodeService,$NodeVip,$sqlnoden,$sqlcur,$sqlInvID,$sqlInvTID,$sqlInvWeight,$sqlNodeID,$sqlLink,$sqlIPort,$sqlinv,$sqlalias,$sqlactive,$sqlmethod,$sqlweight,$sqlenabled,$sqlPoolID,$sqlWeightStat,$curstat,$sqlpool,$sqlPoolReource,$sqlAliasEnabled,$mdstring);
-my $showid;  #=1;  #Ste TestID !!!
+my $showid;  #=1;  #Site TestID !!!
 my ($myIP,$myHost,$myCHost);
+my ($hdeb,$NodeVip6,$mstring6,$sqlIP6,$GlobalIP6,$myIP6,$srvCnt4,$srvCnt6); #2.0.5
+my $prtDeb=undef;  #2.0.5 - set to undef for non debug
+
+
 $granted=&chkuser($curuser);  #Check User
+
+$srvCnt4=0;
+$srvCnt6=0;
+
 print &HTMLHeader;
 $dbh = DBI->connect("DBI:mysql:$database:$servername:3306",$sqluser,$sqlpassword); 
 
 if ($tparam =~ m/^(\w{2})=(\d*)/){  
 	$showid=$2;
-  $sqlalias = $dbh->prepare("SELECT alias,realip FROM tblResources where resID = '" . $showid . "';" ); 
+  $sqlalias = $dbh->prepare("SELECT alias,realip,realip6 FROM tblResources where resID = '" . $showid . "';" ); 
   $sqlalias->execute ; #Get Inventory and ID's
-  (($sqlAlias,$sqlIP)=$sqlalias->fetchrow_array);
+  (($sqlAlias,$sqlIP,$sqlIP6)=$sqlalias->fetchrow_array);
   $GlobalAlias=$sqlAlias;
   $GlobalIP=$sqlIP;
+  $GlobalIP6=$sqlIP6;
+  $hdeb.="$GlobalIP - $GlobalIP6<br>";
 }  
 
 if ($tparam =~ m/^td=/){  
@@ -104,10 +115,13 @@ if ($granted) {
  	}	
 
 	$showid=$1;
-  $sqlalias = $dbh->prepare("SELECT alias,realip FROM tblResources where resID = '" . $showid . "';" ); 
+  $sqlalias = $dbh->prepare("SELECT alias,realip,realip6 FROM tblResources where resID = '" . $showid . "';" ); 
   $sqlalias->execute ; #Get Inventory and ID's
-  (($sqlAlias,$sqlIP)=$sqlalias->fetchrow_array);
+  (($sqlAlias,$sqlIP,$sqlIP6)=$sqlalias->fetchrow_array);
   $myIP=$sqlIP;
+  $myIP6=$sqlIP6;
+  
+  $hdeb.="$myIP - $myIP6<br>";
   $myHost=$sqlAlias;
   $sqlinv = $dbh->prepare("SELECT invID,weight,nodeID,link,port,active,method,weight,automovepoolid FROM tblNodesInventory where resID = '" . $showid . "';" ); 
   $sqlinv->execute ; #Get Inventory and ID's
@@ -115,26 +129,59 @@ if ($granted) {
   #$sqlinv = $dbh->prepare("SELECT invID,weight,nodeID,link,port,automovepoolid FROM tblNodesInventory where resID = '" . $showid . "';" ); 
   #$sqlinv->execute ; #Get Inventory and ID's
   #while (($sqlInvID,$sqlInvWeight,$sqlNodeID,$sqlLink,$sqlIPort,$sqlPoolID)=$sqlinv->fetchrow_array) {
-   $sqlnoden = $dbh->prepare("SELECT service,vip FROM tblNodes where nodeid = '" . $sqlNodeID . "';" ); 
+   $sqlnoden = $dbh->prepare("SELECT service,vip,vip6 FROM tblNodes where nodeid = '" . $sqlNodeID . "';" ); 
    $sqlnoden->execute ; 
-   ($NodeService,$NodeVip)=$sqlnoden->fetchrow_array ;
+   $hdeb.="SELECT service,vip,vip6 FROM tblNodes where nodeid = '" . $sqlNodeID . "<br>";
+   ($NodeService,$NodeVip,$NodeVip6)=$sqlnoden->fetchrow_array ;
    if ($NodeService !~ /fwm/i) {
-    $mstring = "$lvscmd -d -t $NodeVip -r $sqlIP:$sqlIPort";
+    
+    $hdeb.="$NodeVip<-->$sqlIP // $NodeVip6<-->$sqlIP6<br>";
+    if (($NodeVip) and ($sqlIP)){
+     $mstring = "$lvscmd -d -t $NodeVip -r $sqlIP:$sqlIPort";
+     $srvCnt4++;
+    } 
+    if (($NodeVip6) and ($sqlIP6)){
+     #Apply -0: /usr/bin/sudo /sbin/ipvsadm -d -t fde2:8acd:e9d3::220:7798 -r fde2:8acd:e9d3::221:7798
+     if ($NodeVip6=~/(.*):(\d+)$/) {
+      $mstring6 = "$lvscmd -d -t [$1]:$2 -r [$sqlIP6]:$sqlIPort"; #2.0.5
+      $srvCnt6++;
+     } 
+    } 
    } else {
-    $mstring = "$lvscmd -d -f $NodeVip -r $sqlIP";	
+    if (($NodeVip) and ($sqlIP)){
+     $mstring = "$lvscmd -d -f $NodeVip -r $sqlIP:$sqlIPort";	
+     $srvCnt4++;
+    } 
+    if (($NodeVip6) and ($sqlIP6)){ #
+     $mstring6 = "$lvscmd -d -f $NodeVip6 -6 -r [$sqlIP6]:$sqlIPort";	 #2.0.5
+     $srvCnt6++;
+    } 
    }	
    #	APPLY: /usr/bin/sudo /sbin/ipvsadm -a -t 10.0.1.4:7000 -r 10.0.1.11:7000 -g -w 10
    #	APPLY: /usr/bin/sudo /sbin/ipvsadm -a -f 5 -r 10.0.1.11 -g -w 100
    #	APPLY: /usr/bin/sudo /sbin/ipvsadm -d -t 10.0.1.4:7000 -r 10.0.1.11:7000
    #	APPLY: /usr/bin/sudo /sbin/ipvsadm -d -f 5 -r 10.0.1.11
    
-   &PrintHTMLMessage ("Apply -$sqlPoolID: $mstring<br>");
+   if ($mstring) {
+    &PrintHTMLMessage ("Apply -$sqlPoolID: $mstring<br>");
+    &lvslog(2,"Turn off service by: $mstring",$curuser);
+   } 
+
+   if ($mstring6) {
+    &PrintHTMLMessage ("Apply -$sqlPoolID: $mstring6<br>");
+    &lvslog(2,"Turn off service by: $mstring6",$curuser);
+   } 
    
    if ($simulate eq "0") {
-    `$mstring`;
+    if ($mstring) {
+     `$mstring`;
+    } 
+    if ($mstring6) {
+    	`$mstring6`;
+    }	
    } 
-   #aloa
-   &lvslog(2,"Turn off service by: $mstring",$curuser);
+  
+   
    &PrintHTMLMessage("SQL:: UPDATE tblNodesInventory SET enabled = '0' where invID = $sqlInvID<br>");
    if ($simulate eq "0") {
     $sqlcur = $dbh->prepare("UPDATE tblNodesInventory SET enabled = '0' where invID ='" . $sqlInvID . "';" );
@@ -219,6 +266,9 @@ if ($granted) {
    $sqlcur = $dbh->prepare("UPDATE tblState SET statechange = '1' where stateID ='1';");
    $sqlcur->execute;
   } 
+  
+  print "Services IPv4: $srvCnt4<br>\n";
+  print "Services IPv6: $srvCnt6<br>\n";
   print "Turn-Off Proces Complete!\n";
  }    #if ($tparam =~ m/^turnoff=(\d*)/){  
 
@@ -232,29 +282,64 @@ if ($granted) {
  	}	
 
 	$showid=$1;
-  $sqlalias = $dbh->prepare("SELECT alias,realip FROM tblResources where resID = '" . $showid . "';" ); 
+  $sqlalias = $dbh->prepare("SELECT alias,realip,realip6 FROM tblResources where resID = '" . $showid . "';" ); 
   $sqlalias->execute ; #Get Inventory and ID's
-  (($sqlAlias,$sqlIP)=$sqlalias->fetchrow_array);
+  (($sqlAlias,$sqlIP,$sqlIP6)=$sqlalias->fetchrow_array);
   $myIP=$sqlIP;
+  $myIP6=$sqlIP6;
   $sqlinv = $dbh->prepare("SELECT invID,weight,nodeID,link,port,active,method,weight FROM tblNodesInventory where resID = '" . $showid . "';" ); 
   $sqlinv->execute ; #Get Inventory and ID's
   while (($sqlInvID,$sqlInvWeight,$sqlNodeID,$sqlLink,$sqlIPort,$sqlactive,$sqlmethod,$sqlweight)=$sqlinv->fetchrow_array) {
-   $sqlnoden = $dbh->prepare("SELECT service,vip FROM tblNodes where nodeid = '" . $sqlNodeID . "';" ); 
+   $sqlnoden = $dbh->prepare("SELECT service,vip,vip6 FROM tblNodes where nodeid = '" . $sqlNodeID . "';" ); 
    $sqlnoden->execute ; 
-   ($NodeService,$NodeVip)=$sqlnoden->fetchrow_array ;
+   ($NodeService,$NodeVip,$NodeVip6)=$sqlnoden->fetchrow_array ;
    if ($NodeService !~ /fwm/i) {
-    $mstring = "$lvscmd -a -t $NodeVip -r $sqlIP:$sqlIPort -$sqlmethod -w $sqlweight";
+    if ($NodeVip) {
+     $mstring = "$lvscmd -a -t $NodeVip -r $sqlIP:$sqlIPort -$sqlmethod -w $sqlweight";
+     $srvCnt4++;
+    } 
+
+    if ($NodeVip6) {
+     if ($NodeVip6=~/(.*):(\d+)$/) {  #
+      $mstring6 = "$lvscmd -a -t [$1]:$2 -r [$sqlIP6]:$sqlIPort -$sqlmethod -w $sqlweight";
+      $srvCnt6++;
+     } 
+    } 
    } else {
-    $mstring = "$lvscmd -a -f $NodeVip -r $sqlIP -$sqlmethod -w $sqlweight";	
+    if ($NodeVip) {
+     $mstring = "$lvscmd -a -f $NodeVip -r $sqlIP:$sqlIPort -$sqlmethod -w $sqlweight";	
+     $srvCnt4++;
+    } 
+    
+    if ($NodeVip6) { 
+     #$mstring6 = "$lvscmd -d -f $NodeVip6 -6 -r [$sqlIP6]:$sqlIPort";	 #2.0.5
+     $mstring6 = "$lvscmd -a -f $NodeVip6 -6 -r [$sqlIP6]:$sqlIPort -$sqlmethod -w $sqlweight";	
+     $srvCnt6++;
+    }  
    }	
    if ($sqlactive eq "0") {
     &PrintHTMLMessage("WARNING: Host $sqlIP:$sqlIPort is in down state. <BR>");
    }
-   if ($simulate eq "0") {
+
+   if ($mstring) {
     &PrintHTMLMessage ("Apply: $mstring <BR>");
-    `$mstring`;
+    &lvslog(2,"Turn on service by: $mstring",$curuser);
    } 
-   &lvslog(2,"Turn on service by: $mstring",$curuser);
+   if ($mstring6) {
+   	&PrintHTMLMessage ("Apply: $mstring6 <BR>");
+   	&lvslog(2,"Turn on service by: $mstring6",$curuser);
+   } 
+
+
+   if ($simulate eq "0") {
+    if ($mstring) {
+     `$mstring`;
+    } 
+    if ($mstring6) {
+     `$mstring6`;
+    } 
+   } 
+
    if ($simulate eq "0") {
     $sqlcur = $dbh->prepare("UPDATE tblNodesInventory SET enabled = '1', active='1' where invID ='" . $sqlInvID . "';" );
     $sqlcur->execute;
@@ -281,6 +366,9 @@ if ($granted) {
     $sqlcur = $dbh->prepare("UPDATE tblState SET statechange = '1' where stateID ='1';");
     $sqlcur->execute;
    } 
+  print "Services IPv4: $srvCnt4<br>\n";
+  print "Services IPv6: $srvCnt6<br>\n";
+
    print "Turn-On Proces Complete!\n";
  }    #if ($tparam =~ m/^turnoff=(\d*)/){  
 
@@ -297,30 +385,68 @@ if ($granted) {
  	}	
 
 	$showid=$1;
-  $sqlalias = $dbh->prepare("SELECT alias,realip FROM tblResources where resID = '" . $showid . "';" ); 
+  $sqlalias = $dbh->prepare("SELECT alias,realip,realip6 FROM tblResources where resID = '" . $showid . "';" ); 
   $sqlalias->execute ; #Get Inventory and ID's
-  (($sqlAlias,$sqlIP)=$sqlalias->fetchrow_array);
+  (($sqlAlias,$sqlIP,$sqlIP6)=$sqlalias->fetchrow_array);
   $myIP=$sqlIP;
+  $myIP6=$sqlIP6;
   $sqlinv = $dbh->prepare("SELECT invID,weight,nodeID,link,port,active,method,weight,enabled FROM tblNodesInventory where resID = '" . $showid . "';" ); 
   $sqlinv->execute ; #Get Inventory and ID's
   while (($sqlInvID,$sqlInvWeight,$sqlNodeID,$sqlLink,$sqlIPort,$sqlactive,$sqlmethod,$sqlweight,$sqlenabled)=$sqlinv->fetchrow_array) {
-   $sqlnoden = $dbh->prepare("SELECT service,vip FROM tblNodes where nodeid = '" . $sqlNodeID . "';" ); 
+   $sqlnoden = $dbh->prepare("SELECT service,vip,vip6 FROM tblNodes where nodeid = '" . $sqlNodeID . "';" ); 
    $sqlnoden->execute ; 
-   ($NodeService,$NodeVip)=$sqlnoden->fetchrow_array ;
+   ($NodeService,$NodeVip,$NodeVip6)=$sqlnoden->fetchrow_array ;
    if ($NodeService !~ /fwm/i) {
-    $mstring = "$lvscmd -e -t $NodeVip -r $sqlIP:$sqlIPort -$sqlmethod -w $sqlweight";
+    
+    if (($NodeVip) and ($sqlIP)){
+     $mstring = "$lvscmd -e -t $NodeVip -r $sqlIP:$sqlIPort -$sqlmethod -w $sqlweight";
+     $srvCnt4++;
+    }
+    $hdeb.="$NodeVip6-$sqlIP6<br>";
+    if (($NodeVip6) and ($sqlIP6)){
+     if ($NodeVip6=~/(.*):(\d+)$/) {  #
+      $mstring6 = "$lvscmd -e -t [$1]:$2 -r [$sqlIP6]:$sqlIPort -$sqlmethod -w $sqlweight";
+      $srvCnt6++;
+     } 
+    }
+    
+    
+     
    } else {
-    $mstring = "$lvscmd -e -f $NodeVip -r $sqlIP -$sqlmethod -w $sqlweight";	
+   	if ($NodeVip) {
+     $mstring = "$lvscmd -e -f $NodeVip -r $sqlIP -$sqlmethod -w $sqlweight";	
+     &lvslog(2,"Weight up service by: $mstring",$curuser);
+    } 
+  
+   	if ($NodeVip6) {
+     $mstring6 = "$lvscmd -e -f $NodeVip6 -r [$sqlIP] -$sqlmethod -w $sqlweight";	
+     &lvslog(2,"Weight up service by: $mstring6",$curuser);
+    } 
+    
+  
    }	
    if ($sqlenabled eq "1" ) {
     if ($sqlactive ne "1") {
     	&PrintHTMLMessage("WARNING: Host $sqlIP:$sqlIPort is in down state, continiue anyway. <BR>");
     }        #if ($sqlactive eq "1")
-    &PrintHTMLMessage ("Apply: $mstring <BR>");
-    if ($simulate eq "0") {
-     `$mstring`;
+
+    if ($mstring) {
+     &PrintHTMLMessage ("Apply: $mstring <BR>");
     } 
-    &lvslog(2,"Weight up service by: $mstring",$curuser);
+    if ($mstring6) {
+     &PrintHTMLMessage ("Apply: $mstring6 <BR>");
+    } 
+    
+
+    if ($simulate eq "0") {
+     if ($mstring) {
+      `$mstring`;
+     } 
+     if ($mstring6) {
+      `$mstring6`;
+     } 
+    }
+    
     &PrintHTMLMessage(" SQL: UPDATE tblNodesInventory SET weightdown = '0' where invID ='" . $sqlInvID . "' <BR>");
     if ($simulate eq "0") {
      $sqlcur = $dbh->prepare("UPDATE tblNodesInventory SET weightdown = '0' where invID ='" . $sqlInvID . "';" );
@@ -330,6 +456,8 @@ if ($granted) {
     &PrintHTMLMessage("SKIP (DISABLED) Apply: $mstring <BR>");     
    }         #if ($sqlenabled eq "1" ) 
   }          #while (my($sqlInvID,$sqlInvWeight,$sqlNodeID,$sqlLink,$sqlIPort)=$sqlinv->fetchrow_array) 
+  print "Services IPv4: $srvCnt4<br>\n";
+  print "Services IPv6: $srvCnt6<br>\n";
   print "Drain-Up Proces Complete!\n";
  }           #if ($tparam =~ m/^wu=(\d*)/){  
 
@@ -343,30 +471,66 @@ if ($granted) {
  	 &PrintHTMLMessage("Simualtation Mode: !!<BR>");     
  	}	
 	$showid=$1;
-  $sqlalias = $dbh->prepare("SELECT alias,realip,alias FROM tblResources where resID = '" . $showid . "';" ); 
+  $sqlalias = $dbh->prepare("SELECT alias,realip,realip6 FROM tblResources where resID = '" . $showid . "';" ); 
   $sqlalias->execute ; #Get Inventory and ID's
-  (($sqlAlias,$sqlIP)=$sqlalias->fetchrow_array);
+  (($sqlAlias,$sqlIP,$sqlIP6)=$sqlalias->fetchrow_array);
   $myIP=$sqlIP;
+  $myIP6=$sqlIP6;
   $myHost=$sqlAlias;
   $sqlinv = $dbh->prepare("SELECT invID,weight,nodeID,link,port,active,method,weight,automovepoolid FROM tblNodesInventory where resID = '" . $showid . "';" ); 
   $sqlinv->execute ; #Get Inventory and ID's
   while (($sqlInvID,$sqlInvWeight,$sqlNodeID,$sqlLink,$sqlIPort,$sqlactive,$sqlmethod,$sqlweight,$sqlPoolID)=$sqlinv->fetchrow_array) {
-   $sqlnoden = $dbh->prepare("SELECT service,vip FROM tblNodes where nodeid = '" . $sqlNodeID . "';" ); 
+   $sqlnoden = $dbh->prepare("SELECT service,vip,vip6 FROM tblNodes where nodeid = '" . $sqlNodeID . "';" ); 
    $sqlnoden->execute ; 
-   ($NodeService,$NodeVip)=$sqlnoden->fetchrow_array ;
+   ($NodeService,$NodeVip,$NodeVip6)=$sqlnoden->fetchrow_array ;
+   
    if ($NodeService !~ /fwm/i) {
-   	
-    $mstring = "$lvscmd -e -t $NodeVip -r $sqlIP:$sqlIPort -$sqlmethod -w 0";
-    $mdstring = "$lvscmd -d -t $NodeVip -r $sqlIP:$sqlIPort";
+   	if (($NodeVip) and ($sqlIP)){
+     $mstring = "$lvscmd -e -t $NodeVip -r $sqlIP:$sqlIPort -$sqlmethod -w 0";
+     $srvCnt4++;
+    } 
+    
+    if (($NodeVip6) and ($sqlIP6)){
+     if ($NodeVip6=~/(.*):(\d+)$/) {  
+      $mstring6 = "$lvscmd -e -t [$1]:$2 -r [$sqlIP6]:$sqlIPort -$sqlmethod -w 0";
+      $srvCnt6++;
+     } 
+    }
+    
+    $mdstring = "$lvscmd -d -t $NodeVip -r $sqlIP:$sqlIPort";  #2.0.5 - leave untouched
    } else {
-    $mstring = "$lvscmd -e -f $NodeVip -r $sqlIP -$sqlmethod -w 0";	
-    $mdstring = "$lvscmd -d -f $NodeVip -r $sqlIP";	
+    
+    if ($sqlIP) {
+     $mstring = "$lvscmd -e -f $NodeVip -r $sqlIP -$sqlmethod -w 0";	
+    } 
+
+    if ($sqlIP6) {
+     $mstring6 = "$lvscmd -e -f $NodeVip6 -r [$sqlIP] -$sqlmethod -w 0";	
+    } 
+    
+    
+    $mdstring = "$lvscmd -d -f $NodeVip -r $sqlIP";	#2.0.5 - leave untouched
    }	
-   &PrintHTMLMessage("Apply: $mstring <BR>");
+
+    if ($mstring){
+     &PrintHTMLMessage("Apply: $mstring <BR>");
+     &lvslog(2,"Weight down service by: $mstring",$curuser);
+    } 
+    if ($mstring6){
+     &PrintHTMLMessage("Apply: $mstring6 <BR>");
+     &lvslog(2,"Weight down service by: $mstring6",$curuser);
+    } 
+   
    if ($simulate eq "0") {
-    `$mstring`;
-   } 
-   &lvslog(2,"Weight down service by: $mstring",$curuser);
+    if ($mstring){
+     `$mstring`;
+    } 
+    if ($mstring6){
+     `$mstring6`;
+    } 
+   }
+   
+   
    &PrintHTMLMessage(" SQL: UPDATE tblNodesInventory SET weightdown = '1' where invID ='" . $sqlInvID . "' <BR>");
    if ($simulate eq "0") {
     $sqlcur = $dbh->prepare("UPDATE tblNodesInventory SET weightdown = '1' where invID ='" . $sqlInvID . "';" );
@@ -462,6 +626,8 @@ if ($granted) {
    ###########  DONE AUTOMOVE  ##############
    ##########################################
   }   #while (my($sqlInvID,$sqlInvWeight,$sqlNodeID,$sqlLink,$sqlIPort)=$sqlinv->fetchrow_array) 
+  print "Services IPv4: $srvCnt4<br>\n";
+  print "Services IPv6: $srvCnt6<br>\n";
   print "Drain-Down Process Complete!\n";
  }    #if ($tparam =~ m/^wd=(\d*)/)  
 } else {     #if ($granted) 
@@ -692,7 +858,12 @@ my $ret='
 </body>
 </html>
 ';	                
- return $ret;		
+ 
+ if ($prtDeb) {
+  return $hdeb.$ret;		
+ } else {
+ 	return $ret;		
+ } 
 }
 
 sub chkuser {
