@@ -561,7 +561,7 @@ sub HTMLInnerTableStart{
             <td align="right" valign="bottom"><img src="/images/t1_top-gray-lft.gif" height="32" width="11"></td>
             <td class="UeberschrBorderBottom" align="left" height="32" >Server</td>
             <td class="UeberschrBorderBottom" valign="bottom" width="19"><img src="/images/separator-gray_7x32.gif" height="32" width="7"></td>
-            <td colspan="7" class="UeberschrBorderBottom" align="right"><a href="'.$server.'/mylvsaddserver.pl?mode=add"><img src="/images/buttons/add.gif" alt="Add a new server" border="0"></a></td>
+            <td colspan="7" class="UeberschrBorderBottom" align="right"><a href="'.'/mylvsaddserver.pl?mode=add"><img src="/images/buttons/add.gif" alt="Add a new server" border="0"></a></td>
             <td align="left" height="32" valign="bottom" width="11"><img src="/images/t1_top-gray-rt.gif" height="32" width="11"></td>
           </tr>
           <!-- Grau unterlegter Aussenrahmen Oben -->
