@@ -7,7 +7,7 @@
 
 #20090512 - 2.0.1.9 Fix Node deletion
 #20100503 add new mode deleteassign
-
+#20170517 add v6 - 2.0.5
 #####################################################################
 #####################################################################
 
@@ -15,6 +15,8 @@ use warnings;
 use strict;
 use DBI;
 use POSIX;
+use Net::IP ':PROC'; #2.0.5 -  #http://stackoverflow.com/questions/27398691/ip-database-from-ip2location-and-convert-ipv4-to-ipv6-in-perl -  apt-get install libnet-ip-perl
+# apt-get install libnet-ip-perl
 
 
 ####################### CONFIGURATION #######################
@@ -41,7 +43,7 @@ my $retscriptname="mylvseditnode.pl";
 #Remember this:   <td colspan="2" align="left" valign="top"><a href="javascript:history.back()"><img src="/images/back-tab.gif" alt="previous page" width="63" height="29" border="0"></a></td>
 
 ####################### CONFIGURATION #######################
-my $version = "2.0.1.9";
+my $version = "2.0.5";
 
 #Get Apache Environs
 my $tparam=$ENV{QUERY_STRING};
@@ -69,7 +71,8 @@ $dbhn = DBI->connect("DBI:mysql:$database:$servername:3306",$sqluser,$sqlpasswor
 $tparam=URLDecode($tparam);
 my ($nodename,$nodeid,$vip,$protocol,$schedule,$port,$persistance,$enabled,$monitor,$chktoken,$chkinvtoken,$id,$mode,$sqlstat,$sql,$sqlstatN,$sqlN,$dinc);
 my ($ndlink,$ndweight,$ndmethod,$ndcommand,$ndport,$ndsnmp,$ndenabled,$ndpoolid,$ndid,$ndresid,$ndnodeid);
-   
+my ($vip6,$ipinvalid,$tmpvip,$tmpvip6); #2.0.5   
+
 
 $GlobalTxt="Node Manager: Save Assignment";
 print &HTMLStartOutsideTable;
@@ -95,7 +98,8 @@ print &HTMLStartInsideTable;
    foreach (@reqTokens){
  	  if (!/\'|\;|\(|\)|\"|\`|\*|where\s+|truncate\s+|\s+from\s+|\select\s+|delete\s+|\s+as\s+/){  #No SQL Injection
 	   if (/^nodename\=*([^ ]*)/i){$nodename=$1;}	 
-	   if (/^ip\=*([^ ]*)/i){$vip=$1;}	 
+	   if (/^ipv4\=*([^ ]*)/i){$vip=$1;}	  #2.0.5
+	   if (/^ipv6\=*([^ ]*)/i){$vip6=$1;}	  #2.0.5
 	   if (/^protocol\=*([^ ]*)/i){$protocol=$1;}	 
 	   if (/^schedule\=*([^ ]*)/i){$schedule=$1;}	 
 	   if (/^port\=*([^ ]*)/i){$port=$1;}	 
@@ -116,17 +120,39 @@ print &HTMLStartInsideTable;
    if ($monitor =! /on/i){
    	$monitor=1;
    } else {
-   	$monitor=0;
+   	$monitor=0;	
    }	
 
    #Check all tokens to be set
    #$port=undef;
-   if( ((!$nodename) or (!$vip) or (!$protocol) or (!$schedule) or (!$port) or ((!$id) and ($mode ne "add") )) and (lc($mode) ne "delete")  and (lc($mode) ne "deleteassign") ){
-   	print "Data Incomplete -$nodename-$vip-$protocol-$schedule-$port-$persistance-$enabled-$monitor-$id- !!\n";
+   
+   if ($protocol!~/fwm/i){
+    if( ((!$nodename) or ((!$vip) and (!$vip6))  or (!$schedule) and (!$port) and (!$protocol) or ((!$id) and ($mode ne "add") )) and (lc($mode) ne "delete")  and (lc($mode) ne "deleteassign") ){
+   	 print "Data Incomplete -$nodename-$vip-$protocol-$schedule-$port-$persistance-$enabled-$monitor-$id- !!<br>\n";
+   	 $dinc=1;
+    } else {
+     print "Data Complete<BR>";	
+    }
+   } else { #fwmark
+    if( ((!$nodename) or ((!$vip) and (!$vip6))  or (!$schedule) and (!$protocol) or ((!$id) and ($mode ne "add") )) and (lc($mode) ne "delete")  and (lc($mode) ne "deleteassign") ){
+   	 print "Data Incomplete -$nodename-$vip-$protocol-$schedule-$port-$persistance-$enabled-$monitor-$id- !! <br>\n";
+   	 $dinc=1;
+    } else {
+     print "Data Complete<BR>";	
+    }
+   } 
+    
+    
+   if ((!checkIP($vip) and ($protocol!~/fwm/i)) and ($vip)){
+   	print "Syntax error, check IPv4 address format<BR>";	
    	$dinc=1;
-   } else {
-    print "Data Complete<BR>";	
    }
+
+   if ((!checkIP($vip6)) and ($protocol!~/fwm/i) and ($vip6) ){
+   	print "Syntax error, check IPv6 address format<BR>";	
+   	$dinc=1;
+   }
+
   }
 
   if ((lc($mode) eq "nodeinvedit") or (lc($mode) eq "nodeinvadd") or (lc($mode) eq "nodeinvdel") ){  
@@ -210,12 +236,30 @@ print &HTMLStartInsideTable;
   if (!$monitor){$monitor=0;}
   if (!$persistance){$persistance=0;}
   
-
-  if (lc($protocol) ne "fwm"){
-   $vip.=":".$port;
+  if ($protocol!~/fwm/i){
+   if ($vip) {
+   	$tmpvip="', vip='".$vip.":".$port;
+   }
+   if ($vip6) {
+   	$tmpvip6="', vip6='".$vip6.":".$port;
+   } else {
+   	$tmpvip6="', vip6='";
+   }
+  } else {
+   if ($vip) {
+   	$tmpvip="', vip='".$vip;
+   }
+     	
+   if ($vip6) {
+   	$tmpvip6="', vip6='".$vip6;
+   } else {
+   	 $tmpvip6="', vip6='";
+   }
+  	
   }
 
 
+  #print "Extra debug: $tmpvip $tmpvip6<br>";
 
   if ((lc($mode) eq "nodeinvedit") and ($chkinvtoken) and ($id) and not (lc($mode) eq "add") and not (lc($mode) eq "delete")) {
     &PrintHTMLMessage("Update tblNodesInventory");
@@ -223,7 +267,10 @@ print &HTMLStartInsideTable;
 
   if (($chktoken) and ($id) and not (lc($mode) eq "delete") and not (lc($mode) eq "nodeinvedit") and not (lc($mode) eq "nodeinvadd") and not (lc($mode) eq "nodeinvdel") and not (lc($mode) eq "deleteassign") and not ($dinc) ){
    &PrintHTMLMessage("Update Table - $mode<BR>");       
-   $sqlstat = ("Update tblNodes set Name = '".$nodename."', enabled='".$enabled."', service='".lc($protocol)."', scheduler='".lc($schedule)."', vip='".$vip."', persistent='".$persistance."', monitor='".$monitor."' where nodeid ='".$id."';"); 
+
+   
+   
+   $sqlstat = ("Update tblNodes set Name = '".$nodename."', enabled='".$enabled."', service='".lc($protocol)."', scheduler='".lc($schedule).  $tmpvip .  "', persistent='".$persistance."', monitor='".$monitor.$tmpvip6."' where nodeid ='".$id."';"); 
    #my $sql = $dbh->prepare($sqlstat);
    &PrintHTMLMessage("$sqlstat<BR>");   
    if ($simulate ne 1){
@@ -243,6 +290,31 @@ print &HTMLStartInsideTable;
    } else {
    
    
+  if ($protocol!~/fwm/i){
+   if ($vip) {
+   	$tmpvip="$vip:$port";
+   }
+   if ($vip6) {
+   	$tmpvip6="$vip6:$port";
+   } else {
+   	$tmpvip6="";
+   }
+  } else {
+   if ($vip) {
+   	$tmpvip="$vip";
+   }
+     	
+   if ($vip6) {
+   	$tmpvip6="$vip6:$port";
+   }
+  	
+  }
+
+   
+   
+   
+   
+   
     #Get ID!
     $sqlstat = ("Select NodeID from tblNodes order by NodeID desc limit 1;"); 
     $sql = $dbh->prepare($sqlstat);
@@ -251,7 +323,9 @@ print &HTMLStartInsideTable;
     $id=$sqlID+1;
     
     &PrintHTMLMessage("Get new ID = $id<BR>");
-    $sqlstat = ("Insert into tblNodes (nodeID,enabled,Name,scheduler,service,vip,persistent,monitor) values ('".$id."','".$enabled."','".$nodename."','".$schedule."','".$protocol."','".$vip."','".$persistance."','".$monitor."');");
+    #$vip6
+    #$vip
+    $sqlstat = ("Insert into tblNodes (nodeID,enabled,Name,scheduler,service,vip,persistent,monitor,vip6) values ('".$id."','".$enabled."','".$nodename."','".$schedule."','".$protocol."','".$tmpvip."','".$persistance."','".$monitor."','".$tmpvip6."');");
     &PrintHTMLMessage("$sqlstat<BR>");
     if ($simulate ne 1){
      my $rv  = $dbh->do($sqlstat);
@@ -586,4 +660,37 @@ sub PrintHTMLMessage {
 	if ($HTMLLVSView){
 	 print "$_[0]\n";
 	} 
-}
\ No newline at end of file
+}
+
+
+
+
+sub checkIP {  #2.0.5
+ #my $ipaddr='fde2:8acd:e9d3::22011';
+ $ipinvalid=undef;
+ #print "Check IP  $_[0] <BR>";	 
+ my $ip = new Net::IP ($_[0]) or &errorprint(Net::IP::Error());
+
+ #$ip_num=$ip->intip();
+ #$ipaddr=$ip->ip();
+ #$ipver=$ip->version();
+ #$iptype=$ip->iptype();
+ if (!$ipinvalid) {
+ 	#if ($opt_v) {
+  # print ("$_[0] = IP Version: ".$ip->version()." (VALID)\n");
+  # #print ("Size: ".$ip->size()."\n");
+  # #print ("Len : ".$ip->prefixlen()."\n");
+  # #print ("Type: ".$ip->iptype()."\n");
+  #} 
+  return 1;
+ }
+ return undef; 
+}
+
+
+sub errorprint {  #2.0.5
+	#if ($opt_v) {
+	# print "$_[0]\n";
+	#} 
+	$ipinvalid=1;
+}
