@@ -1,6 +1,5 @@
 #!/usr/bin/perl 
 
-
 ##################################
 #Manage Server Add / Edit / Delete
 #Parameter:
@@ -10,6 +9,11 @@
 ##################################
 
 
+#2.0.3 - Add visible and mac adress options - may2011
+#2.0.4 - Add Wakup and Shutdown-Jul2011
+#2.0.5 - Add IP6 support - May 2017
+# To do: Add IP validly check for v4 and v6
+
 use warnings;
 use strict;
 use DBI;
@@ -39,10 +43,9 @@ my $retscriptname="mylvsmgrsrv.pl";
 ####################### CONFIGURATION #######################
 
 
-#2.0.3 - Add visible and mac adress options - may2011
-#2.0.4 - Add Wakup and Shutdown-Jul2011
+my $version = "2.0.5";
+
 
-my $version = "2.0.4";
 
 #Get Apache Environs
 my $tparam=$ENV{QUERY_STRING};
@@ -62,9 +65,10 @@ $dbh = DBI->connect("DBI:mysql:$database:$servername:3306",$sqluser,$sqlpassword
 $dbhn = DBI->connect("DBI:mysql:$database:$servername:3306",$sqluser,$sqlpassword); 
 $tparam=URLDecode($tparam);
 my ($ndid,$ndresid,$ndnodeid,$chktoken,$id,$mode,$sqlstat,$sql);
-my ($ndenabled,$ndalias,$ndip,$ndmrtg,$ndcmd);
+my ($ndenabled,$ndalias,$ndipv4,$ndmrtg,$ndcmd);
 my ($ndvisible,$ndmac,$errmsg); #2.0.3
 my ($ndshut,$ndwake);           #2.0.4
+my ($ndipv6);										#2.0.5
 my @reqTokens = split(/&/,$tparam);
   foreach (@reqTokens){ #Get Mode Fisrt !!!
  	 if (!/\'|\;|\(|\)|\"|\`|\*|where\s+|truncate\s+|\s+from\s+|\select\s+|delete\s+|\s+as\s+/){  #No SQL Injection
@@ -104,7 +108,8 @@ print &HTMLStartInsideTable;
    	 if (/^shutid=*([^ ]*)/i){$ndshut=$1;}	 
    	 if (/^wakeid=*([^ ]*)/i){$ndwake=$1;}	 
    	 if (/^servername\=*([^ ]*)/i){$ndalias=$1;}	 
-   	 if (/^ip\=*([^ ]*)/i){$ndip=$1;}	 
+   	 if (/^ipv4\=*([^ ]*)/i){$ndipv4=$1;}	 
+   	 if (/^ipv6\=*([^ ]*)/i){$ndipv6=$1;}	 #2.0.5
    	 if (/^mrtg\=*([^ ]*)/i){$ndmrtg=$1;}	 
    	 if (/^command\=*([^ ]*)/i){$ndcmd=$1;}	 
    	 #if (/^command\=(\d*)/i){$ndcmd=$1;}	 
@@ -129,7 +134,7 @@ print &HTMLStartInsideTable;
   #lvs2servermanager !
   if (($mode eq "add") and (!$ndid) and not (lc($mode) eq "edit") and not (lc($mode) eq "delete") ){
    &PrintHTMLMessage("Insert Record (Add Server)<BR>");
-   if (((!$ndenabled) and ($ndenabled ne 0)) or (!$ndalias) or (!$ndip) or (!$ndmrtg) or ((!$ndcmd) and ($ndcmd ne 0))){
+   if (((!$ndenabled) and ($ndenabled ne 0)) or (!$ndalias) or (!$ndipv4) or (!$ndmrtg) or ((!$ndcmd) and ($ndcmd ne 0))){
    	&PrintHTMLMessage("Error: Data not complete<BR>");
    } else {
     #Get ID!
@@ -139,7 +144,7 @@ print &HTMLStartInsideTable;
     (my($sqlID)=$sql->fetchrow_array);
     $id=$sqlID+1;
     &PrintHTMLMessage("Get new ID = $id<BR>");
-    $sqlstat = ("Insert into tblResources (resID,enabled,alias,realip,cmd_reboot_id,mrtg_link,visible,mac) values ('".$id."','".$ndenabled."','".$ndalias."','".$ndip."','".$ndcmd."','".$ndmrtg."','1','".$ndmrtg."');");
+    $sqlstat = ("Insert into tblResources (resID,enabled,alias,realip,cmd_reboot_id,mrtg_link,visible,mac,realip6) values ('".$id."','".$ndenabled."','".$ndalias."','".$ndipv4."','".$ndcmd."','".$ndmrtg."','1','".$ndmrtg."','".$ndipv6."');");
     &PrintHTMLMessage("$sqlstat<BR>");
     if ($simulate ne 1){
      my $rv  = $dbh->do($sqlstat);
@@ -158,7 +163,7 @@ print &HTMLStartInsideTable;
   #lvs2servermanager - edit !
   if (($mode eq "edit") and ($ndid) and not (lc($mode) eq "add") and not (lc($mode) eq "delete") ){
    &PrintHTMLMessage("Update Record (Edit Mode) <BR>");
-   if (((!$ndenabled) and ($ndenabled ne 0)) or (!$ndalias) or (!$ndip) or (!$ndmrtg) or ((!$ndcmd) and ($ndcmd ne 0))){
+   if (((!$ndenabled) and ($ndenabled ne 0)) or (!$ndalias) or ( (!$ndipv4) and (!$ndipv6) ) or (!$ndmrtg) or ((!$ndcmd) and ($ndcmd ne 0))){
    	&PrintHTMLMessage("Error: Data not complete<BR>");
    } else {
     
@@ -176,7 +181,7 @@ print &HTMLStartInsideTable;
       if ($SInvID){
      	 $errmsg.="==>> Error: Services are found on this server, please switch them off first <<==<BR><BR>";
       } else {
-       $sqlstat = ("Update tblResources set enabled='".$ndenabled."', alias='".$ndalias."', realip='".$ndip."', cmd_reboot_id='".$ndcmd."', mrtg_link='".$ndmrtg."', visible = '".$ndvisible."', mac = '". $ndmac . "', cmd_shutdown_id = '". $ndshut . "', cmd_wakeup_id = '". $ndwake . "' where resID='".$ndid."';"); 
+       $sqlstat = ("Update tblResources set enabled='".$ndenabled."', alias='".$ndalias."', realip='".$ndipv4."', cmd_reboot_id='".$ndcmd."', mrtg_link='".$ndmrtg."', visible = '".$ndvisible."', mac = '". $ndmac . "', cmd_shutdown_id = '". $ndshut . "', cmd_wakeup_id = '". $ndwake . ",realip6='".$ndipv6."' where resID='".$ndid."';"); 
        
        
        
@@ -185,7 +190,7 @@ print &HTMLStartInsideTable;
       }
      } else {    
       
-      $sqlstat = ("Update tblResources set enabled='".$ndenabled."', alias='".$ndalias."', realip='".$ndip."', cmd_reboot_id='".$ndcmd."', mrtg_link='".$ndmrtg."', visible = '".$ndvisible."', mac = '". $ndmac . "', cmd_shutdown_id = '". $ndshut . "', cmd_wakeup_id = '". $ndwake . "' where resID='".$ndid."';"); 
+      $sqlstat = ("Update tblResources set enabled='".$ndenabled."', alias='".$ndalias."', realip='".$ndipv4."', cmd_reboot_id='".$ndcmd."', mrtg_link='".$ndmrtg."', visible = '".$ndvisible."', mac = '". $ndmac . "', cmd_shutdown_id = '". $ndshut . "', cmd_wakeup_id = '". $ndwake."', realip6='".$ndipv6."' where resID='".$ndid."';"); 
       &PrintHTMLMessage("$sqlstat<BR>");
      }
       
