@@ -36,6 +36,9 @@ use Data::Dumper;
 my $conffile="/etc/mylvs/mylvs.conf.xml";
 my ($servername,$database,$sqluser,$sqlpassword,$lvscmd,$bkupdatabase,$bkupsqluser,$bkupsqlpassword,$bkupservername,$ActiveWarning,$InActiveWarning,$HTTP_ERR,$HTTP_WARN,$simulate,$maxcount,$backuppath,$restoreapp,$backupapp,$SuppressedAddress,$HTMLLVSView,$bkupreplcommand,$sitelogo);
 &getconfig;
+my $hdeb; #2.0.5;
+my $ipv6cnt=0;
+my $ipv4cnt=0;
 ############
 
 
@@ -235,7 +238,7 @@ if ($granted) {
 
 	my ($dbh,$Hostname);
 	$dbh = DBI->connect("DBI:mysql:$database:$servername:3306",$sqluser,$sqlpassword); 
-  my $sqlname = $dbh->prepare("SELECT alias FROM tblResources where realip like '%".$value."%' ;" );
+  my $sqlname = $dbh->prepare("SELECT alias FROM tblResources where realip like '%".$value."%' or realip6 like '%".$value."%' ;" );
   $sqlname->execute ; 
   (($Hostname)=$sqlname->fetchrow_array);
   
@@ -283,7 +286,7 @@ if ($granted) {
               <tr>
                 <td width="11" height="29" align="right"><img src="/images/t1_zeile-lft.gif" alt="1" width="11" height="29"></td>
                 <td height="29" background="/images/t1_zeile-hg.gif" class="fontblacksmall"><img src='. $img_flag .' title="Sender from: '.$country_name.'"></td>
-                <td width="8" height="29" background="/images/t1_zeile-hg.gif"><img src="/images/t1_separator-zeile.gif" alt="1" width="7" height="29"></td>
+  	              <td width="8" height="29" background="/images/t1_zeile-hg.gif"><img src="/images/t1_separator-zeile.gif" alt="1" width="7" height="29"></td>
                 
                 
                 
@@ -447,7 +450,7 @@ my $ret='
                       <td width="58" allign="left" vallign="center">&nbsp;</td>
                       <td width="109" allign="left" vallign="center">&nbsp;</td>
                       <td width="105" class="fontblackblold" allign="left" vallign="center">Total Stats </td>
-                      <td width="84" class="fontblackblold" allign="left" vallign="center">Anount</td>
+                      <td width="84" class="fontblackblold" allign="left" vallign="center">Amount</td>
                     </tr>
                     <tr>
                       <td class="fontblack" allign="left" vallign="center">FIN_WAIT</td>
@@ -470,24 +473,24 @@ my $ret='
                       <td class="fontblack" allign="left" vallign="center">'.$ESTABLISHED.'</td>
                       <td class="fontblack" allign="left" vallign="center">&nbsp;</td>
                       <td class="fontblack" allign="left" vallign="center">&nbsp;</td>
-                      <td class="fontblack" allign="left" vallign="center">&nbsp;</td>
-                      <td class="fontblack" allign="left" vallign="center">&nbsp;</td>
+                      <td class="fontblack" allign="left" vallign="center"><span class="fontblackblold">Protocol (All)</span></td>
+                      <td class="fontblack" allign="left" vallign="center"><span class="fontblackblold">Amount</span></td>
                     </tr>
                     <tr>
                       <td class="fontblack" allign="left" vallign="center">CLOSE</td>
                       <td class="fontblack" allign="left" vallign="center">'.$CLOSED.'</td>
                       <td class="fontblack" allign="left" vallign="center">&nbsp;</td>
                       <td class="fontblack" allign="left" vallign="center">&nbsp;</td>
-                      <td class="fontblack" allign="left" vallign="center">&nbsp;</td>
-                      <td class="fontblack" allign="left" vallign="center">&nbsp;</td>
+                      <td class="fontblack" allign="left" vallign="center">IPv4</td>
+                      <td class="fontblack" allign="left" vallign="center">'.$ipv4cnt.'</td>
                     </tr>
                     <tr>
                       <td class="fontblack" allign="left" vallign="center">SYN_RECV</td>
                       <td class="fontblack" allign="left" vallign="center">'.$SYN_RECV.'</td>
                       <td class="fontblack" allign="left" vallign="center">&nbsp;</td>
                       <td class="fontblack" allign="left" vallign="center">&nbsp;</td>
-                      <td class="fontblack" allign="left" vallign="center">&nbsp;</td>
-                      <td class="fontblack" allign="left" vallign="center">&nbsp;</td>
+                      <td class="fontblack" allign="left" vallign="center">IPv6</td>
+                      <td class="fontblack" allign="left" vallign="center">'.$ipv6cnt.'</td>
                     </tr>
                   </tbody>
               </table></td>
@@ -641,6 +644,7 @@ my $ret='
 </body>
 </html>
 ';	                
+ #return $hdeb.$ret;		 #Incl. debug
  return $ret;		
 }
 
@@ -669,29 +673,62 @@ sub GetConnections {
  	chomp;
  	#print "==> $_\n";
   s/^([^ ]*) *([^ ]*) *([^ ]*) *([^ ]*) *([^ ]*) *([^ ]*)/$1 $2 $3 $4 $5 $6/;  #Get Tokens !
+  $hdeb.="$1 - $2 - $3 ->$4<- $5 - $6<br>";
+  my $iptmp=$4;
+  my $prototmp=$1;
+  my $statetmp=$3;
+  my $targettmp=$6;
   if (( ! /source/ ) and ( ! /destination/)) {   #Taken over from LVS-1 (??)
-   if (($1 eq "TCP") or ($1 eq "IP") or ($1 eq "UDP") ){
+   if (($prototmp eq "TCP") or ($prototmp eq "IP") or ($prototmp eq "UDP") ){
     $tmpSource=undef;
     $tmpTarget=undef;
-    if ($4) {  #Source Token Set ?
-     ($var,$value) = split(/:/,$4,2);    
-     $tmpSource=$var;
+    
+    if ($iptmp) {  #Source Token Set ?
+     if ($iptmp!~/\[/) {  #v6?
+     	$hdeb.="V4<br>\n";
+      ($var,$value) = split(/:/,$4,2);    
+      $tmpSource=$var;  #2.0.5 - Check extra for v6
+      $ipv4cnt++;
+     }  else {
+     	if ($iptmp =~ /^\[(.*)\]:(\d+)$/) {
+        $hdeb.="V6 --> $1<br>\n";  #2.0.5
+        $tmpSource=$1;  #2.0.5 - Check extra for v6
+        $ipv6cnt++;
+      } 
+     	
+     	
+     }	
+     
+    } 
+
+    #if ($4) {  #Source Token Set ?
+    # ($var,$value) = split(/:/,$4,2);    
+    # $tmpSource=$var;  #2.0.5 - Check extra for v6
+    #} 
+
+
+
+    if ($targettmp) {  #Target Token Set ?
+     if ($targettmp!~/\[/) {  #v6?
+   	 ($var,$value) = split(/:/,$targettmp,2);    
+      $tmpTarget=$var;
+     } else {
+     	if ($targettmp =~ /^\[(.*)\]:(\d+)$/) {
+       $tmpTarget=$1;
+      }
+     }
     } 
-    if ($6) {  #Target Token Set ?
-   	($var,$value) = split(/:/,$6,2);    
-     $tmpTarget=$var;
-    }
     if (($tmpSource) and ($tmpTarget)) {   #Source and Target IP present ?
      $CONNECTIONS++;
      $TotLVSConnx{"$tmpSource-$tmpTarget"}++;
-     
+     $hdeb.="TOT $statetmp\n";
      #Get State
-     if ($3) {  #State Token Set ?
-      if ($3 eq "ESTABLISHED"){$tmpTotESTABLISHED{"$tmpSource-$tmpTarget"}++;} 
-      if ($3 eq "CLOSE") {$tmpTotCLOSED{"$tmpSource-$tmpTarget"}++;}
-      if ($3 eq "NONE") {$tmpTotNONE{"$tmpSource-$tmpTarget"}++;}
-      if ($3 eq "FIN_WAIT") {$tmpTotFIN_WAIT{"$tmpSource-$tmpTarget"}++;}
-      if ($3 eq "SYN_RECV") {$tmpTotSYN_RECV{"$tmpSource-$tmpTarget"}++;}
+     if ($statetmp) {  #State Token Set ?
+      if ($statetmp eq "ESTABLISHED"){$tmpTotESTABLISHED{"$tmpSource-$tmpTarget"}++;} 
+      if ($statetmp eq "CLOSE") {$tmpTotCLOSED{"$tmpSource-$tmpTarget"}++;}
+      if ($statetmp eq "NONE") {$tmpTotNONE{"$tmpSource-$tmpTarget"}++;}
+      if ($statetmp eq "FIN_WAIT") {$tmpTotFIN_WAIT{"$tmpSource-$tmpTarget"}++;}
+      if ($statetmp eq "SYN_RECV") {$tmpTotSYN_RECV{"$tmpSource-$tmpTarget"}++;}
      }     #if ($3) {  #State Token Set
     }      #if (($tmpSource) and ($tmpTarget))
    }       #if (($1 eq "TCP") or ($1 eq "IP") or ($1 eq "UDP") )
