@@ -4,6 +4,9 @@
 #Show Nodes
 ###########
 
+#2.0.5 - Add v6
+
+#To Do: Fix missing display stats for v6
 
 #####################################################################
 #####################################################################
@@ -36,7 +39,7 @@ my $retscriptname="mylvshst.pl";
 
 
 ####################### CONFIGURATION #######################
-my $version = "2.0.1.8";
+my $version = "2.0.5";
 
 #Get Apache Environs
 my $tparam=$ENV{QUERY_STRING};
@@ -47,8 +50,8 @@ my $granted = undef;  #user login flag - default off
 #####################################################################
 
 
-my ($dbh);
-
+my ($dbh,$hdeb,%NodeIDv6,%NodeIDv4);   #2.0.5
+my $prtDeb=undef;  #2.0.5 - set to undef for non debug
 
 my (%NodeID,%NodeAddress,%NodePort,%NodeScheduler,%NodePersistent,%NodePersistentTimeout,%NodeProto,%ResSNMPKey,%ResSNMPPass,%ResSNMPPort,%ResSNMPTO,%ResSNMPEnable);
 my (%RSAddress,%RSPort,%RSRoute,%RSWeight,%RSActive,%RSInActive,$curmodeID,$curmodePropertyID,%ResIP,%ResKEY,%ResActiveSrvTot,%ResInActiveConTot,%ResWeightCur,%ResActiveConTot);
@@ -78,15 +81,17 @@ my ($sqlsnmpkey,$sqlsnmppass,$sqlsnmpport,$sqlsnmptimeout,$sqltsnmpID,$CurHTTPUs
 my (%Ssnmpkey,%Ssnmppass,%Ssnmpport,%Ssqlsnmptimeout,%SsqltsnmpID,%SsqltsnmpKEY,%NodeUsers,%NodeActive,%NodeInActive,%NodeServers);
 my ($SQLscheduler,$SQLservice,$SQLvip,$SQLpersistent,$var,$val,$tmpIP,$tmpPort) ;
 
-my $sqnodes = $dbh->prepare("SELECT nodeid,enabled,name,monitor,scheduler,service,vip,persistent FROM tblNodes" ); 
+my $sqnodes = $dbh->prepare("SELECT nodeid,enabled,name,monitor,scheduler,service,vip,persistent,vip6 FROM tblNodes" ); 
 $sqnodes->execute ; #Get Resources
- while (my($SQLnodeid,$SQLenabled,$SQLname,$SQLmonitor,$SQLscheduler,$SQLservice,$SQLvip,$SQLpersistent)=$sqnodes->fetchrow_array) {
+ while (my($SQLnodeid,$SQLenabled,$SQLname,$SQLmonitor,$SQLscheduler,$SQLservice,$SQLvip,$SQLpersistent,$SQLvip6)=$sqnodes->fetchrow_array) {
   $MON_STAT{$SQLnodeid}=1;
   my $sqinvq = $dbh->prepare("SELECT invid,resid,snmpid FROM tblNodesInventory where nodeid='".$SQLnodeid."' and active='1' and enabled='1' "); 
   $sqinvq->execute ; #Get Resources
   while (my($SQLinvid,$SQLresid,$SQLsnmpid)=$sqinvq->fetchrow_array) {
    $Servers{$SQLnodeid}++;
-   
+   #if ($SQLvip6) { #2.0.5
+   #	$Servers{$SQLnodeid}++;
+   #}
    
    
    #Check Monitors
@@ -139,10 +144,22 @@ $sqnodes->execute ; #Get Resources
 
   
   if (uc($SQLservice) ne "FWM") {
-   ($var,$val) = split(/:/,$SQLvip,2);     #Get IP:Port
-   $tmpIP=$var;
-   $tmpPort=$val;
-   #print "$SQLscheduler-$SQLservice-$SQLvip-$SQLpersistent-$tmpIP-$tmpPort\n";
+   if ($SQLvip) {
+    $hdeb.="xx $SQLservice - $SQLvip<br>";
+    ($var,$val) = split(/:/,$SQLvip,2);     #Get IP:Port
+    $tmpIP=$var;
+    $tmpPort=$val;
+    #print "$SQLscheduler-$SQLservice-$SQLvip-$SQLpersistent-$tmpIP-$tmpPort\n";
+   } else {
+    if ($SQLvip6) {
+   	 $hdeb.="xx V6 $SQLservice - $SQLvip6 -- $tmpIP<br>";
+   	 if ($SQLvip6 =~ /^(.*):(\d+)$/){
+      $tmpIP=$1;
+      $tmpPort=$2;
+   	  $hdeb.="xx $SQLservice - $SQLvip6 -->>>s $tmpIP // $tmpPort<br>";
+   	 } 
+    }	
+   } 
   } else {
    $tmpIP=$SQLvip;	
    #print "$SQLscheduler-$SQLservice-$SQLvip-$SQLpersistent\n";
@@ -154,13 +171,19 @@ $sqnodes->execute ; #Get Resources
 
 
   for my $pntbase (sort keys %NodeID){  #Enum LVS Inventory and enum real nodes and services
+   
    if ($SQLenabled eq "1") {
+   	
     if ($NodeScheduler{$pntbase}	eq $SQLscheduler) {  #Thats a great misconfiguration point !!!!
   	 #print " \n";
   	 if (uc($NodeProto{$pntbase}) ne "FWM") {
+  	 		
  		  if (uc($NodeProto{$pntbase}) eq uc($SQLservice)) {
+ 		  	#$hdeb.="blaxx $NodeAddress{$pntbase} - $tmpIP -- $tmpPort<br>"; 		   	
  		   if ($tmpIP eq $NodeAddress{$pntbase}) {
+ 		   	
  		    if ($tmpPort eq $NodePort{$pntbase}) {	
+ 		    	$hdeb.="bla $NodeAddress{$pntbase} - $tmpIP -- $tmpPort<br>"; 		   	
  		     #print "$NodeID{$pntbase} \n";
  		     #print "$NodeProto{$pntbase} \n";
  		     #print "$NodeAddress{$pntbase} \n";
@@ -170,10 +193,23 @@ $sqnodes->execute ; #Get Resources
          #print "$NodePersistentTimeout{$pntbase} \n\n";
          for my $pntval (sort keys %{$RSAddress{$pntbase}} ){
          	#print "=>$SQLnodeid-$RSAddress{$pntbase}{$pntval} - $RSActive{$pntbase}{$pntval} - $RSInActive{$pntbase}{$pntval}\n";
+         	$hdeb.=("=YYYXXXXX>$SQLnodeid-$RSAddress{$pntbase}{$pntval} - $RSActive{$pntbase}{$pntval} - $RSInActive{$pntbase}{$pntval} // $pntbase // $pntval<br>");
          	#%NodeActive,%NodeInActive
          	$NodeActive{$SQLnodeid}+=$RSActive{$pntbase}{$pntval};
          	$NodeInActive{$SQLnodeid}+=$RSInActive{$pntbase}{$pntval};
-         	$NodeServers{$SQLnodeid}++;
+         	$hdeb.=("=FINAL  $NodeActive{$SQLnodeid} // NodeID $SQLnodeid	 // $pntbase // $pntval //--// $RSAddress{$pntbase}{$pntval}<br>");
+         	if ($RSAddress{$pntbase}{$pntval} =~ /\./) {  #2.0.5 count only v4 as server
+         	 $NodeServers{$SQLnodeid}++; 
+         	 $NodeIDv4{$SQLnodeid}=1;
+         	 $hdeb.=("=FINALv4  PLUS<br>");
+         	} 
+         	
+         	if (!$NodeIDv4{$SQLnodeid}) {  #2.0.5
+            #aloa
+         		$NodeServers{$SQLnodeid}++;
+         		$hdeb.=("=FINALv6  PLUS<br>"); 
+         	}	
+         	
          }	
         } 
        }
@@ -259,7 +295,7 @@ $sqnodes->execute ; #Get Resources
    $txt_active="-";
   }
 
-  if ($NodeActive{$SQLnodeid}) {
+  if ($NodeInActive{$SQLnodeid}) {
    $txt_inactive=$NodeInActive{$SQLnodeid};
    $cnt_tot_inactive+=$NodeInActive{$SQLnodeid};
   } else {
@@ -653,7 +689,11 @@ my $ret='
 </body>
 </html>
 ';	                
- return $ret;		
+ if ($prtDeb ) {
+  return $hdeb.$ret;		
+ } else {
+	return $ret;		
+ } 
 }
 
 sub GetChkCmd {
@@ -713,7 +753,7 @@ sub GetSnmpVal {
   } 
 }
 
-
+ 
 sub GetLVSOutput {
  #Parse LVS Command Output and save it to hash
  my @lvsret = `$lvscmd`;   #Get LVS Status
@@ -721,73 +761,146 @@ sub GetLVSOutput {
  	chomp $myret;
   #Mask: "TCP  10.0.1.18:7000 wrr persistent 3600"
   #Mask: "UDP  10.0.1.22:7000 wrr persistent 3600"
- 	#print "XXXXX  DEB1 => $myret\n";
- 	if ($myret =~ /^(\w{3})\s*(\d*).(\d*).(\d*).(\d*):(\d*)\s*(\w*)\s*(\w*)\s*(\d*)/) {
- 	 #print "XXXXX  DEB2 => $myret\n";
- 	 $curmodeID++;
- 	 $curmodePropertyID=0;
-   $NodeID{$curmodeID}=$curmodeID;
-   $NodeProto{$curmodeID}="$1";
- 	 $NodeAddress{$curmodeID}="$2.$3.$4.$5";
- 	 $NodePort{$curmodeID}="$6";
-   $NodeScheduler{$curmodeID}="$7";		
-   $NodePersistent{$curmodeID}="$8";		
-   $NodePersistentTimeout{$curmodeID}="$9";		
- 	} else {
- 	 if ($myret =~ /^(\w{3})\s*(\d*).(\d*).(\d*).(\d*):(\d*)\s*(\w*)/) {
- 	 	#Mask: "TCP  10.0.1.18:7000 wrr"
-    #Mask: "UDP  10.0.1.22:7000 wrr"
- 	 	#print "XXXXX  DEB2a => $myret\n";
+ 	$hdeb.="XXXXX  DEB1 => $myret<br>";
+ 	if ($myret!~/\s*\[/ ) {  #v6?  #2.0.5
+ 	 if ($myret =~ /^(\w{3})\s*(\d*).(\d*).(\d*).(\d*):(\d*)\s*(\w*)\s*(\w*)\s*(\d*)/) {
+ 	  #print "XXXXX  DEB2 => $myret\n";
  	  $curmodeID++;
  	  $curmodePropertyID=0;
     $NodeID{$curmodeID}=$curmodeID;
+    $NodeIDv4{$curmodeID}=$curmodeID;
     $NodeProto{$curmodeID}="$1";
  	  $NodeAddress{$curmodeID}="$2.$3.$4.$5";
  	  $NodePort{$curmodeID}="$6";
     $NodeScheduler{$curmodeID}="$7";		
-    $NodePersistent{$curmodeID}="";		
-    $NodePersistentTimeout{$curmodeID}="";		
+    $NodePersistent{$curmodeID}="$8";		
+    $NodePersistentTimeout{$curmodeID}="$9";		
  	 } else {
- 	  if ($myret =~ /^FWM\s*(\d*)\s*(\w*)\s*(\w*)\s*(\d*)/) {
- 	 	 #Mask: "FWM  1 wlc persistent 3600"
- 	 	 #print "XXXXX  DEB3 => $myret\n";
- 		 $curmodeID++;
- 		 $curmodePropertyID=0;
- 		 $NodeID{$curmodeID}=$curmodeID;
- 		 $NodeProto{$curmodeID}="FWM";
- 		 $NodeAddress{$curmodeID}="$1";
- 		 $NodePort{$curmodeID}="0";
-     $NodeScheduler{$curmodeID}="$2";		
-     $NodePersistent{$curmodeID}="$3";		
-     $NodePersistentTimeout{$curmodeID}="$4";		
+ 	  if ($myret =~ /^(\w{3})\s*(\d*).(\d*).(\d*).(\d*):(\d*)\s*(\w*)/) {
+ 	   #Mask: "TCP  10.0.1.18:7000 wrr"
+     #Mask: "UDP  10.0.1.22:7000 wrr"
+ 	   #print "XYXYXY  DEB2a => $myret\n";
+ 	   $curmodeID++;
+ 	   $curmodePropertyID=0;
+     $NodeID{$curmodeID}=$curmodeID;
+     $NodeIDv4{$curmodeID}=$curmodeID;
+     $NodeProto{$curmodeID}="$1";
+ 	   $NodeAddress{$curmodeID}="$2.$3.$4.$5";
+ 	   $NodePort{$curmodeID}="$6";
+     $NodeScheduler{$curmodeID}="$7";		
+     $NodePersistent{$curmodeID}="";		
+     $NodePersistentTimeout{$curmodeID}="";		
  	  } else {
- 	   if ($myret =~ /^FWM\s*(\d*)\s*(\w*)/) {
- 	    #Mask: "FWM  1 wlc "
- 	 	  #print "XXXXX  DEB3a => $myret\n";
- 		  $curmodeID++;
- 		  $curmodePropertyID=0;
- 		  $NodeID{$curmodeID}=$curmodeID;
- 		  $NodeProto{$curmodeID}="FWM";
- 		  $NodeAddress{$curmodeID}="$1";
- 		  $NodePort{$curmodeID}="0";
+ 	   if ($myret =~ /^FWM\s*(\d*)\s*(\w*)\s*(\w*)\s*(\d*)/) {
+ 	  	 #Mask: "FWM  1 wlc persistent 3600"
+ 	  	 #print "XXXXX  DEB3 => $myret\n";
+ 	 	 $curmodeID++;
+ 	 	 $curmodePropertyID=0;
+ 	 	 $NodeID{$curmodeID}=$curmodeID;
+ 	 	 $NodeIDv4{$curmodeID}=$curmodeID;
+ 	 	 $NodeProto{$curmodeID}="FWM";
+ 	 	 $NodeAddress{$curmodeID}="$1";
+ 	 	 $NodePort{$curmodeID}="0";
       $NodeScheduler{$curmodeID}="$2";		
       $NodePersistent{$curmodeID}="$3";		
       $NodePersistentTimeout{$curmodeID}="$4";		
+ 	   } else {
+ 	    if ($myret =~ /^FWM\s*(\d*)\s*(\w*)/) {
+ 	     #Mask: "FWM  1 wlc "
+ 	  	  #print "XXXXX  DEB3a => $myret\n";
+ 	 	  $curmodeID++;
+ 	 	  $curmodePropertyID=0;
+ 	 	  $NodeID{$curmodeID}=$curmodeID;
+ 	 	  $NodeIDv4{$curmodeID}=$curmodeID;
+ 	 	  $NodeProto{$curmodeID}="FWM";
+ 	 	  $NodeAddress{$curmodeID}="$1";
+ 	 	  $NodePort{$curmodeID}="0";
+       $NodeScheduler{$curmodeID}="$2";		
+       $NodePersistent{$curmodeID}="$3";		
+       $NodePersistentTimeout{$curmodeID}="$4";		
+ 	    }
  	   }
  	  }
+	 }	
+  }   else {  #2.0.5 V6
+   $hdeb.=" =oo> $myret<br>\n";
+ 	 if ($myret =~ /^(\w{3})\s*\[(.*)\]:(\d*)\s*(\w*)\s*(\w*)\s*(\d*)/) {
+ 	  $hdeb.=" yy=> $myret<br>\n";
+ 	  $curmodeID++;
+ 	  $curmodePropertyID=0;
+    $NodeID{$curmodeID}=$curmodeID;
+    $NodeIDv6{$curmodeID}=$curmodeID;
+    $NodeProto{$curmodeID}="$1";
+ 	  $NodeAddress{$curmodeID}="$2";
+ 	  $NodePort{$curmodeID}="$3";
+    $NodeScheduler{$curmodeID}="$4";		
+    $NodePersistent{$curmodeID}="$5";		
+    $NodePersistentTimeout{$curmodeID}="$6";		
+   } else {
+   	#TCP [fde2:8acd:e9d3::220]:7798 wlc
+ 	  if ($myret =~ /^(\w{3})\s*\[(.*)\]:(\d*)\s*(\w*)/) {
+ 	   $hdeb.=" =xxs> $myret<br>\n";	
+ 	  	#Mask: TCP [fde2:8acd:e9d3::220]:7798 wlc
+ 	   $curmodeID++;
+ 	   $curmodePropertyID=0;
+     $NodeID{$curmodeID}=$curmodeID;
+     $NodeIDv6{$curmodeID}=$curmodeID;
+     $NodeProto{$curmodeID}="$1";
+ 	   $NodeAddress{$curmodeID}="$2";
+ 	   $NodePort{$curmodeID}="$3";
+     $NodeScheduler{$curmodeID}="$4";		
+     $NodePersistent{$curmodeID}="";		
+     $NodePersistentTimeout{$curmodeID}="";		
  	 }
-	}	
+  }
+ } 	
+ 	
+ 	
+ 	
  	#Get Node Values
  	#Mask: " -> 10.0.1.240:0                 Route   100    0          0         "
- 	if ($myret =~ m/\s*->\s*(\d*).(\d*).(\d*).(\d*):(\d*)\s*(\w+)\s*(\d*)\s*(\d*)\s*(\d*)/) {
- 	 $curmodePropertyID++;
-   $RSAddress{$curmodeID}{$curmodePropertyID}="$1.$2.$3.$4";
-   $RSPort{$curmodeID}{$curmodePropertyID}="$5";
-   $RSRoute{$curmodeID}{$curmodePropertyID}="$6";
-   $RSWeight{$curmodeID}{$curmodePropertyID}="$7";
-   $RSActive{$curmodeID}{$curmodePropertyID}="$8";
-   $RSInActive{$curmodeID}{$curmodePropertyID}="$9";
+ 	if ($myret!~/\s*->\s*\[/ ) {  #v6?  #2.0.5
+ 	 if ($myret =~ m/\s*->\s*(\d*).(\d*).(\d*).(\d*):(\d*)\s*(\w+)\s*(\d*)\s*(\d*)\s*(\d*)/) {
+ 	  $curmodePropertyID++;
+    $RSAddress{$curmodeID}{$curmodePropertyID}="$1.$2.$3.$4";
+    $RSPort{$curmodeID}{$curmodePropertyID}="$5";
+    $RSRoute{$curmodeID}{$curmodePropertyID}="$6";
+    $RSWeight{$curmodeID}{$curmodePropertyID}="$7";
+    $RSActive{$curmodeID}{$curmodePropertyID}="$8";
+    $RSInActive{$curmodeID}{$curmodePropertyID}="$9";
+ 	 }
+ 	} else {  #v6
+ 		#if ($iptmp =~ /^\[(.*)\]:(\d+)$/) {
+ 		#$hdeb.="V6 --> $myret<br>\n";  #2.0.5
+ 		#  -> [fde2:8acd:e9d3::221]:7798   Route   100    0          0
+
+ 	  if ($myret =~ m/\s*->\s*\[(.*)\]:(\d*)\s*(\w+)\s*(\d*)\s*(\d*)\s*(\d*)/) {
+ 	   #$hdeb.="$1 $2 $3 -- Active=$5 InActive=$6<br>\n";  #2.0.5
+ 	   $curmodePropertyID++;
+     $RSAddress{$curmodeID}{$curmodePropertyID}="$1";
+     $RSPort{$curmodeID}{$curmodePropertyID}="$2";
+     $RSRoute{$curmodeID}{$curmodePropertyID}="$3";
+     $RSWeight{$curmodeID}{$curmodePropertyID}="$4";
+     $RSActive{$curmodeID}{$curmodePropertyID}="$5";
+     $RSInActive{$curmodeID}{$curmodePropertyID}="$6";
+   
+ 	 } else {
+ 	  if ($myret =~ /^FWM\s*(\d*)\s*(\w*)/) {  #=> experimental - not tested yet
+ 	   #Mask: "FWM  1 wlc "
+ 	   #print "XXXXX  DEB3a => $myret\n";
+ 	 	 #$curmodeID++;
+ 	 	 $curmodePropertyID=0;
+ 	 	 $NodeID{$curmodeID}=$curmodeID;
+ 	 	 $NodeIDv6{$curmodeID}=$curmodeID;
+ 	 	 $NodeProto{$curmodeID}="FWM";
+ 	 	 $NodeAddress{$curmodeID}="$1";
+ 	 	 $NodePort{$curmodeID}="0";
+     $NodeScheduler{$curmodeID}="$2";		
+     $NodePersistent{$curmodeID}="$3";		
+     $NodePersistentTimeout{$curmodeID}="$4";		
+ 	  }
+ 	 }
  	}
  }    #for my $myret (@lvsret)
 }     #sub GetLVSOutput
-
+	
\ No newline at end of file
